@@ -173,7 +173,7 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @seejavax.swing.plaf.basic.BasicButtonUI#uninstallDefaults(javax.swing.
+	 * @see javax.swing.plaf.basic.BasicButtonUI#uninstallDefaults(javax.swing.
 	 * AbstractButton)
 	 */
 	@Override
@@ -387,7 +387,8 @@ public class SubstanceButtonUI extends BasicButtonUI {
 		if (shaper == null)
 			return superPref;
 
-		return shaper.getPreferredSize(button, superPref);
+		Dimension result = shaper.getPreferredSize(button, superPref);
+		return result;
 	}
 
 	/*
