@@ -29,16 +29,14 @@
  */
 package org.jvnet.substance;
 
-import java.beans.PropertyChangeEvent;
-import java.beans.PropertyChangeListener;
-
 import javax.swing.*;
 import javax.swing.border.Border;
 import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicButtonListener;
 
-import org.jvnet.lafwidget.animation.*;
+import org.jvnet.lafwidget.animation.FadeKind;
+import org.jvnet.lafwidget.animation.FadeState;
 import org.jvnet.substance.api.*;
 import org.jvnet.substance.painter.border.SubstanceBorderPainter;
 import org.jvnet.substance.painter.gradient.SubstanceGradientPainter;
@@ -55,16 +53,16 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	 */
 	private final static String propertyPrefix = "CheckBox" + ".";
 
-	/**
-	 * Listener for fade animations.
-	 */
-	protected FadeStateListener substanceFadeStateListener;
-
-	/**
-	 * Property change listener. Listens on changes to
-	 * {@link AbstractButton#MODEL_CHANGED_PROPERTY} property.
-	 */
-	protected PropertyChangeListener substancePropertyListener;
+	// /**
+	// * Listener for fade animations.
+	// */
+	// protected FadeStateListener substanceFadeStateListener;
+	//
+	// /**
+	// * Property change listener. Listens on changes to
+	// * {@link AbstractButton#MODEL_CHANGED_PROPERTY} property.
+	// */
+	// protected PropertyChangeListener substancePropertyListener;
 
 	/*
 	 * (non-Javadoc)
@@ -90,7 +88,6 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	 */
 	public SubstanceCheckBoxUI(JToggleButton button) {
 		super(button);
-		button.setRolloverEnabled(true);
 	}
 
 	/*
@@ -103,51 +100,52 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 		return propertyPrefix;
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @seejavax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.
-	 * AbstractButton)
-	 */
-	@Override
-	protected void installListeners(final AbstractButton b) {
-		super.installListeners(b);
-		this.substanceFadeStateListener = new FadeStateListener(b,
-				b.getModel(), SubstanceCoreUtilities.getFadeCallback(b, false));
-		this.substanceFadeStateListener.registerListeners();
-
-		this.substancePropertyListener = new PropertyChangeListener() {
-			public void propertyChange(PropertyChangeEvent evt) {
-				if (AbstractButton.MODEL_CHANGED_PROPERTY.equals(evt
-						.getPropertyName())) {
-					if (substanceFadeStateListener != null)
-						substanceFadeStateListener.unregisterListeners();
-					substanceFadeStateListener = new FadeStateListener(b, b
-							.getModel(), SubstanceCoreUtilities
-							.getFadeCallback(b, false));
-					substanceFadeStateListener.registerListeners();
-				}
-			}
-		};
-		b.addPropertyChangeListener(this.substancePropertyListener);
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @seejavax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.
-	 * AbstractButton)
-	 */
-	@Override
-	protected void uninstallListeners(AbstractButton b) {
-		this.substanceFadeStateListener.unregisterListeners();
-		this.substanceFadeStateListener = null;
-
-		b.removePropertyChangeListener(this.substancePropertyListener);
-		this.substancePropertyListener = null;
-
-		super.uninstallListeners(b);
-	}
+	// /*
+	// * (non-Javadoc)
+	// *
+	// * @seejavax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.
+	// * AbstractButton)
+	// */
+	// @Override
+	// protected void installListeners(final AbstractButton b) {
+	// super.installListeners(b);
+	// this.substanceFadeStateListener = new FadeStateListener(b,
+	// b.getModel(), SubstanceCoreUtilities.getFadeCallback(b, false));
+	// this.substanceFadeStateListener.registerListeners();
+	//
+	// this.substancePropertyListener = new PropertyChangeListener() {
+	// public void propertyChange(PropertyChangeEvent evt) {
+	// if (AbstractButton.MODEL_CHANGED_PROPERTY.equals(evt
+	// .getPropertyName())) {
+	// if (substanceFadeStateListener != null)
+	// substanceFadeStateListener.unregisterListeners();
+	// substanceFadeStateListener = new FadeStateListener(b, b
+	// .getModel(), SubstanceCoreUtilities
+	// .getFadeCallback(b, false));
+	// substanceFadeStateListener.registerListeners();
+	// }
+	// }
+	// };
+	// b.addPropertyChangeListener(this.substancePropertyListener);
+	// }
+	//
+	// /*
+	// * (non-Javadoc)
+	// *
+	// *
+	// @seejavax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.
+	// * AbstractButton)
+	// */
+	// @Override
+	// protected void uninstallListeners(AbstractButton b) {
+	// this.substanceFadeStateListener.unregisterListeners();
+	// this.substanceFadeStateListener = null;
+	//
+	// b.removePropertyChangeListener(this.substancePropertyListener);
+	// this.substancePropertyListener = null;
+	//
+	// super.uninstallListeners(b);
+	// }
 
 	/*
 	 * (non-Javadoc)
@@ -159,6 +157,9 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	@Override
 	protected void installDefaults(AbstractButton b) {
 		super.installDefaults(b);
+
+		button.setRolloverEnabled(true);
+
 		Border border = b.getBorder();
 		if (border == null || border instanceof UIResource) {
 			b.setBorder(SubstanceSizeUtils.getCheckBoxBorder(SubstanceSizeUtils
@@ -226,6 +227,11 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 		SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
 				.getBorderPainter(button);
 
+		// System.out.println(prevState + " -> [" + cyclePos + "] " +
+		// currState);
+		// System.out.println("\t" + prevBorderColorScheme.getDisplayName()
+		// + " -> " + currBorderColorScheme.getDisplayName());
+
 		HashMapKey key = SubstanceCoreUtilities.getHashKey(fontSize,
 				checkMarkSize, currState.name(), prevState.name(), fillPainter
 						.getDisplayName(), borderPainter.getDisplayName(),
