@@ -70,7 +70,7 @@ public class SubstanceColorChooserUI extends Quaqua14ColorChooserUI {
 				setBundleMethod.invoke(null,
 						new Object[] { SubstanceCoreUtilities
 								.getResourceBundle(null) });
-			} catch (Exception exc) {
+			} catch (Throwable t) {
 				// ignore - either the method doesn't exist or the invocation
 				// failed. Nothing to do in both cases.
 			}
