@@ -46,7 +46,7 @@ import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.api.ComponentState;
 import org.jvnet.substance.api.SubstanceConstants.Side;
 import org.jvnet.substance.api.renderers.SubstanceDefaultComboBoxRenderer;
-import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
+import org.jvnet.substance.painter.utils.HighlightPainterUtils;
 import org.jvnet.substance.utils.*;
 import org.jvnet.substance.utils.border.SubstanceBorder;
 import org.jvnet.substance.utils.combo.*;
@@ -337,7 +337,7 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 									.applyComponentOrientation(newOrientation);
 						}
 						if ((editor != null)
-								&& (editor.getEditorComponent() instanceof Component)) {
+								&& (editor.getEditorComponent() != null)) {
 							(editor.getEditorComponent())
 									.applyComponentOrientation(newOrientation);
 						}
@@ -410,8 +410,7 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 				}
 				ComboBoxEditor editor = SubstanceComboBoxUI.this.comboBox
 						.getEditor();
-				if ((editor != null)
-						&& (editor.getEditorComponent() instanceof Component)) {
+				if ((editor != null) && (editor.getEditorComponent() != null)) {
 					(editor.getEditorComponent())
 							.applyComponentOrientation(currOrientation);
 				}
@@ -465,7 +464,7 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 		graphics.setComposite(TransitionLayout.getAlphaComposite(this.comboBox,
 				alpha, g));
 
-		SubstanceHighlightUtils.paintHighlight(graphics, null, this.comboBox,
+		HighlightPainterUtils.paintHighlight(graphics, null, this.comboBox,
 				new Rectangle(0, 0, this.comboBox.getWidth(), this.comboBox
 						.getHeight()), 0.0f, null, state, state, 0.0f);
 		graphics.dispose();
