@@ -39,7 +39,7 @@ import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicDesktopPaneUI;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
 import org.jvnet.substance.utils.border.SubstanceBorder;
 
@@ -49,11 +49,6 @@ import org.jvnet.substance.utils.border.SubstanceBorder;
  * @author Kirill Grouchnikov
  */
 public class SubstanceDesktopPaneUI extends BasicDesktopPaneUI {
-	/**
-	 * Background delegate.
-	 */
-	private SubstanceFillBackgroundDelegate bgDelegate;
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -64,13 +59,6 @@ public class SubstanceDesktopPaneUI extends BasicDesktopPaneUI {
 		return new SubstanceDesktopPaneUI();
 	}
 
-	/**
-	 * Simple constructor.
-	 */
-	private SubstanceDesktopPaneUI() {
-		this.bgDelegate = new SubstanceFillBackgroundDelegate();
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -105,7 +93,7 @@ public class SubstanceDesktopPaneUI extends BasicDesktopPaneUI {
 				graphics.setColor(UIManager.getColor("Panel.background"));
 				graphics.fillRect(0, 0, c.getWidth(), c.getHeight());
 			}
-			this.bgDelegate.updateIfOpaque(graphics, c);
+			BackgroundPaintingUtils.updateIfOpaque(graphics, c);
 			super.paint(graphics, c);
 		} else {
 			super.paint(graphics, c);
