@@ -40,7 +40,7 @@ import javax.swing.plaf.basic.BasicLabelUI;
 import javax.swing.text.View;
 
 import org.jvnet.substance.api.ComponentState;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -49,11 +49,6 @@ import org.jvnet.substance.utils.*;
  * @author Kirill Grouchnikov
  */
 public class SubstanceLabelUI extends BasicLabelUI {
-	/**
-	 * Background delegate.
-	 */
-	private SubstanceFillBackgroundDelegate bgDelegate;
-
 	/**
 	 * Property change listener.
 	 */
@@ -69,14 +64,6 @@ public class SubstanceLabelUI extends BasicLabelUI {
 		return new SubstanceLabelUI();
 	}
 
-	/**
-	 * Creates a new UI delegate for labels.
-	 */
-	public SubstanceLabelUI() {
-		super();
-		bgDelegate = new SubstanceFillBackgroundDelegate();
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -99,7 +86,7 @@ public class SubstanceLabelUI extends BasicLabelUI {
 						// + b.getText()
 						// + "->"
 						// + b
-						//.getClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL)
+						// .getClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL)
 						// );
 					}
 				}
@@ -133,8 +120,7 @@ public class SubstanceLabelUI extends BasicLabelUI {
 		Icon icon = null;
 		if (label.isEnabled()) {
 			icon = label.getIcon();
-			if ((icon != null)
-					&& SubstanceCoreUtilities.useThemedDefaultIcon())
+			if ((icon != null) && SubstanceCoreUtilities.useThemedDefaultIcon())
 				icon = SubstanceCoreUtilities.getThemedIcon(label, icon);
 		} else {
 			icon = label.getDisabledIcon();
@@ -165,7 +151,7 @@ public class SubstanceLabelUI extends BasicLabelUI {
 				paintTextR, label.getIconTextGap());
 
 		Graphics2D g2d = (Graphics2D) g.create();
-		bgDelegate.updateIfOpaque(g2d, c);
+		BackgroundPaintingUtils.updateIfOpaque(g2d, c);
 		if (icon != null) {
 			icon.paintIcon(c, g2d, paintIconR.x, paintIconR.y);
 		}
