@@ -47,9 +47,8 @@ import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.api.*;
 import org.jvnet.substance.api.renderers.SubstanceDefaultListCellRenderer;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
-import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
-import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
+import org.jvnet.substance.painter.utils.HighlightPainterUtils;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -84,11 +83,6 @@ public class SubstanceListUI extends BasicListUI {
 	 */
 	protected boolean isLeftToRight;
 
-	/**
-	 * Delegate for painting the background of list rows.
-	 */
-	private static SubstanceFillBackgroundDelegate backgroundDelegate = new SubstanceFillBackgroundDelegate();
-
 	/**
 	 * Listener for fade animations on list selections.
 	 */
@@ -109,6 +103,8 @@ public class SubstanceListUI extends BasicListUI {
 	 */
 	private Map<Integer, ComponentState> nextStateMap;
 
+	private ComponentListener substanceComponentListener;
+
 	/**
 	 * Listener for fade animations on list rollovers.
 	 * 
@@ -132,7 +128,7 @@ public class SubstanceListUI extends BasicListUI {
 			// if (SubstanceCoreUtilities.toBleedWatermark(list))
 			// return;
 
-			fadeOut();
+			fadeOutRolloverIndication();
 			// System.out.println("Nulling RO index");
 			resetRolloverIndex();
 			// rolledOverIndex = -1;
@@ -171,7 +167,7 @@ public class SubstanceListUI extends BasicListUI {
 				fadeAllowed = false;
 
 			if (!fadeAllowed) {
-				fadeOut();
+				fadeOutRolloverIndication();
 				resetRolloverIndex();
 				// rolledOverIndex = -1;
 				// list.putClientProperty(ROLLED_OVER_INDEX, null);
@@ -187,7 +183,7 @@ public class SubstanceListUI extends BasicListUI {
 				}
 			}
 			if ((roIndex < 0) || (roIndex >= list.getModel().getSize())) {
-				fadeOut();
+				fadeOutRolloverIndication();
 				// System.out.println("Nulling RO index");
 				resetRolloverIndex();
 				// rolledOverIndex = -1;
@@ -199,7 +195,7 @@ public class SubstanceListUI extends BasicListUI {
 				if ((rolledOverIndex >= 0) && (rolledOverIndex == roIndex))
 					return;
 
-				fadeOut();
+				fadeOutRolloverIndication();
 				FadeTracker.getInstance().trackFadeIn(FadeKind.ROLLOVER, list,
 						roIndex, false, new CellRepaintCallback(list, roIndex));
 				// System.out.println("Setting RO index to " + roIndex);
@@ -207,22 +203,6 @@ public class SubstanceListUI extends BasicListUI {
 				// list.putClientProperty(ROLLED_OVER_INDEX, roIndex);
 			}
 		}
-
-		/**
-		 * Initiates the fade out effect.
-		 */
-		private void fadeOut() {
-			// Integer prevRoIndex = (Integer) list
-			// .getClientProperty(ROLLED_OVER_INDEX);
-			// if (prevRoIndex == null)
-			// return;
-			if (rolledOverIndex < 0)
-				return;
-
-			FadeTracker.getInstance().trackFadeOut(FadeKind.ROLLOVER, list,
-					rolledOverIndex, false,
-					new CellRepaintCallback(list, rolledOverIndex));
-		}
 	}
 
 	/*
@@ -530,6 +510,17 @@ public class SubstanceListUI extends BasicListUI {
 			}
 		};
 		list.addPropertyChangeListener(substancePropertyChangeListener);
+
+		this.substanceComponentListener = new ComponentAdapter() {
+			@Override
+			public void componentMoved(ComponentEvent e) {
+				// clear the rollover indexes since these are no longer
+				// in sync with the mouse location
+				fadeOutRolloverIndication();
+				resetRolloverIndex();
+			}
+		};
+		this.list.addComponentListener(this.substanceComponentListener);
 	}
 
 	@Override
@@ -545,6 +536,9 @@ public class SubstanceListUI extends BasicListUI {
 		list.removePropertyChangeListener(substancePropertyChangeListener);
 		substancePropertyChangeListener = null;
 
+		this.list.removeComponentListener(this.substanceComponentListener);
+		this.substanceComponentListener = null;
+
 		super.uninstallListeners();
 	}
 
@@ -606,7 +600,7 @@ public class SubstanceListUI extends BasicListUI {
 				g2d.fillRect(cx, cy, cw, ch);
 			}
 		} else {
-			backgroundDelegate.fillAndWatermark(g2d, this.list,
+			BackgroundPaintingUtils.fillAndWatermark(g2d, this.list,
 					rendererComponent.getBackground(), new Rectangle(cx, cy,
 							cw, ch));
 		}
@@ -654,7 +648,7 @@ public class SubstanceListUI extends BasicListUI {
 		if (totalAlpha > 0.0f) {
 			g2d.setComposite(TransitionLayout.getAlphaComposite(list,
 					totalAlpha, g));
-			SubstanceHighlightUtils.paintHighlight(g2d, this.rendererPane,
+			HighlightPainterUtils.paintHighlight(g2d, this.rendererPane,
 					rendererComponent, cellRect, 0.8f, null, currScheme,
 					prevScheme, currBorderScheme, prevBorderScheme, fadeCoef);
 			g2d.setComposite(TransitionLayout.getAlphaComposite(list, g));
@@ -707,6 +701,22 @@ public class SubstanceListUI extends BasicListUI {
 		rolledOverIndex = -1;
 	}
 
+	/**
+	 * Initiates the fade out effect.
+	 */
+	private void fadeOutRolloverIndication() {
+		// Integer prevRoIndex = (Integer) list
+		// .getClientProperty(ROLLED_OVER_INDEX);
+		// if (prevRoIndex == null)
+		// return;
+		if (rolledOverIndex < 0)
+			return;
+
+		FadeTracker.getInstance().trackFadeOut(FadeKind.ROLLOVER, list,
+				rolledOverIndex, false,
+				new CellRepaintCallback(list, rolledOverIndex));
+	}
+
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -715,7 +725,7 @@ public class SubstanceListUI extends BasicListUI {
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
-		SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.updateIfOpaque(g, c);
+		BackgroundPaintingUtils.updateIfOpaque(g, c);
 
 		Graphics2D g2d = (Graphics2D) g.create();
 		SubstanceStripingUtils.setup(c);
@@ -774,14 +784,14 @@ public class SubstanceListUI extends BasicListUI {
 			this.borderSchemeMap = new EnumMap<ComponentState, SubstanceColorScheme>(
 					ComponentState.class);
 			this.opacity = new HashMap<Component, Boolean>();
-			this.decorationAreaType = SubstanceDecorationUtilities
+			this.decorationAreaType = SubstanceLookAndFeel
 					.getDecorationType(list);
 
 			SubstanceSkin skin = SubstanceCoreUtilities.getSkin(list);
 			this.isInDecorationArea = (this.decorationAreaType != null)
 					&& skin
 							.isRegisteredAsDecorationArea(this.decorationAreaType)
-					& TransitionLayout.isOpaque(list);
+					&& TransitionLayout.isOpaque(list);
 		}
 
 		public SubstanceColorScheme getHighlightColorScheme(ComponentState state) {
