@@ -52,7 +52,7 @@ import org.jvnet.substance.api.tabbed.BaseTabCloseListener;
 import org.jvnet.substance.api.tabbed.TabCloseCallback;
 import org.jvnet.substance.fonts.*;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
-import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
+import org.jvnet.substance.painter.utils.DecorationPainterUtils;
 import org.jvnet.substance.plugin.SubstanceSkinPlugin;
 import org.jvnet.substance.shaper.*;
 import org.jvnet.substance.skin.SkinChangeListener;
@@ -97,22 +97,22 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 	/**
 	 * Plugin manager for component plugins.
 	 */
-	protected static ComponentPluginManager componentPlugins;
+	private static ComponentPluginManager componentPlugins;
 
 	/**
 	 * Plugin manager for skin plugins.
 	 */
-	protected static PluginManager skinPlugins;
+	private static PluginManager skinPlugins;
 
 	/**
 	 * List of all listeners on skin changes.
 	 */
-	protected static Set<SkinChangeListener> skinChangeListeners = new HashSet<SkinChangeListener>();
+	protected final static Set<SkinChangeListener> skinChangeListeners = new HashSet<SkinChangeListener>();
 
 	/**
 	 * List of all listeners on closing tabs.
 	 */
-	protected static Set<LocaleChangeListener> localeChangeListeners = new HashSet<LocaleChangeListener>();
+	protected final static Set<LocaleChangeListener> localeChangeListeners = new HashSet<LocaleChangeListener>();
 
 	/**
 	 * Indicates whether option dialogs (error, question, warning, info) should
@@ -125,7 +125,7 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 	 * @see #isToUseConstantThemesOnDialogs()
 	 * @see #setToUseConstantThemesOnDialogs(boolean)
 	 */
-	protected static boolean toUseConstantThemesOnDialogs = true;
+	private static boolean toUseConstantThemesOnDialogs = true;
 
 	/**
 	 * Change listener on keyboard focus manager - fix for defect 208.
@@ -1950,6 +1950,14 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 	@SubstanceApi
 	private static boolean setSkin(SubstanceSkin newSkin,
 			boolean toUpdateWindows) {
+		if (!SwingUtilities.isEventDispatchThread()) {
+			throw new IllegalStateException(
+					"This method must be called on the Event Dispatch Thread");
+		}
+
+		if (!newSkin.isValid())
+			return false;
+
 		boolean isSubstance = (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel);
 		if (!isSubstance) {
 			class SkinDerivedLookAndFeel extends SubstanceLookAndFeel {
@@ -1964,6 +1972,9 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 			} catch (UnsupportedLookAndFeelException ulafe) {
 				return false;
 			}
+			if (!(UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel)) {
+				return false;
+			}
 			for (Window window : Window.getWindows()) {
 				SwingUtilities.updateComponentTreeUI(window);
 			}
@@ -1972,16 +1983,18 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 
 		try {
 			// Required skin settings must be non-null
-			if (!newSkin.isValid())
+			if (!newSkin.isValid()) {
 				return false;
+			}
 
 			// fix for defect 109 - memory leak on watermark switch
 			if ((currentSkin != null) && (currentSkin.getWatermark() != null)) {
 				currentSkin.getWatermark().dispose();
 			}
 			if (newSkin.getWatermark() != null) {
-				if (!newSkin.getWatermark().updateWatermarkImage(newSkin))
+				if (!newSkin.getWatermark().updateWatermarkImage(newSkin)) {
 					return false;
+				}
 			}
 
 			UIDefaults defaults = UIManager.getLookAndFeelDefaults();
@@ -2021,7 +2034,6 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 			// that can't be found in the classpath.
 			return false;
 		} catch (Exception e) {
-			e.printStackTrace();
 			return false;
 		}
 	}
@@ -2030,12 +2042,16 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 	 * Sets the specified skin. If the current look-and-feel is not Substance,
 	 * this method will create a new Substance look-and-feel based on the
 	 * specified skin and set it on {@link UIManager}. This method does not
-	 * require Substance to be the current look-and-feel.
+	 * require Substance to be the current look-and-feel. Calling this method
+	 * will call {@link SwingUtilities#updateComponentTreeUI(Component)} on all
+	 * open top-level windows.
 	 * 
 	 * @param newSkin
 	 *            Skin to set.
 	 * @return <code>true</code> if the specified skin has been set
 	 *         successfully, <code>false</code> otherwise.
+	 * @throws IllegalStateException
+	 *             When called outside the Event Dispatch Thread.
 	 * @see #registerSkinChangeListener(SkinChangeListener)
 	 * @see #unregisterSkinChangeListener(SkinChangeListener)
 	 * @see SubstanceSkin#isValid()
@@ -2048,12 +2064,16 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 	 * Sets the specified skin. If the current look-and-feel is not Substance,
 	 * this method will create a new Substance look-and-feel based on the
 	 * specified skin and set it on {@link UIManager}. This method does not
-	 * require Substance to be the current look-and-feel.
+	 * require Substance to be the current look-and-feel. Calling this method
+	 * will call {@link SwingUtilities#updateComponentTreeUI(Component)} on all
+	 * open top-level windows.
 	 * 
 	 * @param skinClassName
 	 *            Skin to set.
 	 * @return <code>true</code> if the specified skin has been set
 	 *         successfully, <code>false</code> otherwise.
+	 * @throws IllegalStateException
+	 *             When called outside the Event Dispatch Thread.
 	 * @since version 3.1
 	 * @see #setSkin(SubstanceSkin)
 	 * @see #registerSkinChangeListener(SkinChangeListener)
@@ -2163,7 +2183,7 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 	@SubstanceApi
 	public static void setDecorationType(JComponent comp,
 			DecorationAreaType type) {
-		SubstanceDecorationUtilities.setDecorationType(comp, type);
+		DecorationPainterUtils.setDecorationType(comp, type);
 	}
 
 	// /**
@@ -2199,7 +2219,7 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 	 * @return Decoration area type of the component.
 	 */
 	public static DecorationAreaType getDecorationType(Component comp) {
-		return SubstanceDecorationUtilities.getDecorationType(comp);
+		return DecorationPainterUtils.getDecorationType(comp);
 	}
 
 	/**
@@ -2213,7 +2233,7 @@ public abstract class SubstanceLookAndFeel extends BasicLookAndFeel {
 	 * @return Immediate decoration area type of the component.
 	 */
 	public static DecorationAreaType getImmediateDecorationType(Component comp) {
-		return SubstanceDecorationUtilities.getImmediateDecorationType(comp);
+		return DecorationPainterUtils.getImmediateDecorationType(comp);
 	}
 
 	/**
