@@ -38,8 +38,8 @@ import javax.swing.plaf.basic.BasicMenuBarUI;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
-import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
+import org.jvnet.substance.painter.utils.DecorationPainterUtils;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
 
 /**
@@ -78,7 +78,7 @@ public class SubstanceMenuBarUI extends BasicMenuBarUI {
 	 */
 	@Override
 	protected void uninstallDefaults() {
-		SubstanceDecorationUtilities.clearDecorationType(this.menuBar);
+		DecorationPainterUtils.clearDecorationType(this.menuBar);
 
 		super.uninstallDefaults();
 	}
@@ -93,7 +93,7 @@ public class SubstanceMenuBarUI extends BasicMenuBarUI {
 	public void update(Graphics g, JComponent c) {
 		boolean isOpaque = TransitionLayout.isOpaque(c);
 		if (isOpaque) {
-			SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.update(g, c, false);
+			BackgroundPaintingUtils.update(g, c, false);
 		} else {
 			super.update(g, c);
 		}
