@@ -37,7 +37,7 @@ import javax.swing.plaf.basic.BasicOptionPaneUI;
 
 import org.jvnet.lafwidget.LafWidgetUtilities;
 import org.jvnet.lafwidget.animation.*;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
 import org.jvnet.substance.utils.icon.GlowingIcon;
 
@@ -52,11 +52,6 @@ public class SubstanceOptionPaneUI extends BasicOptionPaneUI {
 				OptionPaneLabel.class);
 	}
 
-	/**
-	 * Delegate for filling the background.
-	 */
-	private static SubstanceFillBackgroundDelegate bgDelegate = new SubstanceFillBackgroundDelegate();
-
 	/**
 	 * Label extension class. Due to defect 250, the option pane icon animation
 	 * (glowing icon) should repaint only the icon itself and not the entire
@@ -91,7 +86,7 @@ public class SubstanceOptionPaneUI extends BasicOptionPaneUI {
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
-		SubstanceOptionPaneUI.bgDelegate.updateIfOpaque(g, c);
+		BackgroundPaintingUtils.updateIfOpaque(g, c);
 	}
 
 	/*
