@@ -38,7 +38,7 @@ import javax.swing.plaf.*;
 import javax.swing.plaf.basic.BasicPanelUI;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.SubstanceColorUtilities;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
 
@@ -70,14 +70,12 @@ public class SubstancePanelUI extends BasicPanelUI {
 		// support for per-window skins
 		Color backgr = p.getBackground();
 		if ((backgr == null) || (backgr instanceof UIResource)) {
-			if ((backgr == null) || (backgr instanceof UIResource)) {
-				Color backgroundFillColor = SubstanceColorUtilities
-						.getBackgroundFillColor(p);
-				// fix for issue 436 - logic in getBackground() of
-				// custom panels can result in null value
-				if (backgroundFillColor != null) {
-					p.setBackground(new ColorUIResource(backgroundFillColor));
-				}
+			Color backgroundFillColor = SubstanceColorUtilities
+					.getBackgroundFillColor(p);
+			// fix for issue 436 - logic in getBackground() of
+			// custom panels can result in null value
+			if (backgroundFillColor != null) {
+				p.setBackground(new ColorUIResource(backgroundFillColor));
 			}
 		}
 	}
@@ -94,7 +92,7 @@ public class SubstancePanelUI extends BasicPanelUI {
 			return;
 
 		if (toPaintBackground(c)) {
-			SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.update(g, c, false);
+			BackgroundPaintingUtils.update(g, c, false);
 		}
 		super.paint(g, c);
 	}
