@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
+ * Copyright (c) 2005-2009 Substance Kirill Grouchnikov. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -31,6 +31,8 @@ package org.jvnet.substance;
 
 import java.awt.*;
 import java.awt.image.BufferedImage;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
 
 import javax.swing.*;
 import javax.swing.event.ChangeEvent;
@@ -43,7 +45,6 @@ import org.jvnet.lafwidget.animation.FadeTracker;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.api.ComponentState;
 import org.jvnet.substance.api.SubstanceColorScheme;
-import org.jvnet.substance.painter.border.InnerDelegateBorderPainter;
 import org.jvnet.substance.painter.border.SubstanceBorderPainter;
 import org.jvnet.substance.painter.gradient.SubstanceGradientPainter;
 import org.jvnet.substance.utils.*;
@@ -80,6 +81,17 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	 */
 	protected ChangeListener substanceValueChangeListener;
 
+	/**
+	 * Property change listener. Tracks changes to the <code>font</code>
+	 * property.
+	 */
+	protected PropertyChangeListener substancePropertyChangeListener;
+
+	/**
+	 * Inner margin.
+	 */
+	protected int margin;
+
 	/**
 	 * The speed factor for the indeterminate progress bars.
 	 */
@@ -122,6 +134,15 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 
 		this.speed = (20.0f * UIManager.getInt("ProgressBar.repaintInterval"))
 				/ UIManager.getInt("ProgressBar.cycleTime");
+
+		float borderThickness = SubstanceSizeUtils
+				.getBorderStrokeWidth(SubstanceSizeUtils
+						.getComponentFontSize(this.progressBar));
+		SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
+				.getBorderPainter(this.progressBar);
+		this.margin = borderPainter.isPaintingInnerContour() ? (int) Math
+				.ceil(2.0 * borderThickness) : (int) Math
+				.ceil(1.5 * borderThickness);
 	}
 
 	@Override
@@ -132,15 +153,16 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 		if (model instanceof DefaultBoundedRangeModel) {
 			substanceValueChangeListener = new ChangeListener() {
 				public void stateChanged(ChangeEvent e) {
+					SubstanceCoreUtilities
+							.testComponentStateChangeThreadingViolation(progressBar);
+
 					int oldValue = (Integer) progressBar
 							.getClientProperty(PROGRESS_BAR_TO);
 					int currValue = model.getValue();
 					int span = model.getMaximum() - model.getMinimum();
-					Insets b = progressBar.getInsets(); // area for border
-					int barRectWidth = progressBar.getWidth()
-							- (b.right + b.left);
-					int barRectHeight = progressBar.getHeight()
-							- (b.top + b.bottom);
+					// Insets b = getInsets(); // area for border
+					int barRectWidth = progressBar.getWidth() - 2 * margin;
+					int barRectHeight = progressBar.getHeight() - 2 * margin;
 					int totalPixels = (progressBar.getOrientation() == JProgressBar.HORIZONTAL) ? barRectWidth
 							: barRectHeight;
 					// fix for defect 223 (min and max on the model are the
@@ -174,8 +196,29 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 			((DefaultBoundedRangeModel) model)
 					.addChangeListener(substanceValueChangeListener);
 		}
+
+		this.substancePropertyChangeListener = new PropertyChangeListener() {
+			@Override
+			public void propertyChange(PropertyChangeEvent evt) {
+				if ("font".equals(evt.getPropertyName())) {
+					SwingUtilities.invokeLater(new Runnable() {
+						public void run() {
+							if (progressBar != null)
+								progressBar.updateUI();
+						}
+					});
+				}
+			}
+		};
+		this.progressBar
+				.addPropertyChangeListener(this.substancePropertyChangeListener);
 	}
 
+	/*
+	 * (non-Javadoc)
+	 * 
+	 * @see javax.swing.plaf.basic.BasicProgressBarUI#uninstallListeners()
+	 */
 	@Override
 	protected void uninstallListeners() {
 		BoundedRangeModel model = progressBar.getModel();
@@ -184,6 +227,10 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 					.removeChangeListener(substanceValueChangeListener);
 		}
 
+		this.progressBar
+				.removePropertyChangeListener(this.substancePropertyChangeListener);
+		this.substancePropertyChangeListener = null;
+
 		super.uninstallListeners();
 	}
 
@@ -218,6 +265,8 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	/**
 	 * Returns the background of a determinate progress bar.
 	 * 
+	 * @param bar
+	 *            Progress bar.
 	 * @param width
 	 *            Progress bar width.
 	 * @param height
@@ -274,27 +323,26 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 			return;
 		}
 
-		final Insets insets = progressBar.getInsets();
-		insets.top /= 2;
-		insets.left /= 2;
-		insets.bottom /= 2;
-		insets.right /= 2;
-		int barRectWidth = progressBar.getWidth()
-				- (insets.right + insets.left);
-		int barRectHeight = progressBar.getHeight()
-				- (insets.top + insets.bottom);
+		// final Insets insets = this.getInsets();
+		// insets.top /= 2;
+		// insets.left /= 2;
+		// insets.bottom /= 2;
+		// insets.right /= 2;
+		int barRectWidth = progressBar.getWidth() - 2 * margin;
+		int barRectHeight = progressBar.getHeight() - 2 * margin;
 
 		// amount of progress to draw
-		int amountFull = getAmountFull(insets, barRectWidth, barRectHeight);
+		int amountFull = getAmountFull(new Insets(margin, margin, margin,
+				margin), barRectWidth, barRectHeight);
 
 		Graphics2D g2d = (Graphics2D) g.create();
 		// install state-aware alpha channel (support for skins
 		// that use translucency on disabled states).
-		float themeAlpha = SubstanceColorSchemeUtilities.getAlpha(progressBar,
+		float stateAlpha = SubstanceColorSchemeUtilities.getAlpha(progressBar,
 				progressBar.isEnabled() ? ComponentState.DEFAULT
 						: ComponentState.DISABLED_UNSELECTED);
 		g2d.setComposite(TransitionLayout.getAlphaComposite(progressBar,
-				themeAlpha, g));
+				stateAlpha, g));
 
 		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
 				.getColorScheme(progressBar,
@@ -308,49 +356,27 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 					barRectWidth + 1, barRectHeight + 1, scheme, gp,
 					progressBar.getOrientation(), this.progressBar
 							.getComponentOrientation());
-			g2d.drawImage(back, insets.left, insets.top, null);
+			g2d.drawImage(back, margin, margin, null);
 		} else {
 			BufferedImage back = getDeterminateBackground(progressBar,
 					barRectHeight + 1, barRectWidth + 1, scheme, gp,
 					progressBar.getOrientation(), this.progressBar
 							.getComponentOrientation());
-			g2d.drawImage(back, insets.left, insets.top, null);
+			g2d.drawImage(back, margin, margin, null);
 		}
-		// if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
-		// Shape contour = SubstanceOutlineUtilities.getBaseOutline(
-		// barRectWidth + 1, barRectHeight + 1, 0, null);
-		// gp.paintContourBackground(g2d, barRectWidth + 1, barRectHeight + 1,
-		// contour, false, scheme, scheme, 0, true, false);
-		// } else {
-		// Shape contour = SubstanceOutlineUtilities.getBaseOutline(
-		// barRectHeight + 1, barRectWidth + 1, 0, null);
-		//
-		// AffineTransform at = g2d.getTransform();
-		//
-		// AffineTransform rotated = new AffineTransform(at);
-		// if (this.progressBar.getComponentOrientation().isLeftToRight()) {
-		// rotated.translate(0, barRectHeight);
-		// rotated.rotate(-Math.PI / 2);
-		// } else {
-		// rotated.translate(barRectWidth, 0);
-		// rotated.rotate(Math.PI / 2);
-		// }
-		// g2d.setTransform(rotated);
-		// gp.paintContourBackground(g2d, barRectHeight + 1, barRectWidth + 1,
-		// contour, false, scheme, scheme, 0, true, false);
-		// g2d.setTransform(at);
-		// }
-		// g2d.translate(-insets.left, -insets.top);
 
 		if (amountFull > 0) {
-			float borderStrokeWidth = SubstanceSizeUtils
-					.getBorderStrokeWidth(SubstanceSizeUtils
-							.getComponentFontSize(progressBar));
-			SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
-					.getBorderPainter(null);
-			int borderDelta = (borderPainter instanceof InnerDelegateBorderPainter) ? (int) (Math
-					.ceil(2.0 * borderStrokeWidth)) / 2
-					: (int) (borderStrokeWidth / 2.0);
+			// float borderStrokeWidth = SubstanceSizeUtils
+			// .getBorderStrokeWidth(SubstanceSizeUtils
+			// .getComponentFontSize(progressBar));
+			// SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
+			// .getBorderPainter(null);
+			int borderDelta = 0;
+			// (borderPainter instanceof InnerDelegateBorderPainter) ? (int)
+			// (Math
+			// .ceil(2.0 * borderStrokeWidth)) / 2
+			// : (int) (Math.ceil(borderStrokeWidth / 2.0));// : 0;
+			// if (borderDelta == 0)
 
 			SubstanceColorScheme fillColorScheme = SubstanceColorSchemeUtilities
 					.getColorScheme(progressBar,
@@ -361,30 +387,34 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 				int barHeight = barRectHeight - 2 * borderDelta;
 				if ((barWidth > 0) && (barHeight > 0)) {
 					if (progressBar.getComponentOrientation().isLeftToRight()) {
-						SubstanceImageCreator.paintRectangularBackground(g,
-								insets.left + borderDelta, insets.top
+						SubstanceImageCreator.paintRectangularBackground(
+								progressBar, g, margin + borderDelta, margin
 										+ borderDelta, barWidth, barHeight,
 								fillColorScheme, 0.6f, false);
+
+						// g.setColor(Color.red);
+						// g.fillRect(insets.left + borderDelta,
+						// insets.top + borderDelta, barWidth, barHeight);
 					} else {
 						// fix for RTL determinate horizontal progress
 						// bar in 2.3
-						SubstanceImageCreator.paintRectangularBackground(g,
-								insets.left + barRectWidth - amountFull - 2
-										* borderDelta,
-								insets.top + borderDelta, barWidth, barHeight,
+						SubstanceImageCreator.paintRectangularBackground(
+								progressBar, g, margin + barRectWidth
+										- amountFull - 2 * borderDelta, margin
+										+ borderDelta, barWidth, barHeight,
 								fillColorScheme, 0.6f, false);
 					}
 				}
 			} else { // VERTICAL
-				int barWidth = progressBar.getHeight() - insets.bottom
-						- amountFull - 2 * borderDelta;
+				int barWidth = amountFull - 2 * borderDelta;
 				int barHeight = barRectWidth - 2 * borderDelta;
-				if ((barWidth > 0) && (barHeight > 0)) {
+				if ((amountFull > 0) && (barHeight > 0)) {
 					// fix for issue 95. Vertical bar is growing from
 					// the bottom
-					SubstanceImageCreator.paintRectangularBackground(g,
-							insets.left + borderDelta, barWidth + borderDelta,
-							barHeight, amountFull, fillColorScheme, 0.6f, true);
+					SubstanceImageCreator.paintRectangularBackground(
+							progressBar, g, margin + borderDelta, margin
+									+ barRectHeight - barWidth - borderDelta,
+							barHeight, barWidth, fillColorScheme, 0.6f, true);
 				}
 			}
 		}
@@ -393,8 +423,8 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 		if (progressBar.isStringPainted()) {
 			g2d.setComposite(TransitionLayout.getAlphaComposite(progressBar,
 					1.0f, g));
-			this.paintString(g2d, insets.left, insets.top, barRectWidth,
-					barRectHeight, amountFull, insets);
+			this.paintString(g2d, margin, margin, barRectWidth, barRectHeight,
+					amountFull, new Insets(margin, margin, margin, margin));
 		}
 		g2d.dispose();
 	}
@@ -440,46 +470,47 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 			return;
 		}
 
-		final Insets b = progressBar.getInsets(); // area for border
-		final int barRectWidth = progressBar.getWidth() - (b.right + b.left);
-		final int barRectHeight = progressBar.getHeight() - (b.top + b.bottom);
+		// final Insets b = this.getInsets(); // area for border
+		final int barRectWidth = progressBar.getWidth() - 2 * margin;
+		final int barRectHeight = progressBar.getHeight() - 2 * margin;
 
 		final int valComplete = (int) animationIndex;
 
 		Graphics2D g2d = (Graphics2D) g.create();
 		// install state-aware alpha channel (support for skins
 		// that use translucency on disabled states).
-		float themeAlpha = SubstanceColorSchemeUtilities.getAlpha(progressBar,
+		float stateAlpha = SubstanceColorSchemeUtilities.getAlpha(progressBar,
 				progressBar.isEnabled() ? ComponentState.SELECTED
 						: ComponentState.DISABLED_UNSELECTED);
 		g2d.setComposite(TransitionLayout.getAlphaComposite(progressBar,
-				themeAlpha, g));
+				stateAlpha, g));
 
 		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
 				.getColorScheme(progressBar,
 						progressBar.isEnabled() ? ComponentState.SELECTED
 								: ComponentState.DISABLED_UNSELECTED);
 		if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
-			SubstanceImageCreator.paintRectangularStripedBackground(g2d,
-					b.left, b.top, barRectWidth, barRectHeight, scheme,
-					SubstanceProgressBarUI.getStripe(barRectHeight, false,
-							scheme), valComplete, 0.6f, false);
+			SubstanceImageCreator.paintRectangularStripedBackground(
+					progressBar, g2d, margin, margin, barRectWidth,
+					barRectHeight, scheme, SubstanceProgressBarUI.getStripe(
+							barRectHeight, false, scheme), valComplete, 0.6f,
+					false);
 		} else {
 			// fix for issue 95. Vertical progress bar grows from the
 			// bottom.
-			SubstanceImageCreator.paintRectangularStripedBackground(g2d,
-					b.left, b.top, barRectWidth, barRectHeight, scheme,
-					SubstanceProgressBarUI
-							.getStripe(barRectWidth, true, scheme), 2
-							* barRectWidth - valComplete, 0.6f, true);
+			SubstanceImageCreator.paintRectangularStripedBackground(
+					progressBar, g2d, margin, margin, barRectWidth,
+					barRectHeight, scheme, SubstanceProgressBarUI.getStripe(
+							barRectWidth, true, scheme), 2 * barRectWidth
+							- valComplete, 0.6f, true);
 		}
 
 		// Deal with possible text painting
 		if (progressBar.isStringPainted()) {
 			g2d.setComposite(TransitionLayout.getAlphaComposite(progressBar,
 					1.0f, g));
-			this.paintString(g2d, b.left, b.top, barRectWidth, barRectHeight,
-					barRectWidth, b);
+			this.paintString(g2d, margin, margin, barRectWidth, barRectHeight,
+					barRectWidth, new Insets(margin, margin, margin, margin));
 		}
 		g2d.dispose();
 	}
@@ -491,10 +522,10 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	 */
 	@Override
 	protected Rectangle getBox(Rectangle r) {
-		Insets b = progressBar.getInsets(); // area for border
-		int barRectWidth = progressBar.getWidth() - (b.right + b.left);
-		int barRectHeight = progressBar.getHeight() - (b.top + b.bottom);
-		return new Rectangle(b.left, b.top, barRectWidth, barRectHeight);
+		// Insets b = this.getInsets(); // area for border
+		int barRectWidth = progressBar.getWidth() - 2 * margin;
+		int barRectHeight = progressBar.getHeight() - 2 * margin;
+		return new Rectangle(margin, margin, barRectWidth, barRectHeight);
 	}
 
 	/*
@@ -506,9 +537,9 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	protected void incrementAnimationIndex() {
 		float newValue = animationIndex + this.speed;
 
-		Insets b = progressBar.getInsets(); // area for border
-		int barRectHeight = progressBar.getHeight() - (b.top + b.bottom);
-		int barRectWidth = progressBar.getWidth() - (b.right + b.left);
+		// Insets b = this.getInsets(); // area for border
+		int barRectHeight = progressBar.getHeight() - 2 * margin;
+		int barRectWidth = progressBar.getWidth() - 2 * margin;
 		int threshold = 0;
 		if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
 			threshold = 2 * barRectHeight + 1;
@@ -701,5 +732,20 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 			// fontSizer.getHeight(), stringWidth);
 		}
 	}
-
+	//
+	// private Insets getInsets() {
+	// float borderThickness = SubstanceSizeUtils
+	// .getBorderStrokeWidth(SubstanceSizeUtils
+	// .getComponentFontSize(this.progressBar));
+	// SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
+	// .getBorderPainter(this.progressBar);
+	// int insets = 0;
+	// if (borderPainter instanceof InnerDelegateBorderPainter) {
+	// insets = (int) Math.ceil(2.0 * borderThickness);
+	// } else {
+	// insets = (int) Math.ceil(1.5 * borderThickness);
+	// }
+	//
+	// return new Insets(insets, insets, insets, insets);
+	// }
 }
