@@ -45,7 +45,7 @@ import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.api.*;
 import org.jvnet.substance.painter.border.SubstanceBorderPainter;
 import org.jvnet.substance.painter.gradient.SubstanceGradientPainter;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -144,6 +144,8 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 							.getComponentFontSize(b)));
 		}
 
+		button.setRolloverEnabled(true);
+
 		LookAndFeel.installProperty(b, "iconTextGap", SubstanceSizeUtils
 				.getTextIconGap(SubstanceSizeUtils.getComponentFontSize(b)));
 	}
@@ -302,7 +304,7 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 
 		if (// isOpaque ||
 		TransitionLayout.isOpaque(c)) {
-			SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.update(g, c, false);
+			BackgroundPaintingUtils.update(g, c, false);
 		}
 
 		// b.setOpaque(isOpaque);
