@@ -49,6 +49,10 @@ import org.jvnet.substance.utils.*;
  * @author Larry Salibra (fix for defect 198)
  */
 public class SubstanceRootPaneUI extends BasicRootPaneUI {
+	private enum CursorState {
+		EXITED, ENTERED, NIL
+	}
+
 	/**
 	 * The amount of space (in pixels) that the cursor is changed on.
 	 */
@@ -412,7 +416,7 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 								public void run() {
 									if (window == null)
 										return;
-									
+
 									if (!window.isShowing()
 											|| !window.isDisplayable()) {
 										currentRootPaneGC = null;
@@ -1232,17 +1236,23 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 			}
 		}
 
+		private CursorState cursorState = CursorState.NIL;
+
 		public void mouseEntered(MouseEvent ev) {
 			Window w = (Window) ev.getSource();
-			// fix for defect 107
-			SubstanceRootPaneUI.this.lastCursor = w.getCursor();
-			// Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR);
+			if (cursorState == CursorState.EXITED
+					|| cursorState == CursorState.NIL) {
+				// fix for defect 107
+				SubstanceRootPaneUI.this.lastCursor = w.getCursor();
+			}
+			cursorState = CursorState.ENTERED;
 			this.mouseMoved(ev);
 		}
 
 		public void mouseExited(MouseEvent ev) {
 			Window w = (Window) ev.getSource();
 			w.setCursor(SubstanceRootPaneUI.this.lastCursor);
+			cursorState = CursorState.EXITED;
 		}
 
 		public void mouseClicked(MouseEvent ev) {
@@ -1255,19 +1265,20 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 				return;
 			}
 
-			JComponent windowTitlePane = SubstanceRootPaneUI.this.getTitlePane();
+			JComponent windowTitlePane = SubstanceRootPaneUI.this
+					.getTitlePane();
 			// fix for issue 444 - ignore double clicks when the title pane
-			// is not showing (for example under JRootPane.NONE decoration style).
+			// is not showing (for example under JRootPane.NONE decoration
+			// style).
 			if (windowTitlePane == null)
 				return;
-			
+
 			Point convertedPoint = SwingUtilities.convertPoint(w,
 					ev.getPoint(), windowTitlePane);
 
 			int state = f.getExtendedState();
 			if ((windowTitlePane != null)
-					&& windowTitlePane.contains(
-							convertedPoint)) {
+					&& windowTitlePane.contains(convertedPoint)) {
 				if (((ev.getClickCount() % 2) == 0)
 						&& ((ev.getModifiers() & InputEvent.BUTTON1_MASK) != 0)) {
 					if (f.isResizable()) {
