@@ -48,7 +48,7 @@ import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionBorder;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.lafwidget.utils.LafConstants;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
 import org.jvnet.substance.utils.SubstanceSizeUtils;
 import org.jvnet.substance.utils.scroll.SubstanceScrollPaneBorder;
@@ -78,11 +78,6 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 	 */
 	protected long horScrollId;
 
-	/**
-	 * Background delegate.
-	 */
-	protected static SubstanceFillBackgroundDelegate bgDelegate = new SubstanceFillBackgroundDelegate();
-
 	/**
 	 * Creates new UI delegate.
 	 * 
@@ -604,7 +599,7 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
-		bgDelegate.updateIfOpaque(g, c);
+		BackgroundPaintingUtils.updateIfOpaque(g, c);
 		JScrollPane jsp = (JScrollPane) c;
 		// if (SubstanceCoreUtilities.hasOverlayProperty(jsp)) {
 		// JViewport viewport = jsp.getViewport();
@@ -669,8 +664,8 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 
 			if (TransitionLayout.isOpaque(c)) {
 				for (Component corner : corners) {
-					bgDelegate.fillAndWatermark(g, c, c.getBackground(), corner
-							.getBounds());
+					BackgroundPaintingUtils.fillAndWatermark(g, c, c
+							.getBackground(), corner.getBounds());
 				}
 			}
 		}
