@@ -36,12 +36,11 @@ import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.basic.BasicSeparatorUI;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.api.ComponentState;
-import org.jvnet.substance.api.SubstanceColorScheme;
-import org.jvnet.substance.api.SubstanceConstants.MenuGutterFillKind;
 import org.jvnet.substance.painter.utils.SeparatorPainterUtils;
-import org.jvnet.substance.utils.*;
+import org.jvnet.substance.utils.SubstanceCoreUtilities;
+import org.jvnet.substance.utils.SubstanceSizeUtils;
 import org.jvnet.substance.utils.menu.MenuUtilities;
+import org.jvnet.substance.utils.menu.SubstanceMenuBackgroundDelegate;
 
 /**
  * UI for separators in <b>Substance</b> look and feel.
@@ -62,74 +61,34 @@ public class SubstanceSeparatorUI extends BasicSeparatorUI {
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
+
+		Component parent = c.getParent();
+		if (!(parent instanceof JPopupMenu)) {
+			SeparatorPainterUtils.paintSeparator(c, g, c.getWidth(), c
+					.getHeight(), ((JSeparator) c).getOrientation());
+			return;
+		}
+
 		Graphics2D graphics = (Graphics2D) g.create();
 
-		try {
-			Component parent = c.getParent();
-			if (!(parent instanceof JPopupMenu)) {
-				SeparatorPainterUtils.paintSeparator(c, graphics, c.getWidth(),
-						c.getHeight(), ((JSeparator) c).getOrientation());
-				return;
-			}
-
-			int xOffset = MenuUtilities.getTextOffset(c, parent);
-
-			Dimension s = c.getSize();
-			int startX = 0;
-			int width = s.width;
-			if (parent.getComponentOrientation().isLeftToRight()) {
-				MenuGutterFillKind fillKind = SubstanceCoreUtilities
-						.getMenuGutterFillKind();
-				if (fillKind != MenuGutterFillKind.NONE) {
-					SubstanceColorScheme parentScheme = SubstanceColorSchemeUtilities
-							.getColorScheme(parent, ComponentState.DEFAULT);
-					Color leftColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? parentScheme
-							.getUltraLightColor()
-							: parentScheme.getLightColor();
-					Color rightColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? parentScheme
-							.getUltraLightColor()
-							: parentScheme.getLightColor();
-					GradientPaint gp = new GradientPaint(0, 0, leftColor,
-							xOffset, 0, rightColor);
-
-					graphics.setComposite(TransitionLayout.getAlphaComposite(
-							parent, 0.7f, g));
-					graphics.setPaint(gp);
-					graphics.fillRect(0, 0, xOffset - 2, c.getHeight());
-				}
-				startX = xOffset - 2;
-				width = s.width - startX;
-			} else {
-				// fix for defect 125 - support of RTL menus
-				MenuGutterFillKind fillKind = SubstanceCoreUtilities
-						.getMenuGutterFillKind();
-				if (fillKind != MenuGutterFillKind.NONE) {
-					SubstanceColorScheme parentScheme = SubstanceColorSchemeUtilities
-							.getColorScheme(parent, ComponentState.DEFAULT);
-					Color leftColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? parentScheme
-							.getLightColor()
-							: parentScheme.getUltraLightColor();
-					Color rightColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? parentScheme
-							.getLightColor()
-							: parentScheme.getUltraLightColor();
-					GradientPaint gp = new GradientPaint(xOffset, 0, leftColor,
-							s.width, 0, rightColor);
-
-					graphics.setComposite(TransitionLayout.getAlphaComposite(
-							parent, 0.7f, g));
-					graphics.setPaint(gp);
-					graphics.fillRect(xOffset - 2, 0, s.width, c.getHeight());
-				}
-				startX = 0;
-				width = xOffset - 4;
-			}
-			graphics.translate(startX, 0);
-			graphics.setComposite(TransitionLayout.getAlphaComposite(parent));
-			SeparatorPainterUtils.paintSeparator(c, graphics, width, s.height,
-					((JSeparator) c).getOrientation(), true, 2);
-		} finally {
-			graphics.dispose();
+		int xOffset = MenuUtilities.getTextOffset(c, parent);
+		SubstanceMenuBackgroundDelegate.paintBackground(graphics, c, xOffset);
+		Dimension s = c.getSize();
+		int startX = 0;
+		int width = s.width;
+		if (parent.getComponentOrientation().isLeftToRight()) {
+			startX = xOffset - 2;
+			width = s.width - startX;
+		} else {
+			startX = 0;
+			width = xOffset - 4;
 		}
+		graphics.translate(startX, 0);
+		graphics.setComposite(TransitionLayout.getAlphaComposite(parent));
+		SeparatorPainterUtils.paintSeparator(c, graphics, width, s.height,
+				((JSeparator) c).getOrientation(), true, 2);
+
+		graphics.dispose();
 	}
 
 	/*
