@@ -49,7 +49,7 @@ import org.jvnet.substance.painter.border.SubstanceBorderPainter;
 import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
 import org.jvnet.substance.painter.gradient.SubstanceGradientPainter;
 import org.jvnet.substance.painter.utils.SeparatorPainterUtils;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.*;
 import org.jvnet.substance.utils.icon.SubstanceIconFactory;
 
@@ -514,8 +514,7 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 		float alpha = SubstanceColorSchemeUtilities.getAlpha(this.slider,
 				currState);
 
-		SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.updateIfOpaque(
-				graphics, c);
+		BackgroundPaintingUtils.updateIfOpaque(graphics, c);
 
 		recalculateIfInsetsChanged();
 		recalculateIfOrientationChanged();
