@@ -149,8 +149,8 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 								.getComponentFontSize(spinner);
 						float spinnerArrowIconHeight = SubstanceSizeUtils
 								.getSpinnerArrowIconHeight(fontSize);
-//						System.out.println("OLD height : "
-//								+ spinnerArrowIconHeight);
+						// System.out.println("OLD height : "
+						// + spinnerArrowIconHeight);
 						return SubstanceImageCreator.getArrowIcon(
 								SubstanceSizeUtils
 										.getSpinnerArrowIconWidth(fontSize),
@@ -285,8 +285,9 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 							// (propagated)
 							// by Substance. In the second case we can replace
 							// that color (even though it's not a UIResource).
-							boolean canReplace = (tf.getBackground() instanceof UIResource)
-									|| (tf.getBackground() instanceof SubstanceColorResource);
+							Color tfBackground = tf.getBackground();
+							boolean canReplace = SubstanceCoreUtilities
+									.canReplaceChildBackgroundColor(tfBackground);
 							// fix for issue 387 - if spinner background
 							// is null, do nothing
 							if (spinner.getBackground() == null)
