@@ -46,6 +46,7 @@ import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicTabbedPaneUI;
 import javax.swing.text.View;
 
+import org.jvnet.lafwidget.LafWidgetUtilities;
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.lafwidget.utils.LafConstants;
@@ -54,7 +55,7 @@ import org.jvnet.substance.api.SubstanceConstants.*;
 import org.jvnet.substance.api.tabbed.*;
 import org.jvnet.substance.painter.border.SubstanceBorderPainter;
 import org.jvnet.substance.painter.gradient.SubstanceGradientPainter;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.shaper.ClassicButtonShaper;
 import org.jvnet.substance.shaper.SubstanceButtonShaper;
 import org.jvnet.substance.utils.*;
@@ -751,6 +752,10 @@ public class SubstanceTabbedPaneUI extends BasicTabbedPaneUI {
 	protected void installDefaults() {
 		super.installDefaults();
 		this.fadeModifiedIds = new HashMap<Component, Long>();
+		int selectedIndex = this.tabPane.getSelectedIndex();
+		if (selectedIndex >= 0) {
+			this.prevStateMap.put(selectedIndex, ComponentState.SELECTED);
+		}
 	}
 
 	/*
@@ -1027,7 +1032,7 @@ public class SubstanceTabbedPaneUI extends BasicTabbedPaneUI {
 			int delta = (int) (Math.floor(SubstanceSizeUtils
 					.getBorderStrokeWidth(SubstanceSizeUtils
 							.getComponentFontSize(tabPane))));
-			if (delta % 2 == 1)
+			if (delta % 2 != 0)
 				delta--;
 			int iconSize = width - delta;
 
@@ -1412,8 +1417,7 @@ public class SubstanceTabbedPaneUI extends BasicTabbedPaneUI {
 
 		// restrict the painting to the tab area only
 		Graphics2D g2d = (Graphics2D) g.create(0, 0, width, height);
-		SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.update(g2d,
-				this.tabPane, true);
+		BackgroundPaintingUtils.update(g2d, this.tabPane, true);
 		g2d.dispose();
 		super.paintTabArea(g, tabPlacement, selectedIndex);
 	}
@@ -1889,7 +1893,12 @@ public class SubstanceTabbedPaneUI extends BasicTabbedPaneUI {
 	 *            Tab area insets.
 	 */
 	public void setTabAreaInsets(Insets insets) {
+		Insets old = this.tabAreaInsets;
 		this.tabAreaInsets = insets;
+		// Fire a property change event so that the tabbed
+		// pane can revalidate itself
+		LafWidgetUtilities.firePropertyChangeEvent(this.tabPane,
+				"tabAreaInsets", old, tabAreaInsets);
 	}
 
 	/**
@@ -2235,7 +2244,7 @@ public class SubstanceTabbedPaneUI extends BasicTabbedPaneUI {
 
 		x += offset;
 		y += offset;
-		w -= 2 * offset;
+		// w -= 2 * offset;
 		h -= 2 * offset;
 
 		// Draw unbroken line if tabs are not on LEFT, OR
@@ -2463,7 +2472,7 @@ public class SubstanceTabbedPaneUI extends BasicTabbedPaneUI {
 		x += offset;
 		y += offset;
 		w -= 2 * offset;
-		h -= 2 * offset;
+		// h -= 2 * offset;
 
 		// Draw unbroken line if tabs are not on TOP, OR
 		// selected tab is not in run adjacent to content, OR
@@ -2544,6 +2553,8 @@ public class SubstanceTabbedPaneUI extends BasicTabbedPaneUI {
 	protected ComponentState getPrevTabState(int tabIndex) {
 		if (this.prevStateMap.containsKey(tabIndex))
 			return this.prevStateMap.get(tabIndex);
+		// if (getTabState(tabIndex) == ComponentState.SELECTED)
+		// return ComponentState.SELECTED;
 		return ComponentState.DEFAULT;
 	}
 
