@@ -45,7 +45,7 @@ import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.api.*;
 import org.jvnet.substance.api.renderers.SubstanceDefaultTableHeaderCellRenderer;
-import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
+import org.jvnet.substance.painter.utils.HighlightPainterUtils;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -634,7 +634,7 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		if (totalHighlightAlpha > 0.0f) {
 			g2d.setComposite(TransitionLayout.getAlphaComposite(this.header,
 					totalHighlightAlpha, g));
-			SubstanceHighlightUtils.paintHighlight(g2d, rendererPane, component, cellRect,
+			HighlightPainterUtils.paintHighlight(g2d, rendererPane, component, cellRect,
 					0.0f, null, currState, prevState, fadeCoef);
 			g2d
 					.setComposite(TransitionLayout.getAlphaComposite(
@@ -692,7 +692,7 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 				.getColorScheme(c, ColorSchemeAssociationKind.BORDER,
 						backgroundState);
 
-		SubstanceHighlightUtils.paintHighlight(g, null, c, clip, 0.0f, null,
+		HighlightPainterUtils.paintHighlight(g, null, c, clip, 0.0f, null,
 				fillScheme, fillScheme, borderScheme, borderScheme, 0.0f);
 		paint(g, c);
 	}
@@ -831,7 +831,7 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 			final ComponentState backgroundState = (header.isEnabled() && header
 					.getTable().isEnabled()) ? ComponentState.DEFAULT
 					: ComponentState.DISABLED_UNSELECTED;
-			SubstanceHighlightUtils.paintHighlight(g2d, null, this.header,
+			HighlightPainterUtils.paintHighlight(g2d, null, this.header,
 					new Rectangle(0, 0, this.getWidth(), this.getHeight()),
 					0.0f, null, backgroundState, backgroundState, 0.0f);
 
