@@ -37,8 +37,7 @@ import java.util.*;
 
 import javax.swing.*;
 import javax.swing.event.*;
-import javax.swing.plaf.ComponentUI;
-import javax.swing.plaf.UIResource;
+import javax.swing.plaf.*;
 import javax.swing.plaf.basic.BasicTableUI;
 import javax.swing.table.*;
 
@@ -47,11 +46,11 @@ import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.api.*;
 import org.jvnet.substance.api.SubstanceConstants.Side;
-import org.jvnet.substance.api.renderers.*;
+import org.jvnet.substance.api.renderers.SubstanceDefaultTableCellRenderer;
+import org.jvnet.substance.api.renderers.SubstanceDefaultTableHeaderCellRenderer;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
-import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
-import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
+import org.jvnet.substance.painter.utils.HighlightPainterUtils;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -130,6 +129,9 @@ public class SubstanceTableUI extends BasicTableUI {
 	 */
 	private Insets cellRendererInsets;
 
+	// public static final String IGNORE_COLORS =
+	// "substancelaf.internal.table.ignoreColors";
+
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -241,11 +243,11 @@ public class SubstanceTableUI extends BasicTableUI {
 		// for custom fonts and high-DPI monitors.
 		//
 		// The current solution first checks whether all the renderers
-		// come from Substance. If not, it does nothing. If they do:
-		// 1. If the table is empty, create a dummy label, compute its
-		// preferred height and apply insets.
-		// 2. Otherwise, compute preferred heights for each cell and
-		// take the biggest one.
+		// come from Substance. If not, it does nothing. If they do, it
+		// creates a dummy label, computes its preferred height and apply
+		// insets. There's no need to go over each cell and compute its
+		// preferred height - since at this moment the cell renderers
+		// *are* Substance labels.
 		boolean areAllRenderersFromSubstance = true;
 		TableColumnModel columnModel = table.getColumnModel();
 		for (int i = 0; i < columnModel.getColumnCount(); i++) {
@@ -268,23 +270,6 @@ public class SubstanceTableUI extends BasicTableUI {
 			dummy.setFont(table.getFont());
 			int rowHeight = dummy.getPreferredSize().height
 					+ rendererInsets.bottom + rendererInsets.top;
-			for (int i = 0; i < table.getRowCount(); i++) {
-				for (int j = 0; j < table.getColumnCount(); j++) {
-					TableCellRenderer renderer = table.getCellRenderer(i, j);
-					try {
-						rowHeight = Math.max(rowHeight, renderer
-								.getTableCellRendererComponent(table,
-										table.getValueAt(i, j), false, false,
-										i, j).getPreferredSize().height);
-					} catch (Throwable t) {
-						// Ignore - this happens when the renderer has a null
-						// font, such as in NetBeans palette table (in the
-						// getPreferredSize() call). Not much we can do since
-						// setting the font on the table or renderer will
-						// interfere with the application logic.
-					}
-				}
-			}
 			table.setRowHeight(rowHeight);
 		}
 		this.table.putClientProperty(SubstanceCoreUtilities.USE_HIGHLIGHT,
@@ -363,12 +348,7 @@ public class SubstanceTableUI extends BasicTableUI {
 			TableCellRenderer renderer) {
 		TableCellRenderer currRenderer = this.table.getDefaultRenderer(clazz);
 		if (currRenderer != null) {
-			boolean isSubstanceRenderer = currRenderer.getClass()
-					.isAnnotationPresent(SubstanceRenderer.class);
-			// boolean isSubstanceRenderer = (currRenderer instanceof
-			// SubstanceDefaultTableCellRenderer)
-			// || (currRenderer instanceof
-			// SubstanceDefaultTableCellRenderer.BooleanRenderer);
+			boolean isSubstanceRenderer = isSubstanceDefaultRenderer(currRenderer);
 			if (!isSubstanceRenderer)
 				return;
 		}
@@ -474,10 +454,19 @@ public class SubstanceTableUI extends BasicTableUI {
 					// propagate application-specific background color to the
 					// header.
 					Color newBackgr = (Color) evt.getNewValue();
-					if (!(newBackgr instanceof UIResource)) {
-						JTableHeader header = table.getTableHeader();
-						if (header != null) {
-							if (header.getBackground() instanceof UIResource) {
+					JTableHeader header = table.getTableHeader();
+					if (header != null) {
+						Color headerBackground = header.getBackground();
+						if (SubstanceCoreUtilities
+								.canReplaceChildBackgroundColor(headerBackground)) {
+							if (!(newBackgr instanceof UIResource)) {
+								// Issue 450 - wrap the color in
+								// SubstanceColorResource to
+								// mark that it can be replaced.
+								header
+										.setBackground(new SubstanceColorResource(
+												newBackgr));
+							} else {
 								header.setBackground(newBackgr);
 							}
 						}
@@ -1021,7 +1010,7 @@ public class SubstanceTableUI extends BasicTableUI {
 			if (totalHighlightAlpha > 0.0f) {
 				g2d.setComposite(TransitionLayout.getAlphaComposite(this.table,
 						totalHighlightAlpha, g));
-				SubstanceHighlightUtils.paintHighlight(g2d, this.rendererPane,
+				HighlightPainterUtils.paintHighlight(g2d, this.rendererPane,
 						component, highlightCellRect, highlightBorderAlpha,
 						highlightOpenSides, currHighlightScheme,
 						prevHighlightScheme, currBorderScheme,
@@ -1088,6 +1077,7 @@ public class SubstanceTableUI extends BasicTableUI {
 
 			TableCellRenderer renderer = this.table
 					.getCellRenderer(row, column);
+			boolean isSubstanceRenderer = isSubstanceDefaultRenderer(renderer);
 			Component rendererComponent = this.table.prepareRenderer(renderer,
 					row, column);
 			boolean isWatermarkBleed = this.updateInfo.toDrawWatermark;
@@ -1105,14 +1095,13 @@ public class SubstanceTableUI extends BasicTableUI {
 								highlightCellRect.height);
 					}
 				} else {
-					SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE
-							.fillAndWatermark(g2d, this.table,
-									rendererComponent.getBackground(),
-									highlightCellRect);
+					BackgroundPaintingUtils.fillAndWatermark(g2d, this.table,
+							rendererComponent.getBackground(),
+							highlightCellRect);
 				}
 			}
 
-			if (totalHighlightAlpha > 0.0f) {
+			if (isSubstanceRenderer && (totalHighlightAlpha > 0.0f)) {
 				g2d.setComposite(TransitionLayout.getAlphaComposite(this.table,
 						totalHighlightAlpha, g));
 				float extra = SubstanceSizeUtils
@@ -1134,7 +1123,7 @@ public class SubstanceTableUI extends BasicTableUI {
 				// + currTheme.getDisplayName() + ":"
 				// + prevTheme.getDisplayName() + ":"
 				// + fadeCoef);
-				SubstanceHighlightUtils.paintHighlight(g2d, this.rendererPane,
+				HighlightPainterUtils.paintHighlight(g2d, this.rendererPane,
 						rendererComponent, new Rectangle(highlightCellRect.x
 								- (int) extraWidth, highlightCellRect.y
 								- (int) extraHeight, highlightCellRect.width
@@ -1344,7 +1333,7 @@ public class SubstanceTableUI extends BasicTableUI {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected class CellRepaintCallback extends FadeTrackerAdapter {
+	protected class CellRepaintCallback extends UIThreadFadeTrackerAdapter {
 		/**
 		 * Associated table.
 		 */
@@ -1514,7 +1503,7 @@ public class SubstanceTableUI extends BasicTableUI {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected class RowRepaintCallback extends FadeTrackerAdapter {
+	protected class RowRepaintCallback extends UIThreadFadeTrackerAdapter {
 		/**
 		 * Associated table.
 		 */
@@ -1678,7 +1667,7 @@ public class SubstanceTableUI extends BasicTableUI {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected class ColumnRepaintCallback extends FadeTrackerAdapter {
+	protected class ColumnRepaintCallback extends UIThreadFadeTrackerAdapter {
 		/**
 		 * Associated table.
 		 */
@@ -2269,7 +2258,11 @@ public class SubstanceTableUI extends BasicTableUI {
 			if ((header == null) || (!header.isVisible()))
 				return;
 
-			SubstanceTableHeaderUI ui = (SubstanceTableHeaderUI) header.getUI();
+			TableHeaderUI ui = header.getUI();
+			if (!(ui instanceof SubstanceTableHeaderUI))
+				return;
+
+			SubstanceTableHeaderUI sthui = (SubstanceTableHeaderUI) ui;
 
 			// synchronized (SubstanceTableUI.this.table) {
 			int row = SubstanceTableUI.this.table.rowAtPoint(e.getPoint());
@@ -2288,7 +2281,7 @@ public class SubstanceTableUI extends BasicTableUI {
 
 				this.fadeOutTableHeader();
 				FadeTracker.getInstance().trackFadeIn(FadeKind.ROLLOVER,
-						header, column, false, ui.getCallback(column));
+						header, column, false, sthui.getCallback(column));
 				// System.out.println("Setting RO column index to " +
 				// column);
 				if (FadeConfigurationManager.getInstance().fadeAllowed(
@@ -2745,7 +2738,7 @@ public class SubstanceTableUI extends BasicTableUI {
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
-		SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.updateIfOpaque(g, c);
+		BackgroundPaintingUtils.updateIfOpaque(g, c);
 		Graphics2D g2d = (Graphics2D) g.create();
 		SubstanceStripingUtils.setup(c);
 		this.updateInfo = new UpdateOptimizationInfo();
@@ -2824,14 +2817,14 @@ public class SubstanceTableUI extends BasicTableUI {
 					ComponentState.class);
 			this.hasSelectionAnimations = _hasSelectionAnimations();
 			this.opacity = new HashMap<Component, Boolean>();
-			this.decorationAreaType = SubstanceDecorationUtilities
+			this.decorationAreaType = SubstanceLookAndFeel
 					.getDecorationType(table);
 
 			SubstanceSkin skin = SubstanceCoreUtilities.getSkin(table);
 			this.isInDecorationArea = (this.decorationAreaType != null)
 					&& skin
 							.isRegisteredAsDecorationArea(this.decorationAreaType)
-					& TransitionLayout.isOpaque(table);
+					&& TransitionLayout.isOpaque(table);
 		}
 
 		public SubstanceColorScheme getHighlightColorScheme(ComponentState state) {
@@ -2862,4 +2855,9 @@ public class SubstanceTableUI extends BasicTableUI {
 			return this.highlightAlphaMap.get(state);
 		}
 	}
+
+	private boolean isSubstanceDefaultRenderer(TableCellRenderer renderer) {
+		return (renderer instanceof SubstanceDefaultTableCellRenderer)
+				|| (renderer instanceof SubstanceDefaultTableCellRenderer.BooleanRenderer);
+	}
 }
