@@ -38,8 +38,8 @@ import javax.swing.plaf.basic.BasicToolBarUI;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
-import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
+import org.jvnet.substance.painter.utils.DecorationPainterUtils;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
 
 /**
@@ -77,7 +77,7 @@ public class SubstanceToolBarUI extends BasicToolBarUI {
 	 */
 	@Override
 	protected void uninstallDefaults() {
-		SubstanceDecorationUtilities.clearDecorationType(this.toolBar);
+		DecorationPainterUtils.clearDecorationType(this.toolBar);
 		super.uninstallDefaults();
 	}
 
@@ -91,7 +91,7 @@ public class SubstanceToolBarUI extends BasicToolBarUI {
 	public void update(Graphics g, JComponent c) {
 		boolean isOpaque = TransitionLayout.isOpaque(c);
 		if (isOpaque) {
-			SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.update(g, c, false);
+			BackgroundPaintingUtils.update(g, c, false);
 		} else {
 			super.update(g, c);
 		}
