@@ -41,7 +41,8 @@ import javax.swing.event.TreeSelectionListener;
 import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.IconUIResource;
 import javax.swing.plaf.basic.BasicTreeUI;
-import javax.swing.tree.*;
+import javax.swing.tree.TreeCellRenderer;
+import javax.swing.tree.TreePath;
 
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
@@ -49,8 +50,8 @@ import org.jvnet.lafwidget.utils.LookUtils;
 import org.jvnet.substance.api.ComponentState;
 import org.jvnet.substance.api.SubstanceColorScheme;
 import org.jvnet.substance.api.renderers.SubstanceDefaultTreeCellRenderer;
-import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
+import org.jvnet.substance.painter.utils.HighlightPainterUtils;
 import org.jvnet.substance.utils.*;
 import org.jvnet.substance.utils.icon.SubstanceIconFactory;
 
@@ -70,11 +71,6 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	 */
 	protected TreePathId currRolloverPathId;
 
-	/**
-	 * Delegate for painting the background of list rows.
-	 */
-	private static SubstanceFillBackgroundDelegate backgroundDelegate = new SubstanceFillBackgroundDelegate();
-
 	/**
 	 * Listener that listens to changes on tree properties.
 	 */
@@ -260,9 +256,9 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		g2d.setComposite(TransitionLayout.getAlphaComposite(this.tree,
 				currFactor));
 
-		Color background = renderer.getBackground();
-		if (background == null)
-			background = tree.getBackground();
+		// Color background = renderer.getBackground();
+		// if (background == null)
+		// background = tree.getBackground();
 
 		ComponentState prevState = this.getPrevPathState(pathId);
 		ComponentState currState = this.getPathState(pathId);
@@ -296,16 +292,14 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		// + alphaForPrevBackground + "]:" + currTheme.getDisplayName()
 		// + "[" + alphaForCurrBackground + "]");
 
-		// The DefaultTreeCellRenderer overrides the isOpaque method
-		// so that there is no point in trying to make it non-opaque.
-		// Fix for defect 181.
-		boolean canHaveSubstanceEffects = !(renderer instanceof DefaultTreeCellRenderer);
-		if (canHaveSubstanceEffects && (totalAlpha > 0.0f)) {
+		// At this point the renderer is an instance of
+		// SubstanceDefaultTreeCellRenderer
+		if (totalAlpha > 0.0f) {
 			g2d.setComposite(TransitionLayout.getAlphaComposite(this.tree,
 					currFactor * totalAlpha, g));
 			// Fix for defect 180 - painting the
 			// highlight beneath the entire row
-			SubstanceHighlightUtils
+			HighlightPainterUtils
 					.paintHighlight(g2d, this.rendererPane, renderer,
 							new Rectangle(this.tree.getInsets().left, bounds.y,
 									this.tree.getWidth()
@@ -318,34 +312,25 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		}
 
 		// System.out.println("Painting row " + row);
-		if (renderer instanceof JComponent) {
-			// Play with opacity to make our own gradient background
-			// on selected elements to show.
-			JComponent jRenderer = (JComponent) renderer;
-			boolean newOpaque = !this.tree.isRowSelected(row);
-			if (SubstanceCoreUtilities.toDrawWatermark(this.tree))
-				newOpaque = false;
+		// Play with opacity to make our own gradient background
+		// on selected elements to show - safe to cast and set opacity
+		// since at this point the renderer can only by the
+		// SubstanceDefaultTreeCellRenderer
+		JComponent jRenderer = (JComponent) renderer;
+		boolean newOpaque = !this.tree.isRowSelected(row);
+		if (SubstanceCoreUtilities.toDrawWatermark(this.tree))
+			newOpaque = false;
 
-			// fix for defect 181 - no highlight on renderers
-			// that extend DefaultTreeCellRenderer
-			newOpaque = newOpaque && canHaveSubstanceEffects;
-
-			Map<Component, Boolean> opacity = new HashMap<Component, Boolean>();
-			if (!newOpaque)
-				SubstanceCoreUtilities.makeNonOpaque(jRenderer, opacity);
-			this.rendererPane.paintComponent(g2d, renderer, this.tree,
-					bounds.x, bounds.y, Math.max(this.tree.getWidth()
-							- this.tree.getInsets().right
-							- this.tree.getInsets().left - bounds.x,
-							bounds.width), bounds.height, true);
-			if (!newOpaque)
-				SubstanceCoreUtilities.restoreOpaque(jRenderer, opacity);
-		} else {
-			this.rendererPane.paintComponent(g2d, renderer, this.tree,
-					bounds.x, bounds.y, Math
-							.max(clipBounds.width, bounds.width),
-					bounds.height, true);
-		}
+		Map<Component, Boolean> opacity = new HashMap<Component, Boolean>();
+		if (!newOpaque)
+			SubstanceCoreUtilities.makeNonOpaque(jRenderer, opacity);
+		this.rendererPane.paintComponent(g2d, renderer, this.tree, bounds.x,
+				bounds.y, Math.max(this.tree.getWidth()
+						- this.tree.getInsets().right
+						- this.tree.getInsets().left - bounds.x, bounds.width),
+				bounds.height, true);
+		if (!newOpaque)
+			SubstanceCoreUtilities.restoreOpaque(jRenderer, opacity);
 
 		// Paint the expand control now after the row background has been
 		// overlayed by the highlight background on selected and rolled over
@@ -1015,7 +1000,7 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
-		SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.updateIfOpaque(g, c);
+		BackgroundPaintingUtils.updateIfOpaque(g, c);
 
 		// Should never happen if installed for a UI
 		if (treeState == null) {
@@ -1081,15 +1066,15 @@ public class SubstanceTreeUI extends BasicTreeUI {
 								paintBounds.width, bounds.height);
 					} else {
 						if (this.tree.getComponentOrientation().isLeftToRight()) {
-							backgroundDelegate.fillAndWatermark(g2d, this.tree,
-									background, new Rectangle(paintBounds.x,
-											bounds.y, paintBounds.width,
-											bounds.height));
+							BackgroundPaintingUtils.fillAndWatermark(g2d,
+									this.tree, background, new Rectangle(
+											paintBounds.x, bounds.y,
+											paintBounds.width, bounds.height));
 						} else {
-							backgroundDelegate.fillAndWatermark(g2d, this.tree,
-									background, new Rectangle(paintBounds.x,
-											bounds.y, paintBounds.width,
-											bounds.height));
+							BackgroundPaintingUtils.fillAndWatermark(g2d,
+									this.tree, background, new Rectangle(
+											paintBounds.x, bounds.y,
+											paintBounds.width, bounds.height));
 						}
 					}
 					if ((bounds.y + bounds.height) >= endY)
