@@ -162,7 +162,7 @@ public enum ComponentState {
 	 * Active fade kinds for this state. For example, {@link #ROLLOVER_SELECTED}
 	 * contains {@link FadeKind#ROLLOVER} and {@link FadeKind#SELECTION}.
 	 */
-	private FadeKind[] activeKinds;
+	private transient FadeKind[] activeKinds;
 
 	/**
 	 * Simple constructor.
@@ -309,6 +309,14 @@ public enum ComponentState {
 				JButton jb = (JButton) component;
 				if (jb.isDefaultButton()) {
 					if (model.isEnabled()) {
+						// check for rollover
+						if (jb.isRolloverEnabled()
+								&& jb.getModel().isRollover()) {
+							if (model.isSelected())
+								return ROLLOVER_SELECTED;
+							else
+								return ROLLOVER_UNSELECTED;
+						}
 						if ((!model.isPressed()) && (!model.isArmed()))
 							return ACTIVE;
 					} else
