@@ -88,11 +88,11 @@ public interface SchemeDerivedColors {
 	public Color getBackgroundFillColor();
 
 	/**
-	 * Returns the light background fill color for <code>this</code> scheme.
+	 * Returns the text background fill color for <code>this</code> scheme.
 	 * 
-	 * @return The light background fill color for <code>this</code> scheme.
+	 * @return The text background fill color for <code>this</code> scheme.
 	 */
-	public Color getLightBackgroundFillColor();
+	public Color getTextBackgroundFillColor();
 
 	/**
 	 * Returns the focus ring color for <code>this</code> scheme.
