@@ -213,8 +213,8 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 	 * the component state is not <code>null</code>, or a global highlight color
 	 * scheme otherwise.
 	 * 
-	 * @param stateHighlightScheme
-	 *            Highlight color scheme for the specified component state.
+	 * @param highlightScheme
+	 *            Highlight color scheme for the specified component states.
 	 * @param alpha
 	 *            Alpha channel for the highlight color scheme.
 	 * @param states
@@ -222,8 +222,12 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 	 *            scheme will be applied for all states left unspecified.
 	 */
 	public void registerHighlightColorScheme(
-			SubstanceColorScheme stateHighlightScheme, float alpha,
+			SubstanceColorScheme highlightScheme, float alpha,
 			ComponentState... states) {
+		if (highlightScheme == null) {
+			throw new IllegalArgumentException("Cannot pass null color scheme");
+		}
+
 		if ((states == null) || (states.length == 0)) {
 			for (ComponentState state : ComponentState.values()) {
 				if (!state.isKindActive(FadeKind.ENABLE))
@@ -235,14 +239,14 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 						.containsKey(state))
 					this.colorSchemeMap.get(
 							ColorSchemeAssociationKind.HIGHLIGHT).put(state,
-							stateHighlightScheme);
+							highlightScheme);
 				if (!this.stateHighlightSchemeAlphaMap.containsKey(state))
 					this.stateHighlightSchemeAlphaMap.put(state, alpha);
 			}
 		} else {
 			for (ComponentState state : states) {
 				this.colorSchemeMap.get(ColorSchemeAssociationKind.HIGHLIGHT)
-						.put(state, stateHighlightScheme);
+						.put(state, highlightScheme);
 				this.stateHighlightSchemeAlphaMap.put(state, alpha);
 			}
 		}
@@ -259,8 +263,7 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 	 * @return The color scheme of the component in the specified component
 	 *         state.
 	 */
-	public SubstanceColorScheme getColorScheme(Component comp,
-			ComponentState componentState) {
+	public SubstanceColorScheme getColorScheme(ComponentState componentState) {
 		SubstanceColorScheme registered = this.colorSchemeMap.get(
 				ColorSchemeAssociationKind.FILL).get(componentState);
 		if (registered != null)
@@ -304,7 +307,7 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 	@Deprecated
 	public SubstanceColorScheme getHighlightColorScheme(Component comp,
 			ComponentState componentState) {
-		return this.getColorScheme(comp, ColorSchemeAssociationKind.HIGHLIGHT,
+		return this.getColorScheme(ColorSchemeAssociationKind.HIGHLIGHT,
 				componentState);
 		// SubstanceColorScheme registered = this.colorSchemeMap.get(
 		// ColorSchemeAssociationKind.HIGHLIGHT).get(componentState);
@@ -387,8 +390,8 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 	 * <li>
 	 * <code>associationKind</code>={@link ColorSchemeAssociationKind#FILL}</li>
 	 * <li>
-	 * <code>states</code>={@link ComponentState#ROLLOVER_SELECTED}, {@link ComponentState#ROLLOVER_UNSELECTED}
-	 * </li>
+	 * <code>states</code>={@link ComponentState#ROLLOVER_SELECTED},
+	 * {@link ComponentState#ROLLOVER_UNSELECTED}</li>
 	 * </ul>
 	 * 
 	 * @param scheme
@@ -404,6 +407,9 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 	public void registerColorScheme(SubstanceColorScheme scheme,
 			ColorSchemeAssociationKind associationKind,
 			ComponentState... states) {
+		if (scheme == null) {
+			throw new IllegalArgumentException("Cannot pass null color scheme");
+		}
 
 		if ((states == null) || (states.length == 0)) {
 			for (ComponentState state : ComponentState.values()) {
@@ -433,11 +439,11 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 	 * @see #registerColorScheme(SubstanceColorScheme, ComponentState...)
 	 * @since version 5.1
 	 */
-	public SubstanceColorScheme getColorScheme(Component comp,
+	public SubstanceColorScheme getColorScheme(
 			ColorSchemeAssociationKind associationKind,
 			ComponentState componentState) {
 		if (associationKind == ColorSchemeAssociationKind.FILL)
-			return this.getColorScheme(comp, componentState);
+			return this.getColorScheme(componentState);
 
 		SubstanceColorScheme registered = this.colorSchemeMap.get(
 				associationKind).get(componentState);
@@ -448,7 +454,7 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 		if (fallback == null)
 			return null;
 
-		return getColorScheme(comp, fallback, componentState);
+		return getColorScheme(fallback, componentState);
 	}
 
 	/**
@@ -469,20 +475,8 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 	@Deprecated
 	public void registerBorderColorScheme(SubstanceColorScheme scheme,
 			ComponentState... states) {
-		if ((states == null) || (states.length == 0)) {
-			for (ComponentState state : ComponentState.values()) {
-				if (this.colorSchemeMap.get(ColorSchemeAssociationKind.BORDER)
-						.containsKey(state))
-					continue;
-				this.colorSchemeMap.get(ColorSchemeAssociationKind.BORDER).put(
-						state, scheme);
-			}
-		} else {
-			for (ComponentState state : states) {
-				this.colorSchemeMap.get(ColorSchemeAssociationKind.BORDER).put(
-						state, scheme);
-			}
-		}
+		this.registerColorScheme(scheme, ColorSchemeAssociationKind.BORDER,
+				states);
 	}
 
 	/**
@@ -501,7 +495,7 @@ public class SubstanceColorSchemeBundle implements Cloneable {
 	@Deprecated
 	public SubstanceColorScheme getBorderColorScheme(Component comp,
 			ComponentState componentState) {
-		return this.getColorScheme(comp, ColorSchemeAssociationKind.BORDER,
+		return this.getColorScheme(ColorSchemeAssociationKind.BORDER,
 				componentState);
 		// SubstanceColorScheme registered = this.colorSchemeMap.get(
 		// ColorSchemeAssociationKind.BORDER).get(componentState);
