@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
+ * Copyright (c) 2005-2009 Substance Kirill Grouchnikov. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without 
  * modification, are permitted provided that the following conditions are met:
@@ -38,7 +38,6 @@ import org.jvnet.lafwidget.animation.FadeKind;
 import org.jvnet.lafwidget.animation.FadeTracker;
 import org.jvnet.substance.SubstanceLookAndFeel;
 import org.jvnet.substance.colorscheme.*;
-import org.jvnet.substance.painter.border.InnerDelegateBorderPainter;
 import org.jvnet.substance.shaper.SubstanceButtonShaper;
 import org.jvnet.substance.utils.*;
 
@@ -209,8 +208,9 @@ public class SubstanceConstants {
 							BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND, 0.0f,
 							new float[] { dashLength, dashGap }, dashPhase));
 
-					GeneralPath contour = shaper.getButtonOutline(
-							(AbstractButton) mainComp, null);
+					Shape contour = shaper.getButtonOutline(
+							(AbstractButton) mainComp, null, mainComp
+									.getWidth(), mainComp.getHeight(), false);
 					graphics.draw(contour);
 					// }
 				} else {
@@ -295,8 +295,7 @@ public class SubstanceConstants {
 						if (fadeTracker.isTracked(focusedComp,
 								FadeKind.FOCUS_LOOP_ANIMATION)) {
 							dashPhase = (dashLength + dashGap)
-									* (1.0f - fadeTracker.getFade(
-											focusedComp,
+									* (1.0f - fadeTracker.getFade(focusedComp,
 											FadeKind.FOCUS_LOOP_ANIMATION));
 						}
 						float focusStrokeWidth = SubstanceSizeUtils
@@ -309,8 +308,10 @@ public class SubstanceConstants {
 						Insets insets = new Insets(insetsPix, insetsPix,
 								insetsPix, insetsPix);
 
-						GeneralPath contour = shaper.getButtonOutline(
-								(AbstractButton) mainComp, insets);
+						Shape contour = shaper.getButtonOutline(
+								(AbstractButton) mainComp, insets, mainComp
+										.getWidth(), mainComp.getHeight(),
+								false);
 						graphics.draw(contour);
 					}
 				} else {
@@ -385,8 +386,10 @@ public class SubstanceConstants {
 						Insets insets = new Insets(extraPadding, extraPadding,
 								extraPadding, extraPadding);
 
-						GeneralPath contour = shaper.getButtonOutline(
-								(AbstractButton) mainComp, insets);
+						Shape contour = shaper.getButtonOutline(
+								(AbstractButton) mainComp, insets, mainComp
+										.getWidth(), mainComp.getHeight(),
+								false);
 						graphics.draw(contour);
 					}
 				} else {
@@ -490,21 +493,22 @@ public class SubstanceConstants {
 		 * Paints the focus ring on the specified component.
 		 * 
 		 * @param mainComp
-		 * 		The main component for the focus painting.
+		 *            The main component for the focus painting.
 		 * @param focusedComp
-		 * 		The actual component that has the focus. For example, the main
-		 * 		component can be a {@link JSpinner}, while the focused component
-		 * 		is a text field inside the the spinner editor.
+		 *            The actual component that has the focus. For example, the
+		 *            main component can be a {@link JSpinner}, while the
+		 *            focused component is a text field inside the the spinner
+		 *            editor.
 		 * @param graphics
-		 * 		Graphics context.
+		 *            Graphics context.
 		 * @param focusShape
-		 * 		Focus shape. May be <code>null</code> - in this case, the bounds
-		 * 		of <code>mainComp</code> will be used.
+		 *            Focus shape. May be <code>null</code> - in this case, the
+		 *            bounds of <code>mainComp</code> will be used.
 		 * @param textRect
-		 * 		Text rectangle (if relevant).
+		 *            Text rectangle (if relevant).
 		 * @param extraPadding
-		 * 		Extra padding between the component bounds and the focus ring
-		 * 		painting.
+		 *            Extra padding between the component bounds and the focus
+		 *            ring painting.
 		 */
 		public abstract void paintFocus(Component mainComp,
 				Component focusedComp, Graphics2D graphics, Shape focusShape,
@@ -514,11 +518,11 @@ public class SubstanceConstants {
 		 * Paints the focus ring on the specified component.
 		 * 
 		 * @param comp
-		 * 		Component.
+		 *            Component.
 		 * @param graphics
-		 * 		Graphics context.
+		 *            Graphics context.
 		 * @param textRect
-		 * 		Text rectangle (if relevant).
+		 *            Text rectangle (if relevant).
 		 */
 		public void paintFocus(Component comp, Graphics2D graphics,
 				Rectangle textRect) {
@@ -529,7 +533,7 @@ public class SubstanceConstants {
 		 * Returns DPI-aware dash length for dash-based focus painting.
 		 * 
 		 * @param fontSize
-		 * 		The font size of the component for focus painting.
+		 *            The font size of the component for focus painting.
 		 * @return DPI-aware dash length for dash-based focus painting.
 		 */
 		protected static float getDashLength(int fontSize) {
@@ -540,7 +544,7 @@ public class SubstanceConstants {
 		 * Returns DPI-aware dash gap for dash-based focus painting.
 		 * 
 		 * @param fontSize
-		 * 		The font size of the component for focus painting.
+		 *            The font size of the component for focus painting.
 		 * @return DPI-aware dash gap for dash-based focus painting.
 		 */
 		protected static float getDashGap(int fontSize) {
@@ -553,7 +557,7 @@ public class SubstanceConstants {
 		 * generally static.
 		 * 
 		 * @return <code>true</code> if <code>this</code> focus kind can be
-		 * 	animated, <code>false</code> otherwise.
+		 *         animated, <code>false</code> otherwise.
 		 */
 		public boolean isAnimated() {
 			return false;
@@ -564,9 +568,8 @@ public class SubstanceConstants {
 	 * Enumerates of image-based watermarks kinds.
 	 * 
 	 * @author Kirill Grouchnikov
-	 * @see
-	 * 	SubstanceLookAndFeel#setImageWatermarkKind(org.jvnet.substance.utils.
-	 * 	SubstanceConstants.ImageWatermarkKind)
+	 * @see SubstanceLookAndFeel#setImageWatermarkKind(org.jvnet.substance.utils.
+	 *      SubstanceConstants.ImageWatermarkKind)
 	 * @see SubstanceLookAndFeel#getImageWatermarkKind()
 	 */
 	public enum ImageWatermarkKind {
@@ -710,18 +713,19 @@ public class SubstanceConstants {
 	}
 
 	/**
-	 * Color shift kind for shifting themes in inner border painters. See
-	 * {@link InnerDelegateBorderPainter} for usage details.
+	 * Color shift kind for shifting themes in inner border painters.
 	 * 
 	 * @author Kirill Grouchnikov
+	 * @deprecated Will be removed in version 6.0
 	 */
+	@Deprecated
 	public enum ColorShiftKind {
 		/**
 		 * Instructs the inner border painter to shade the border theme for the
 		 * inner part of the border.
 		 * 
 		 * @see ShadeColorScheme
-		 * @see SubstanceTheme#shade(double)
+		 * @see SubstanceColorScheme#shade(double)
 		 */
 		SHADE,
 
@@ -730,7 +734,7 @@ public class SubstanceConstants {
 		 * inner part of the border.
 		 * 
 		 * @see TintColorScheme
-		 * @see SubstanceTheme#tint(double)
+		 * @see SubstanceColorScheme#tint(double)
 		 */
 		TINT,
 
@@ -739,7 +743,7 @@ public class SubstanceConstants {
 		 * inner part of the border.
 		 * 
 		 * @see ToneColorScheme
-		 * @see SubstanceTheme#tone(double)
+		 * @see SubstanceColorScheme#tone(double)
 		 */
 		TONE,
 
@@ -782,9 +786,9 @@ public class SubstanceConstants {
 	}
 
 	/**
-	 * Enumerates configurable Substance-specific widget types for {@link
-	 * SubstanceLookAndFeel#setWidgetVisible(javax.swing.JRootPane, boolean,
-	 * SubstanceWidgetType...)} API.
+	 * Enumerates configurable Substance-specific widget types for
+	 * {@link SubstanceLookAndFeel#setWidgetVisible(javax.swing.JRootPane, boolean, SubstanceWidgetType...)}
+	 * API.
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
