@@ -162,6 +162,14 @@ public class SubstanceDefaultTableCellRenderer extends DefaultTableCellRenderer
 		protected final void paintComponent(Graphics g) {
 			super.paintComponent(g);
 		}
+
+		@Override
+		protected final void paintBorder(Graphics g) {
+		}
+
+		@Override
+		public final void paintComponents(Graphics g) {
+		}
 	}
 
 	/**
@@ -316,7 +324,8 @@ public class SubstanceDefaultTableCellRenderer extends DefaultTableCellRenderer
 			}
 		}
 
-		// SubstanceColorScheme scheme = (state == ComponentState.DEFAULT) ? ui
+		// SubstanceColorScheme scheme = (state == ComponentState.DEFAULT) ?
+		// ui
 		// .getDefaultColorScheme() : SubstanceColorSchemeUtilities
 		// .getColorScheme(table, state);
 		if (scheme == null)
@@ -393,4 +402,12 @@ public class SubstanceDefaultTableCellRenderer extends DefaultTableCellRenderer
 	protected final void paintComponent(Graphics g) {
 		super.paintComponent(g);
 	}
+
+	@Override
+	protected final void paintBorder(Graphics g) {
+	}
+
+	@Override
+	public final void paintComponents(Graphics g) {
+	}
 }
