@@ -322,8 +322,7 @@ public class SubstanceDefaultTreeCellRenderer extends JLabel implements
 	@Override
 	protected void firePropertyChange(String propertyName, Object oldValue,
 			Object newValue) {
-		// Strings get interned...
-		if (propertyName == "text")
+		if ("text".equals(propertyName))
 			super.firePropertyChange(propertyName, oldValue, newValue);
 	}
 
