@@ -33,6 +33,7 @@ import java.awt.Color;
 
 import org.jvnet.substance.api.SchemeDerivedColors;
 import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.utils.SubstanceColorUtilities;
 
 /**
  * Base class for <b>Substance</b> color schemes.
@@ -254,6 +255,7 @@ public abstract class BaseColorScheme implements SubstanceColorScheme {
 	 * 
 	 * @see org.jvnet.substance.api.SchemeDerivedColors#getWatermarkStampColor()
 	 */
+	@Override
 	public Color getWatermarkStampColor() {
 		return derivedColorsResolver.getWatermarkStampColor();
 	}
@@ -262,10 +264,11 @@ public abstract class BaseColorScheme implements SubstanceColorScheme {
 	 * (non-Javadoc)
 	 * 
 	 * @see
-	 * org.jvnet.substance.api.SchemeDerivedColors#getLightBackgroundFillColor()
+	 * org.jvnet.substance.api.SchemeDerivedColors#getTextBackgroundFillColor()
 	 */
-	public Color getLightBackgroundFillColor() {
-		return derivedColorsResolver.getLightBackgroundFillColor();
+	@Override
+	public Color getTextBackgroundFillColor() {
+		return derivedColorsResolver.getTextBackgroundFillColor();
 	}
 
 	/*
@@ -286,6 +289,21 @@ public abstract class BaseColorScheme implements SubstanceColorScheme {
 	 */
 	@Override
 	public String toString() {
-		return this.getDisplayName();
+		return this.getDisplayName() + " {\n    kind="
+				+ (this.isDark() ? "Dark" : "Light") + "\n    colorUltraLight="
+				+ SubstanceColorUtilities.encode(this.getUltraLightColor())
+				+ "\n    colorExtraLight="
+				+ SubstanceColorUtilities.encode(this.getExtraLightColor())
+				+ "\n    colorLight="
+				+ SubstanceColorUtilities.encode(this.getLightColor())
+				+ "\n    colorMid="
+				+ SubstanceColorUtilities.encode(this.getMidColor())
+				+ "\n    colorDark="
+				+ SubstanceColorUtilities.encode(this.getDarkColor())
+				+ "\n    colorUltraDark="
+				+ SubstanceColorUtilities.encode(this.getUltraDarkColor())
+				+ "\n    colorForeground="
+				+ SubstanceColorUtilities.encode(this.getForegroundColor())
+				+ "\n}";
 	}
 }
