@@ -158,10 +158,10 @@ public class DerivedColorsResolverLight implements SchemeDerivedColors {
 	 * (non-Javadoc)
 	 * 
 	 * @see
-	 * org.jvnet.substance.api.SchemeDerivedColors#getLightBackgroundFillColor()
+	 * org.jvnet.substance.api.SchemeDerivedColors#getTextBackgroundFillColor()
 	 */
 	@Override
-	public Color getLightBackgroundFillColor() {
+	public Color getTextBackgroundFillColor() {
 		return SubstanceColorUtilities.getInterpolatedColor(this.scheme
 				.getUltraLightColor(), this.scheme.getExtraLightColor(), 0.8);
 	}
