@@ -107,7 +107,7 @@ public class ShiftColorScheme extends BaseColorScheme {
 	/**
 	 * Cache of shifted schemes.
 	 */
-	protected static LazyResettableHashMap<SubstanceColorScheme> shiftedCache = new LazyResettableHashMap<SubstanceColorScheme>(
+	protected final static LazyResettableHashMap<SubstanceColorScheme> shiftedCache = new LazyResettableHashMap<SubstanceColorScheme>(
 			"ShiftColorScheme.shiftedSchemes");
 
 	/**
