@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
+ * Copyright (c) 2005-2009 Substance Kirill Grouchnikov. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -75,7 +75,7 @@ public class SubstanceFontUtilities {
 		 * @return Substance-specific font resource.
 		 */
 		private FontUIResource getSubstanceFont(FontUIResource systemFont) {
-			return this.getSubstanceFont(systemFont, false, 0);
+			return systemFont;
 		}
 
 		/**
@@ -100,8 +100,11 @@ public class SubstanceFontUtilities {
 				else
 					newStyle = Font.BOLD;
 			}
-			return new FontUIResource(systemFont.getFontName(), newStyle,
-					systemFont.getSize() + extraFontSize);
+			return new FontUIResource(systemFont.deriveFont(
+					(float) (systemFont.getSize() + extraFontSize)).deriveFont(
+					newStyle));
+			// return new FontUIResource(systemFont.getFontName(), newStyle,
+			// systemFont.getSize() + extraFontSize);
 		}
 
 		/*
@@ -170,6 +173,7 @@ public class SubstanceFontUtilities {
 		// boolean toWrapPolicy = !LookUtils.IS_OS_MAC;
 		FontPolicy defaultPolicy = FontPolicies.getDefaultPlasticPolicy();
 		boolean isKDE = false;
+		// boolean isGnome = false;
 		try {
 			isKDE = DefaultKDEFontPolicy.isKDERunning();
 		} catch (Throwable t) {
@@ -196,6 +200,7 @@ public class SubstanceFontUtilities {
 						if ("gnome".equals(desktop)) {
 							// new in version 4.1
 							defaultPolicy = new DefaultGnomeFontPolicy();
+							// isGnome = true;
 						}
 					} catch (Throwable t) {
 						// security access - too bad for Gnome desktops.
@@ -210,7 +215,7 @@ public class SubstanceFontUtilities {
 		SubstanceSizeUtils.resetPointsToPixelsRatio(defaultPolicy);
 		final FontPolicy fontPolicy = FontPolicies
 				.customSettingsPolicy(defaultPolicy);
-		if (LookUtils.IS_OS_MAC || isKDE)
+		if (LookUtils.IS_OS_MAC || isKDE)// || isGnome)
 			return fontPolicy;
 		return new FontPolicy() {
 			public FontSet getFontSet(String lafName, UIDefaults table) {
