@@ -79,7 +79,7 @@ public abstract class InnerDelegateBorderPainter implements
 	/**
 	 * Map of shifted color schemes (to speed up the subsequent lookups).
 	 */
-	protected static LazyResettableHashMap<SubstanceColorScheme> shiftMap = new LazyResettableHashMap<SubstanceColorScheme>(
+	protected final static LazyResettableHashMap<SubstanceColorScheme> shiftMap = new LazyResettableHashMap<SubstanceColorScheme>(
 			"InnerDelegateBorderPainter");
 
 	/**
