@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
+ * Copyright (c) 2005-2009 Substance Kirill Grouchnikov. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without 
  * modification, are permitted provided that the following conditions are met:
@@ -60,15 +60,15 @@ public class Glass3DDecorationPainter implements SubstanceDecorationPainter {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.painter.decoration.SubstanceDecorationPainter#paintDecorationArea(java.awt.Graphics2D,
-	 *      java.awt.Component,
-	 *      org.jvnet.substance.painter.decoration.DecorationAreaType, int, int,
-	 *      org.jvnet.substance.skin.SubstanceSkin)
+	 * @seeorg.jvnet.substance.painter.decoration.SubstanceDecorationPainter#
+	 * paintDecorationArea(java.awt.Graphics2D, java.awt.Component,
+	 * org.jvnet.substance.painter.decoration.DecorationAreaType, int, int,
+	 * org.jvnet.substance.skin.SubstanceSkin)
 	 */
 	public void paintDecorationArea(Graphics2D graphics, Component comp,
 			DecorationAreaType decorationAreaType, int width, int height,
 			SubstanceSkin skin) {
-		SubstanceImageCreator.paintRectangularBackground(graphics, 0, 0, width,
+		SubstanceImageCreator.paintRectangularBackground(comp, graphics, 0, 0, width,
 				height, skin.getBackgroundColorScheme(decorationAreaType),
 				0.0f, false);
 	}
