@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
+ * Copyright (c) 2005-2009 Substance Kirill Grouchnikov. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without 
  * modification, are permitted provided that the following conditions are met:
@@ -51,8 +51,8 @@ public class MarbleNoiseDecorationPainter extends ImageWrapperDecorationPainter
 	public MarbleNoiseDecorationPainter() {
 		super();
 		this.originalTile = NoiseFactory.getNoiseImage(
-				SubstanceColorSchemeUtilities.METALLIC_SKIN, 400, 400, 0.8, 0.8,
-				false, null, true, true);
+				SubstanceColorSchemeUtilities.METALLIC_SKIN, 400, 400, 0.8,
+				0.8, false, null, true, true);
 	}
 
 	/*
