@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
+ * Copyright (c) 2005-2009 Substance Kirill Grouchnikov. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without 
  * modification, are permitted provided that the following conditions are met:
@@ -38,8 +38,8 @@ import org.jvnet.substance.api.SubstanceConstants.Side;
 import org.jvnet.substance.api.trait.SubstanceTrait;
 
 /**
- * Highlight painter interface for <b>Substance</b> look and feel. This class
- * is part of officially supported API.<br>
+ * Highlight painter interface for <b>Substance</b> look and feel. This class is
+ * part of officially supported API.<br>
  * <br>
  * 
  * @author Kirill Grouchnikov
@@ -66,11 +66,15 @@ public interface SubstanceHighlightPainter extends SubstanceTrait {
 	 *            The first color scheme.
 	 * @param colorScheme2
 	 *            The second color scheme.
+	 * @param borderColorScheme1
+	 *            The first border color scheme.
+	 * @param borderColorScheme2
+	 *            The second border color scheme.
 	 * @param cyclePos
 	 *            Cycle position. Is used for rollover and selection animations.
-	 *            Must be in 0..10 range.
+	 *            Must be in 0..1 range.
 	 */
 	public void paintHighlight(Graphics2D graphics, Component comp, int width,
-			int height, float borderAlpha, Set<Side> openSides,
-			SubstanceColorScheme colorScheme1, SubstanceColorScheme colorScheme2, float cyclePos);
+			int height, Set<Side> openSides, SubstanceColorScheme colorScheme1,
+			SubstanceColorScheme colorScheme2, float cyclePos);
 }
