@@ -36,14 +36,14 @@ import java.util.Collection;
 import javax.swing.JSeparator;
 import javax.swing.SwingConstants;
 
+import org.jvnet.substance.SubstanceLookAndFeel;
 import org.jvnet.substance.api.*;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
-import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
 import org.jvnet.substance.utils.*;
 
 /**
- * Collection of various utility methods for painting separators. This class is
- * for internal use only.
+ * Contains utility methods related to painting separators. This class is for
+ * internal use only.
  * 
  * @author Kirill Grouchnikov
  */
@@ -68,7 +68,7 @@ public class SeparatorPainterUtils {
 	 * @param orientation
 	 *            Separator orientation.
 	 */
-	public static void paintSeparator(Component c, Graphics2D graphics,
+	public static void paintSeparator(Component c, Graphics graphics,
 			int width, int height, int orientation) {
 		paintSeparator(c, graphics, width, height, orientation, true, 10);
 	}
@@ -95,7 +95,7 @@ public class SeparatorPainterUtils {
 	 *            separator. The ramp portions are located on separator ends and
 	 *            allow providing a faded appearance on those ends.
 	 */
-	public static void paintSeparator(Component c, Graphics2D graphics,
+	public static void paintSeparator(Component c, Graphics graphics,
 			int width, int height, int orientation, boolean hasShadow,
 			int maxGradLength) {
 		paintSeparator(c, graphics, width, height, orientation, hasShadow,
@@ -107,7 +107,7 @@ public class SeparatorPainterUtils {
 	 * 
 	 * @param c
 	 *            Component.
-	 * @param g2d
+	 * @param g
 	 *            Graphics context.
 	 * @param width
 	 *            Separator width.
@@ -131,16 +131,15 @@ public class SeparatorPainterUtils {
 	 *            If <code>true</code>, the fade sequences will always use alpha
 	 *            colors. This may affect the performance.
 	 */
-	public static void paintSeparator(Component c, Graphics2D g2d, int width,
+	public static void paintSeparator(Component c, Graphics g, int width,
 			int height, int orientation, boolean hasShadow,
 			int maxGradLengthStart, int maxGradLengthEnd,
 			boolean toEnforceAlphaColors) {
 		SubstanceColorScheme compScheme = SubstanceColorSchemeUtilities
 				.getColorScheme(c, ColorSchemeAssociationKind.SEPARATOR,
 						ComponentState.DEFAULT);
-		paintSeparator(c, g2d, compScheme, width, height, orientation,
-				hasShadow, maxGradLengthStart, maxGradLengthEnd,
-				toEnforceAlphaColors);
+		paintSeparator(c, g, compScheme, width, height, orientation, hasShadow,
+				maxGradLengthStart, maxGradLengthEnd, toEnforceAlphaColors);
 	}
 
 	/**
@@ -148,7 +147,7 @@ public class SeparatorPainterUtils {
 	 * 
 	 * @param c
 	 *            Component.
-	 * @param g2d
+	 * @param g
 	 *            Graphics context.
 	 * @param scheme
 	 *            Color scheme.
@@ -174,20 +173,20 @@ public class SeparatorPainterUtils {
 	 *            If <code>true</code>, the fade sequences will always use alpha
 	 *            colors. This may affect the performance.
 	 */
-	public static void paintSeparator(Component c, Graphics2D g2d,
+	public static void paintSeparator(Component c, Graphics g,
 			SubstanceColorScheme scheme, int width, int height,
 			int orientation, boolean hasShadow, int maxGradLengthStart,
 			int maxGradLengthEnd, boolean toEnforceAlphaColors) {
 
-		DecorationAreaType decorationAreaType = SubstanceDecorationUtilities
+		DecorationAreaType decorationAreaType = SubstanceLookAndFeel
 				.getDecorationType(c);
 		SubstanceSkin skin = SubstanceCoreUtilities.getSkin(c);
 		// use alpha colors when the control is in a painted decoration area
 		// (where skin can use different background colors) or in a decoration
-		// area that has drop shadows.
+		// area that has overlays.
 		boolean toUseAlphaColors = ((decorationAreaType == null) || (decorationAreaType == DecorationAreaType.NONE)) ? false
 				: skin.isRegisteredAsDecorationArea(decorationAreaType)
-						|| skin.isPaintingDropShadows(decorationAreaType);
+						|| (skin.getOverlayPainters(decorationAreaType).size() > 0);
 		toUseAlphaColors = toUseAlphaColors || toEnforceAlphaColors;
 
 		Color backgrFill = SubstanceColorUtilities.getBackgroundFillColor(c);
@@ -293,7 +292,9 @@ public class SeparatorPainterUtils {
 			graphics.dispose();
 			cached.put(key, toCache);
 		}
+		Graphics2D g2d = (Graphics2D) g.create();
 		g2d.drawImage(cached.get(key), 0, 0, null);
+		g2d.dispose();
 	}
 
 	/**
@@ -376,6 +377,7 @@ public class SeparatorPainterUtils {
 		for (int lineX : x) {
 			g2d.drawImage(singleLine, lineX - offset / 2, y, null);
 		}
+		g2d.dispose();
 	}
 
 	/**
@@ -463,5 +465,6 @@ public class SeparatorPainterUtils {
 		for (int lineY : y) {
 			g2d.drawImage(singleLine, x, lineY - offset / 2, null);
 		}
+		g2d.dispose();
 	}
 }
