@@ -32,6 +32,7 @@ package org.jvnet.substance.plugin;
 import java.util.HashSet;
 import java.util.Set;
 
+import org.jvnet.substance.api.skin.*;
 import org.jvnet.substance.skin.*;
 
 /**
@@ -86,6 +87,9 @@ public class BaseSkinPlugin implements SubstanceSkinPlugin {
 				false));
 		result.add(create(RavenGraphiteGlassSkin.NAME,
 				RavenGraphiteGlassSkin.class, false));
+		result
+				.add(create(GraphiteAquaSkin.NAME, GraphiteAquaSkin.class,
+						false));
 		result.add(create(ChallengerDeepSkin.NAME, ChallengerDeepSkin.class,
 				false));
 		result.add(create(EmeraldDuskSkin.NAME, EmeraldDuskSkin.class, false));
@@ -99,6 +103,8 @@ public class BaseSkinPlugin implements SubstanceSkinPlugin {
 		result.add(create(DustSkin.NAME, DustSkin.class, false));
 		result.add(create(DustCoffeeSkin.NAME, DustCoffeeSkin.class, false));
 		result.add(create(TwilightSkin.NAME, TwilightSkin.class, false));
+		result.add(create(MagellanSkin.NAME, MagellanSkin.class, false));
+		result.add(create(GeminiSkin.NAME, GeminiSkin.class, false));
 
 		return result;
 	}
