@@ -53,7 +53,7 @@ public class ClassicButtonShaper extends BaseButtonShaper implements
 	/**
 	 * Cache of already computed contours.
 	 */
-	public static LazyResettableHashMap<GeneralPath> contours = new LazyResettableHashMap<GeneralPath>(
+	private final static LazyResettableHashMap<GeneralPath> contours = new LazyResettableHashMap<GeneralPath>(
 			"ClassicButtonShaper");
 
 	/**
