@@ -53,7 +53,7 @@ public class StandardButtonShaper extends BaseButtonShaper implements
 	/**
 	 * Cache of already computed contours.
 	 */
-	public static LazyResettableHashMap<GeneralPath> contours = new LazyResettableHashMap<GeneralPath>(
+	private final static LazyResettableHashMap<GeneralPath> contours = new LazyResettableHashMap<GeneralPath>(
 			"StandardButtonShaper");
 
 	/*
@@ -217,7 +217,7 @@ public class StandardButtonShaper extends BaseButtonShaper implements
 					+ iconPaddingHeight);
 		}
 
-		if (result.height % 2 == 1)
+		if (result.height % 2 != 0)
 			result.height++;
 
 		return result;
