@@ -29,9 +29,9 @@
  */
 package org.jvnet.substance.skin;
 
-import java.util.Map;
-
 import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.painter.overlay.BottomLineOverlayPainter;
+import org.jvnet.substance.api.painter.overlay.TopShadowOverlayPainter;
 import org.jvnet.substance.painter.border.*;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
 import org.jvnet.substance.painter.decoration.MarbleNoiseDecorationPainter;
@@ -49,13 +49,18 @@ public class AutumnSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Autumn";
+	public static final String NAME = "Autumn";
+
+	/**
+	 * Overlay painter to paint separator lines on some decoration areas.
+	 */
+	private BottomLineOverlayPainter bottomLineOverlayPainter;
 
 	/**
 	 * Creates a new <code>Autumn</code> skin.
 	 */
 	public AutumnSkin() {
-		Map<String, SubstanceColorScheme> schemes = SubstanceSkin
+		SubstanceSkin.ColorSchemes schemes = SubstanceSkin
 				.getColorSchemes(AutumnSkin.class.getClassLoader().getResource(
 						"org/jvnet/substance/skin/autumn.colorschemes"));
 
@@ -84,7 +89,19 @@ public class AutumnSkin extends SubstanceSkin {
 				DecorationAreaType.GENERAL, DecorationAreaType.FOOTER,
 				DecorationAreaType.TOOLBAR);
 
-		this.setPaintingDropShadows(DecorationAreaType.TOOLBAR);
+		// add an overlay painter to paint a drop shadow along the top
+		// edge of toolbars
+		this.addOverlayPainter(TopShadowOverlayPainter.getInstance(),
+				DecorationAreaType.TOOLBAR);
+
+		// add an overlay painter to paint separator lines along the bottom
+		// edges of title panes and menu bars
+		this.bottomLineOverlayPainter = new BottomLineOverlayPainter(
+				ColorSchemeSingleColorQuery.DARK);
+		this.addOverlayPainter(this.bottomLineOverlayPainter,
+				DecorationAreaType.PRIMARY_TITLE_PANE,
+				DecorationAreaType.SECONDARY_TITLE_PANE,
+				DecorationAreaType.HEADER);
 
 		this.buttonShaper = new ClassicButtonShaper();
 		this.gradientPainter = new MatteGradientPainter();
@@ -102,7 +119,6 @@ public class AutumnSkin extends SubstanceSkin {
 		this.highlightPainter = new ClassicHighlightPainter();
 
 		MarbleNoiseDecorationPainter decorationPainter = new MarbleNoiseDecorationPainter();
-		decorationPainter.setPaintingSeparators(true);
 		decorationPainter.setTextureAlpha(0.7f);
 		this.decorationPainter = decorationPainter;
 	}
