@@ -32,6 +32,7 @@ package org.jvnet.substance.skin;
 import java.awt.Color;
 
 import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.painter.overlay.TopShadowOverlayPainter;
 import org.jvnet.substance.colorscheme.*;
 import org.jvnet.substance.painter.border.ClassicBorderPainter;
 import org.jvnet.substance.painter.decoration.*;
@@ -50,7 +51,7 @@ public class BusinessBlackSteelSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Business Black Steel";
+	public static final String NAME = "Business Black Steel";
 
 	/**
 	 * Creates a new <code>Business</code> skin.
@@ -114,7 +115,10 @@ public class BusinessBlackSteelSkin extends SubstanceSkin {
 		this.registerDecorationAreaSchemeBundle(generalSchemeBundle,
 				DecorationAreaType.FOOTER, DecorationAreaType.GENERAL);
 
-		this.setPaintingDropShadows(DecorationAreaType.TOOLBAR);
+		// add an overlay painter to paint a drop shadow along the top
+		// edge of toolbars
+		this.addOverlayPainter(TopShadowOverlayPainter.getInstance(),
+				DecorationAreaType.TOOLBAR);
 
 		this.buttonShaper = new ClassicButtonShaper();
 		this.gradientPainter = new ClassicGradientPainter();
