@@ -48,7 +48,7 @@ public class BusinessBlueSteelSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Business Blue Steel";
+	public static final String NAME = "Business Blue Steel";
 
 	/**
 	 * Creates a new <code>Business</code> skin.
