@@ -52,7 +52,7 @@ public class ChallengerDeepSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Challenger Deep";
+	public static final String NAME = "Challenger Deep";
 
 	/**
 	 * Creates a new <code>Challenger Deep</code> skin.
