@@ -51,7 +51,7 @@ public class CremeCoffeeSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Creme Coffee";
+	public static final String NAME = "Creme Coffee";
 
 	/**
 	 * Creates a new <code>Creme Coffee</code> skin.
