@@ -48,7 +48,7 @@ public class CremeSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Creme";
+	public static final String NAME = "Creme";
 
 	/**
 	 * Creates a new <code>Creme</code> skin.
