@@ -52,7 +52,7 @@ public class EmeraldDuskSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Emerald Dusk";
+	public static final String NAME = "Emerald Dusk";
 
 	/**
 	 * Creates a new <code>Emerald Dusk</code> skin.
