@@ -48,7 +48,7 @@ public class MistAquaSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Mist Aqua";
+	public static final String NAME = "Mist Aqua";
 
 	/**
 	 * Creates a new <code>Silver Aqua</code> skin.
