@@ -48,7 +48,7 @@ public class MistSilverSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Mist Silver";
+	public static final String NAME = "Mist Silver";
 
 	/**
 	 * Creates a new <code>Silver</code> skin.
