@@ -43,7 +43,7 @@ public class NebulaBrickWallSkin extends NebulaSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Nebula Brick Wall";
+	public static final String NAME = "Nebula Brick Wall";
 
 	/**
 	 * Creates a new <code>Nebula Brick Wall</code> skin.
