@@ -29,9 +29,11 @@
  */
 package org.jvnet.substance.skin;
 
-import java.util.Map;
+import java.awt.Color;
 
 import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.painter.overlay.BottomLineOverlayPainter;
+import org.jvnet.substance.api.painter.overlay.TopShadowOverlayPainter;
 import org.jvnet.substance.painter.border.FlatBorderPainter;
 import org.jvnet.substance.painter.decoration.*;
 import org.jvnet.substance.painter.gradient.SubduedGradientPainter;
@@ -48,13 +50,18 @@ public class NebulaSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Nebula";
+	public static final String NAME = "Nebula";
+
+	/**
+	 * Overlay painter to paint separator lines on some decoration areas.
+	 */
+	private BottomLineOverlayPainter bottomLineOverlayPainter;
 
 	/**
 	 * Creates a new <code>Nebula</code> skin.
 	 */
 	public NebulaSkin() {
-		Map<String, SubstanceColorScheme> schemes = SubstanceSkin
+		SubstanceSkin.ColorSchemes schemes = SubstanceSkin
 				.getColorSchemes(NebulaSkin.class.getClassLoader().getResource(
 						"org/jvnet/substance/skin/nebula.colorschemes"));
 
@@ -96,13 +103,31 @@ public class NebulaSkin extends SubstanceSkin {
 				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
 				DecorationAreaType.GENERAL);
 
-		this.setPaintingDropShadows(DecorationAreaType.TOOLBAR);
+		// add an overlay painter to paint a drop shadow along the top
+		// edge of toolbars
+		this.addOverlayPainter(TopShadowOverlayPainter.getInstance(),
+				DecorationAreaType.TOOLBAR);
+
+		// add an overlay painter to paint separator lines along the bottom
+		// edges of title panes and menu bars
+		this.bottomLineOverlayPainter = new BottomLineOverlayPainter(
+				new ColorSchemeSingleColorQuery() {
+					@Override
+					public Color query(SubstanceColorScheme scheme) {
+						Color dark = scheme.getDarkColor();
+						return new Color(dark.getRed(), dark.getGreen(), dark
+								.getBlue(), 160);
+					}
+				});
+		this.addOverlayPainter(this.bottomLineOverlayPainter,
+				DecorationAreaType.PRIMARY_TITLE_PANE,
+				DecorationAreaType.SECONDARY_TITLE_PANE,
+				DecorationAreaType.HEADER);
 
 		this.buttonShaper = new ClassicButtonShaper();
 		this.gradientPainter = new SubduedGradientPainter();
 
 		MarbleNoiseDecorationPainter decorationPainter = new MarbleNoiseDecorationPainter();
-		decorationPainter.setPaintingSeparators(true);
 		decorationPainter.setBaseDecorationPainter(new ArcDecorationPainter());
 		decorationPainter.setTextureAlpha(0.3f);
 		this.decorationPainter = decorationPainter;
