@@ -32,14 +32,16 @@ package org.jvnet.substance.skin;
 import java.awt.Color;
 
 import org.jvnet.substance.api.*;
-import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.api.painter.overlay.BottomLineOverlayPainter;
+import org.jvnet.substance.api.painter.overlay.TopLineOverlayPainter;
+import org.jvnet.substance.colorscheme.EbonyColorScheme;
 import org.jvnet.substance.painter.border.*;
 import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
 import org.jvnet.substance.painter.gradient.GlassGradientPainter;
 import org.jvnet.substance.painter.highlight.GlassHighlightPainter;
 import org.jvnet.substance.shaper.ClassicButtonShaper;
-import org.jvnet.substance.watermark.SubstanceCrosshatchWatermark;
+import org.jvnet.substance.utils.SubstanceColorUtilities;
 
 /**
  * <code>Raven Graphite Glass</code> skin. This class is part of officially
@@ -52,40 +54,46 @@ public class RavenGraphiteGlassSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Raven Graphite Glass";
+	public static final String NAME = "Raven Graphite Glass";
+
+	/**
+	 * Overlay painter to paint a dark line along the bottom edge of the
+	 * menubar.
+	 */
+	private BottomLineOverlayPainter menuOverlayPainter;
+
+	/**
+	 * Overlay painter to paint a light line along the top edge of the toolbars.
+	 */
+	private TopLineOverlayPainter toolbarOverlayPainter;
 
 	/**
 	 * Creates a new <code>Raven Graphite</code> skin.
 	 */
 	public RavenGraphiteGlassSkin() {
-		SubstanceColorScheme activeScheme = new EbonyColorScheme().tint(0.2)
-				.named("Raven Graphite Glass Active");
-		SubstanceColorScheme defaultScheme = activeScheme.shade(0.2).named(
-				"Raven Graphite Glass Default");
-		SubstanceColorScheme disabledScheme = new ToneColorScheme(
-				new EbonyColorScheme(), 0.35) {
-			Color foreColor = new Color(32, 32, 32);
+		SubstanceSkin.ColorSchemes schemes = SubstanceSkin
+				.getColorSchemes(RavenGraphiteGlassSkin.class
+						.getClassLoader()
+						.getResource(
+								"org/jvnet/substance/skin/ravengraphite.colorschemes"));
 
-			@Override
-			public Color getForegroundColor() {
-				return foreColor;
-			}
-		}.named("Raven Graphite Glass Disabled");
-		SubstanceColorScheme selectedDisabledScheme = new TintColorScheme(
-				new EbonyColorScheme(), 0.2) {
-			Color foreColor = new Color(32, 32, 32);
+		SubstanceColorScheme activeScheme = schemes
+				.get("Raven Graphite Active");
+		SubstanceColorScheme selectedDisabledScheme = schemes
+				.get("Raven Graphite Selected Disabled");
+		SubstanceColorScheme disabledScheme = schemes
+				.get("Raven Graphite Disabled");
 
-			@Override
-			public Color getForegroundColor() {
-				return foreColor;
-			}
-		}.named("Raven Graphite Glass Selected Disabled");
+		SubstanceColorScheme defaultScheme = schemes
+				.get("Raven Graphite Default");
+		SubstanceColorScheme backgroundScheme = schemes
+				.get("Raven Graphite Background");
 		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
 				activeScheme, defaultScheme, disabledScheme);
 
 		// highlight fill scheme + custom alphas
-		SubstanceColorScheme highlightScheme = new MetallicColorScheme().tint(
-				0.1).named("Raven Graphite Glass Highlight");
+		SubstanceColorScheme highlightScheme = schemes
+				.get("Raven Graphite Highlight");
 		defaultSchemeBundle.registerHighlightColorScheme(highlightScheme, 0.6f,
 				ComponentState.ROLLOVER_UNSELECTED);
 		defaultSchemeBundle.registerHighlightColorScheme(highlightScheme, 0.8f,
@@ -96,13 +104,21 @@ public class RavenGraphiteGlassSkin extends SubstanceSkin {
 				0.75f, ComponentState.ARMED, ComponentState.ROLLOVER_ARMED);
 
 		// highlight border scheme
+		SubstanceColorScheme borderScheme = schemes
+				.get("Raven Graphite Border");
+		SubstanceColorScheme separatorScheme = schemes
+				.get("Raven Graphite Separator");
 		defaultSchemeBundle.registerColorScheme(new EbonyColorScheme(),
 				ColorSchemeAssociationKind.HIGHLIGHT_BORDER, ComponentState
 						.getActiveStates());
+		defaultSchemeBundle.registerColorScheme(borderScheme,
+				ColorSchemeAssociationKind.BORDER);
+		defaultSchemeBundle.registerColorScheme(separatorScheme,
+				ColorSchemeAssociationKind.SEPARATOR);
 
 		// text highlight scheme
-		SubstanceColorScheme textHighlightScheme = new MetallicColorScheme()
-				.tone(0.5).named("Raven Graphite Text Highlight");
+		SubstanceColorScheme textHighlightScheme = schemes
+				.get("Raven Graphite Text Highlight");
 		defaultSchemeBundle.registerColorScheme(textHighlightScheme,
 				ColorSchemeAssociationKind.TEXT_HIGHLIGHT,
 				ComponentState.SELECTED, ComponentState.ROLLOVER_SELECTED);
@@ -117,31 +133,47 @@ public class RavenGraphiteGlassSkin extends SubstanceSkin {
 				ComponentState.DISABLED_SELECTED);
 
 		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
-				DecorationAreaType.NONE);
+				backgroundScheme, DecorationAreaType.NONE);
 
-		this.registerAsDecorationArea(defaultScheme,
+		this.registerAsDecorationArea(backgroundScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
-				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
+				DecorationAreaType.HEADER);// , DecorationAreaType.TOOLBAR);
 
-		setSelectedTabFadeStart(0.3);
-		setSelectedTabFadeEnd(0.6);
+		this.setSelectedTabFadeStart(0.1);
+		this.setSelectedTabFadeEnd(0.3);
+
+		// add two overlay painters to create a bezel line between
+		// menu bar and toolbars
+		this.menuOverlayPainter = new BottomLineOverlayPainter(
+				ColorSchemeSingleColorQuery.MID);
+		this.toolbarOverlayPainter = new TopLineOverlayPainter(
+				new ColorSchemeSingleColorQuery() {
+					@Override
+					public Color query(SubstanceColorScheme scheme) {
+						return SubstanceColorUtilities.getAlphaColor(scheme
+								.getForegroundColor(), 32);
+					}
+				});
+		this.addOverlayPainter(this.menuOverlayPainter,
+				DecorationAreaType.HEADER);
+		this.addOverlayPainter(this.toolbarOverlayPainter,
+				DecorationAreaType.TOOLBAR);
 
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceCrosshatchWatermark();
+		this.watermark = null;
 		this.gradientPainter = new GlassGradientPainter();
 		this.decorationPainter = new ArcDecorationPainter();
 		this.highlightPainter = new GlassHighlightPainter();
 		this.borderPainter = new CompositeBorderPainter("Raven Graphite Glass",
 				new ClassicBorderPainter(), new DelegateBorderPainter(
 						"Raven Graphite Glass Inner",
-						new ClassicBorderPainter(), 0xD0FFFFFF, 0x60FFFFFF,
-						0x10FFFFFF, new ColorSchemeTransform() {
+						new ClassicBorderPainter(), 0xA0FFFFFF, 0x60FFFFFF,
+						0x60FFFFFF, new ColorSchemeTransform() {
 							@Override
 							public SubstanceColorScheme transform(
 									SubstanceColorScheme scheme) {
-								return scheme.tint(0.4f);
+								return scheme.tint(0.25f);
 							}
 						}));
 		this.highlightBorderPainter = new ClassicBorderPainter();
