@@ -32,14 +32,13 @@ package org.jvnet.substance.skin;
 import java.awt.Color;
 
 import org.jvnet.substance.api.*;
-import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.colorscheme.EbonyColorScheme;
 import org.jvnet.substance.painter.border.*;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
 import org.jvnet.substance.painter.decoration.FlatDecorationPainter;
 import org.jvnet.substance.painter.gradient.SimplisticGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
 import org.jvnet.substance.shaper.ClassicButtonShaper;
-import org.jvnet.substance.watermark.SubstanceCrosshatchWatermark;
 
 /**
  * <code>Raven Graphite</code> skin. This class is part of officially supported
@@ -52,48 +51,36 @@ public class RavenGraphiteSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Raven Graphite";
+	public static final String NAME = "Raven Graphite";
 
 	/**
 	 * Creates a new <code>Raven Graphite</code> skin.
 	 */
 	public RavenGraphiteSkin() {
-		SubstanceColorScheme activeScheme = new TintColorScheme(
-				new EbonyColorScheme(), 0.2) {
-			Color foreColor = new Color(200, 200, 200);
+		SubstanceSkin.ColorSchemes schemes = SubstanceSkin
+				.getColorSchemes(RavenGraphiteSkin.class
+						.getClassLoader()
+						.getResource(
+								"org/jvnet/substance/skin/ravengraphite.colorschemes"));
 
-			@Override
-			public Color getForegroundColor() {
-				return foreColor;
-			}
-		}.named("Raven Graphite Active");
-		SubstanceColorScheme selectedDisabledScheme = new TintColorScheme(
-				new EbonyColorScheme(), 0.2) {
-			Color foreColor = new Color(32, 32, 32);
+		SubstanceColorScheme activeScheme = schemes
+				.get("Raven Graphite Active");
+		SubstanceColorScheme selectedDisabledScheme = schemes
+				.get("Raven Graphite Selected Disabled");
+		SubstanceColorScheme disabledScheme = schemes
+				.get("Raven Graphite Disabled");
 
-			@Override
-			public Color getForegroundColor() {
-				return foreColor;
-			}
-		}.named("Raven Graphite Selected Disabled");
-		SubstanceColorScheme disabledScheme = new ToneColorScheme(
-				new EbonyColorScheme(), 0.35) {
-			Color foreColor = new Color(32, 32, 32);
-
-			@Override
-			public Color getForegroundColor() {
-				return foreColor;
-			}
-		}.named("Raven Graphite Disabled");
-		SubstanceColorScheme defaultScheme = activeScheme.shade(0.2).named(
-				"Raven Graphite Default");
+		SubstanceColorScheme defaultScheme = schemes
+				.get("Raven Graphite Default");
+		SubstanceColorScheme backgroundScheme = schemes
+				.get("Raven Graphite Background");
 
 		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
 				activeScheme, defaultScheme, disabledScheme);
 
 		// highlight fill scheme + custom alpha for rollover unselected state
-		SubstanceColorScheme highlightScheme = new MetallicColorScheme().tint(
-				0.1).named("Raven Graphite Highlight");
+		SubstanceColorScheme highlightScheme = schemes
+				.get("Raven Graphite Highlight");
 		defaultSchemeBundle.registerHighlightColorScheme(highlightScheme, 0.6f,
 				ComponentState.ROLLOVER_UNSELECTED);
 		defaultSchemeBundle.registerHighlightColorScheme(highlightScheme, 0.8f,
@@ -104,13 +91,21 @@ public class RavenGraphiteSkin extends SubstanceSkin {
 				0.75f, ComponentState.ARMED, ComponentState.ROLLOVER_ARMED);
 
 		// highlight border scheme
+		SubstanceColorScheme borderScheme = schemes
+				.get("Raven Graphite Border");
+		SubstanceColorScheme separatorScheme = schemes
+				.get("Raven Graphite Separator");
 		defaultSchemeBundle.registerColorScheme(new EbonyColorScheme(),
 				ColorSchemeAssociationKind.HIGHLIGHT_BORDER, ComponentState
 						.getActiveStates());
+		defaultSchemeBundle.registerColorScheme(borderScheme,
+				ColorSchemeAssociationKind.BORDER);
+		defaultSchemeBundle.registerColorScheme(separatorScheme,
+				ColorSchemeAssociationKind.SEPARATOR);
 
 		// text highlight scheme
-		SubstanceColorScheme textHighlightScheme = new MetallicColorScheme()
-				.tone(0.5).named("Raven Graphite Text Highlight");
+		SubstanceColorScheme textHighlightScheme = schemes
+				.get("Raven Graphite Text Highlight");
 		defaultSchemeBundle.registerColorScheme(textHighlightScheme,
 				ColorSchemeAssociationKind.TEXT_HIGHLIGHT,
 				ComponentState.SELECTED, ComponentState.ROLLOVER_SELECTED);
@@ -123,19 +118,13 @@ public class RavenGraphiteSkin extends SubstanceSkin {
 		defaultSchemeBundle.registerColorScheme(selectedDisabledScheme, 0.5f,
 				ComponentState.DISABLED_SELECTED);
 		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
-				DecorationAreaType.NONE);
+				backgroundScheme, DecorationAreaType.NONE);
 
-		this.registerAsDecorationArea(defaultScheme,
-				DecorationAreaType.PRIMARY_TITLE_PANE,
-				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
-				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
-
-		setSelectedTabFadeStart(0.3);
-		setSelectedTabFadeEnd(0.6);
+		this.setSelectedTabFadeStart(0.1);
+		this.setSelectedTabFadeEnd(0.3);
 
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceCrosshatchWatermark();
+		this.watermark = null;
 		this.gradientPainter = new SimplisticGradientPainter() {
 			@Override
 			public Color getBottomFillColor(
@@ -163,12 +152,12 @@ public class RavenGraphiteSkin extends SubstanceSkin {
 		this.borderPainter = new CompositeBorderPainter("Raven Graphite",
 				new ClassicBorderPainter(), new DelegateBorderPainter(
 						"Raven Graphite Inner", new ClassicBorderPainter(),
-						0xFFFFFFFF, 0x60FFFFFF, 0x00FFFFFF,
+						0xA0FFFFFF, 0x60FFFFFF, 0x60FFFFFF,
 						new ColorSchemeTransform() {
 							@Override
 							public SubstanceColorScheme transform(
 									SubstanceColorScheme scheme) {
-								return scheme.tint(0.4f);
+								return scheme.tint(0.25f);
 							}
 						}));
 		this.highlightBorderPainter = new ClassicBorderPainter();
