@@ -51,7 +51,7 @@ public class RavenSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Raven";
+	public static final String NAME = "Raven";
 
 	/**
 	 * Creates a new <code>Raven</code> skin.
