@@ -62,4 +62,14 @@ public class SkinInfo extends TraitInfoImpl {
 		}
 		return false;
 	}
+
+	/*
+	 * (non-Javadoc)
+	 * 
+	 * @see java.lang.Object#hashCode()
+	 */
+	@Override
+	public int hashCode() {
+		return this.getDisplayName().hashCode();
+	}
 }
