@@ -167,8 +167,9 @@ public class LazyResettableHashMap<T> {
 				entryCounter.put(key, entryCounter.get(key) + map.size());
 			}
 
-			for (String key : mapCounter.keySet()) {
-				result.add(mapCounter.get(key) + " " + key + " with "
+			for (Map.Entry<String, Integer> entry : mapCounter.entrySet()) {
+				String key = entry.getKey();
+				result.add(entry.getValue() + " " + key + " with "
 						+ entryCounter.get(key) + " entries total");
 			}
 
