@@ -33,8 +33,8 @@ import java.awt.Color;
 import java.awt.Component;
 import java.io.*;
 import java.net.URL;
-import java.util.HashMap;
-import java.util.Map;
+import java.util.ArrayList;
+import java.util.List;
 
 import javax.swing.*;
 import javax.swing.plaf.UIResource;
@@ -691,7 +691,7 @@ public class SubstanceColorSchemeUtilities {
 		}
 	}
 
-	private static SubstanceColorScheme getLightColorScheme(String name,
+	public static SubstanceColorScheme getLightColorScheme(String name,
 			final Color[] colors) {
 		if (colors == null)
 			throw new IllegalArgumentException("Color encoding cannot be null");
@@ -729,7 +729,7 @@ public class SubstanceColorSchemeUtilities {
 		};
 	}
 
-	private static SubstanceColorScheme getDarkColorScheme(String name,
+	public static SubstanceColorScheme getDarkColorScheme(String name,
 			final Color[] colors) {
 		if (colors == null)
 			throw new IllegalArgumentException("Color encoding cannot be null");
@@ -767,8 +767,8 @@ public class SubstanceColorSchemeUtilities {
 		};
 	}
 
-	public static Map<String, SubstanceColorScheme> getColorSchemes(URL url) {
-		Map<String, SubstanceColorScheme> result = new HashMap<String, SubstanceColorScheme>();
+	public static SubstanceSkin.ColorSchemes getColorSchemes(URL url) {
+		List<SubstanceColorScheme> schemes = new ArrayList<SubstanceColorScheme>();
 
 		BufferedReader reader = null;
 		Color ultraLight = null;
@@ -819,9 +819,9 @@ public class SubstanceColorSchemeUtilities {
 					Color[] colors = new Color[] { ultraLight, extraLight,
 							light, mid, dark, ultraDark, foreground };
 					if (kind == ColorSchemeKind.LIGHT) {
-						result.put(name, getLightColorScheme(name, colors));
+						schemes.add(getLightColorScheme(name, colors));
 					} else {
-						result.put(name, getDarkColorScheme(name, colors));
+						schemes.add(getDarkColorScheme(name, colors));
 					}
 					name = null;
 					kind = null;
@@ -928,7 +928,7 @@ public class SubstanceColorSchemeUtilities {
 				}
 			}
 		}
-		return result;
+		return new SubstanceSkin.ColorSchemes(schemes);
 	}
 
 }
