@@ -39,8 +39,8 @@ import javax.swing.text.JTextComponent;
 
 import org.jvnet.lafwidget.animation.FadeKind;
 import org.jvnet.lafwidget.animation.FadeState;
+import org.jvnet.substance.SubstanceLookAndFeel;
 import org.jvnet.substance.api.*;
-import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
 
 /**
  * Various color-related utilities. This class is <b>for internal use only</b>.
@@ -817,13 +817,13 @@ public class SubstanceColorUtilities {
 	 */
 	public static ColorUIResource getDefaultBackgroundColor(
 			Class<?> componentClass, SubstanceSkin skin, boolean isDisabled) {
-		boolean useLightBackgroundColor = (JTextComponent.class
+		boolean isTextControl = (JTextComponent.class
 				.isAssignableFrom(componentClass))
 				|| (JComboBox.class.isAssignableFrom(componentClass))
 				|| (JSpinner.class.isAssignableFrom(componentClass));
-		if (useLightBackgroundColor || isDisabled)
+		if (isTextControl || isDisabled)
 			return new ColorUIResource(skin.getMainDefaultColorScheme()
-					.getLightBackgroundFillColor());
+					.getTextBackgroundFillColor());
 		return new ColorUIResource(skin.getMainDefaultColorScheme()
 				.getBackgroundFillColor());
 	}
@@ -847,11 +847,11 @@ public class SubstanceColorUtilities {
 			// background fill color.
 			return new ColorUIResource(SubstanceColorSchemeUtilities
 					.getColorScheme(comp, compState)
-					.getLightBackgroundFillColor());
+					.getTextBackgroundFillColor());
 		}
 		return new ColorUIResource(SubstanceCoreUtilities.getSkin(comp)
 				.getBackgroundColorScheme(
-						SubstanceDecorationUtilities.getDecorationType(comp))
+						SubstanceLookAndFeel.getDecorationType(comp))
 				.getBackgroundFillColor());
 		// SubstanceColorSchemeUtilities
 		// .getColorScheme(comp, compState).getBackgroundFillColor());
@@ -886,4 +886,18 @@ public class SubstanceColorUtilities {
 
 		return darkerColor;
 	}
+
+	public static String encode(int number) {
+		if ((number < 0) || (number > 255))
+			throw new IllegalArgumentException("" + number);
+		String hex = "0123456789ABCDEF";
+		char c1 = hex.charAt(number / 16);
+		char c2 = hex.charAt(number % 16);
+		return c1 + "" + c2;
+	}
+
+	public static String encode(Color color) {
+		return "#" + encode(color.getRed()) + encode(color.getGreen())
+				+ encode(color.getBlue());
+	}
 }
