@@ -40,8 +40,7 @@ import java.util.*;
 import javax.swing.*;
 import javax.swing.border.Border;
 import javax.swing.border.CompoundBorder;
-import javax.swing.plaf.ButtonUI;
-import javax.swing.plaf.IconUIResource;
+import javax.swing.plaf.*;
 import javax.swing.text.JTextComponent;
 
 import org.jvnet.lafwidget.LafWidgetUtilities;
@@ -2526,4 +2525,8 @@ public class SubstanceCoreUtilities {
 		return bimage;
 	}
 
+	public static boolean canReplaceChildBackgroundColor(Color background) {
+		return (background instanceof UIResource)
+				|| (background instanceof SubstanceColorResource);
+	}
 }
