@@ -421,9 +421,6 @@ public final class SubstanceImageCreator {
 		graphics.drawImage(singleArrow, 0, 0, null);
 		graphics.drawImage(singleArrow, 0, delta, null);
 
-		// graphics.setColor(Color.blue);
-		// graphics.drawRect(0, 0, (int) width - 1, (int) height - 1);
-
 		int quadrantCounterClockwise = 0;
 		switch (direction) {
 		case SwingConstants.NORTH:
@@ -598,7 +595,7 @@ public final class SubstanceImageCreator {
 	 *            First color scheme.
 	 * @param scheme2
 	 *            Second color scheme.
-	 * @param interpolationCyclePos10
+	 * @param interpolationCyclePos
 	 *            Interpolation cycle.
 	 * @param checkMarkVisibility
 	 *            Checkmark visibility in 0.0-1.0 range.
@@ -615,12 +612,16 @@ public final class SubstanceImageCreator {
 			SubstanceColorScheme prevMarkColorScheme,
 			SubstanceColorScheme currBorderColorScheme,
 			SubstanceColorScheme prevBorderColorScheme,
-			float interpolationCyclePos10, float checkMarkVisibility) {
+			float interpolationCyclePos, float checkMarkVisibility) {
 
 		// ComponentState.ColorSchemeKind kind = componentState
 		// .getColorSchemeKind();
 
-		float cyclePos = (currFillColorScheme != prevFillColorScheme) ? interpolationCyclePos10
+		float cyclePos = (currFillColorScheme != prevFillColorScheme) ? interpolationCyclePos
+				: componentState.getCyclePosition();
+		float borderCyclePos = (currBorderColorScheme != prevBorderColorScheme) ? interpolationCyclePos
+				: componentState.getCyclePosition();
+		float markCyclePos = (currMarkColorScheme != prevMarkColorScheme) ? interpolationCyclePos
 				: componentState.getCyclePosition();
 
 		if (componentState.getColorSchemeKind() != ColorSchemeKind.CURRENT) {
@@ -656,7 +657,7 @@ public final class SubstanceImageCreator {
 
 		borderPainter.paintBorder(graphics, component, dimension, dimension,
 				contourBorder, contourInner, currBorderColorScheme,
-				prevBorderColorScheme, cyclePos,
+				prevBorderColorScheme, borderCyclePos,
 				currBorderColorScheme != prevBorderColorScheme);
 		graphics.setComposite(AlphaComposite.SrcOver);
 		// graphics.translate(-offsetX, 0);
@@ -682,7 +683,7 @@ public final class SubstanceImageCreator {
 					markOval);
 			graphics.setComposite(AlphaComposite.getInstance(
 					AlphaComposite.SRC_OVER, alpha * checkMarkVisibility
-							* cyclePos));
+							* markCyclePos));
 			drawRadioMark(graphics, SubstanceColorUtilities
 					.getMarkColor(prevMarkColorScheme, componentState
 							.getColorSchemeKind() != ColorSchemeKind.DISABLED),
@@ -775,6 +776,10 @@ public final class SubstanceImageCreator {
 
 		float cyclePos = (currFillColorScheme != prevFillColorScheme) ? interpolationCyclePos
 				: componentState.getCyclePosition();
+		float borderCyclePos = (currBorderColorScheme != prevBorderColorScheme) ? interpolationCyclePos
+				: componentState.getCyclePosition();
+		float markCyclePos = (currMarkColorScheme != prevMarkColorScheme) ? interpolationCyclePos
+				: componentState.getCyclePosition();
 
 		int contourDim = dimension - delta;
 		int borderDelta = (int) Math.floor(SubstanceSizeUtils
@@ -809,7 +814,7 @@ public final class SubstanceImageCreator {
 				borderThickness + borderDelta);
 		borderPainter.paintBorder(graphics, button, contourDim, contourDim,
 				contour, contourInner, currBorderColorScheme,
-				prevBorderColorScheme, cyclePos,
+				prevBorderColorScheme, borderCyclePos,
 				currBorderColorScheme != prevBorderColorScheme);
 		graphics.translate(-delta, 1 - delta);
 		if (componentState.isKindActive(FadeKind.SELECTION)
@@ -831,7 +836,7 @@ public final class SubstanceImageCreator {
 							.isKindActive(FadeKind.ENABLE),
 					prevMarkColorScheme, checkMarkVisibility);
 			graphics.setComposite(AlphaComposite.getInstance(
-					AlphaComposite.SRC_OVER, alpha * cyclePos));
+					AlphaComposite.SRC_OVER, alpha * markCyclePos));
 			graphics.drawImage(checkMark2, 1 + 2 * offset / 3,
 					(dimension < 14) ? 0 : -1, null);
 		}
