@@ -46,7 +46,7 @@ import org.jvnet.substance.*;
 import org.jvnet.substance.api.SubstanceColorScheme;
 import org.jvnet.substance.colorscheme.ShiftColorScheme;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
-import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.icon.SubstanceIconFactory;
 import org.jvnet.substance.utils.icon.TransitionAwareIcon;
 
@@ -405,8 +405,10 @@ public class SubstanceInternalFrameTitlePane extends
 			}
 		}
 
-		SubstanceDecorationUtilities.paintDecorationBackground(graphics,
+		BackgroundPaintingUtils.update(graphics,
 				SubstanceInternalFrameTitlePane.this, false);
+		// DecorationPainterUtils.paintDecorationBackground(graphics,
+		// SubstanceInternalFrameTitlePane.this, false);
 
 		// draw the title (if needed)
 		if (theTitle != null) {
