@@ -255,15 +255,13 @@ public class SubstanceOutlineUtilities {
 	public static GeneralPath getTriangleButtonOutline(int width, int height,
 			float radius, Insets insets) {
 
-		int xs = (insets == null) ? 0 : insets.left;
-		int ys = (insets == null) ? 0 : insets.top;
-		int xe = (insets == null) ? width : width - insets.right;
+		int xs = insets.left;
+		int ys = insets.top;
+		int xe = width - insets.right;
 		xe--;
-		int ye = (insets == null) ? height : height - insets.bottom;
-		if (insets != null) {
-			width -= (insets.right + insets.left);
-			height -= (insets.top + insets.bottom);
-		}
+		int ye = height - insets.bottom;
+		width -= (insets.right + insets.left);
+		height -= (insets.top + insets.bottom);
 
 		GeneralPath result = new GeneralPath();
 		float radius3 = (float) (radius / (1.5 * Math.pow(height, 0.5)));
