@@ -173,7 +173,7 @@ public class SubstanceSizeUtils {
 		if (delta <= 0)
 			return baseSize;
 		int result = baseSize + delta * toAdjustBy / forEachBase;
-		if (toRoundAsEven && (result % 2 == 1))
+		if (toRoundAsEven && (result % 2 != 0))
 			result--;
 		return result;
 	}
@@ -350,7 +350,7 @@ public class SubstanceSizeUtils {
 	 */
 	public static int getBigDragBumpDiameter(int fontSize) {
 		int result = getAdjustedSize(fontSize, 3, 3, 1, false);
-		if (result % 2 == 1)
+		if (result % 2 != 0)
 			result++;
 		return result;
 	}
@@ -543,7 +543,7 @@ public class SubstanceSizeUtils {
 	 * @return Width of scroll bars under the specified font size.
 	 */
 	public static int getScrollBarWidth(int fontSize) {
-		int result = (int)(getArrowIconWidth(fontSize) * 3 / 2);
+		int result = (int) (getArrowIconWidth(fontSize) * 3 / 2);
 		if (result % 2 == 0)
 			result++;
 		return result;
@@ -558,7 +558,7 @@ public class SubstanceSizeUtils {
 	 */
 	public static int getSliderIconSize(int fontSize) {
 		int result = fontSize + 5;
-		if (result % 2 == 1)
+		if (result % 2 != 0)
 			result--;
 		return result;
 	}
@@ -665,16 +665,16 @@ public class SubstanceSizeUtils {
 				borderStrokeWidth, borderStrokeWidth);
 	}
 
-//	/**
-//	 * Returns the spinner button width under the specified font size.
-//	 * 
-//	 * @param fontSize
-//	 *            Font size.
-//	 * @return Spinner button width under the specified font size.
-//	 */
-//	public static int getSpinnerButtonWidth(int fontSize) {
-//		return (int)(getArrowIconWidth(fontSize) * 3 / 2);
-//	}
+	// /**
+	// * Returns the spinner button width under the specified font size.
+	// *
+	// * @param fontSize
+	// * Font size.
+	// * @return Spinner button width under the specified font size.
+	// */
+	// public static int getSpinnerButtonWidth(int fontSize) {
+	// return (int)(getArrowIconWidth(fontSize) * 3 / 2);
+	// }
 
 	/**
 	 * Returns the spinner text border insets under the specified font size.
