@@ -44,7 +44,7 @@ import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.SubstanceLookAndFeel;
 import org.jvnet.substance.SubstanceSplitPaneUI;
 import org.jvnet.substance.api.*;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.icon.TransitionAwareIcon;
 
 /**
@@ -169,8 +169,7 @@ public class SubstanceSplitPaneDivider extends BasicSplitPaneDivider implements
 	@Override
 	public void paint(Graphics g) {
 		if (SubstanceCoreUtilities.hasFlatAppearance(this.splitPane, true)) {
-			SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.updateIfOpaque(g,
-					this.splitPane);
+			BackgroundPaintingUtils.updateIfOpaque(g, this.splitPane);
 		}
 
 		Graphics2D graphics = (Graphics2D) g.create();
