@@ -42,7 +42,7 @@ import org.jvnet.lafwidget.animation.FadeKind;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.lafwidget.utils.RenderingUtils;
 import org.jvnet.substance.api.ComponentState;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.utils.border.SubstanceBorder;
 import org.jvnet.substance.watermark.SubstanceWatermark;
 
@@ -422,7 +422,7 @@ public class SubstanceTextUtilities {
 						null, borderDelta)
 				: new Rectangle(0, 0, comp.getWidth(), comp.getHeight());
 
-		SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.update(g, comp, false);
+		BackgroundPaintingUtils.update(g, comp, false);
 		g2d.setColor(backgr);
 		g2d.fill(contour);
 
