@@ -49,7 +49,7 @@ import org.jvnet.substance.*;
 import org.jvnet.substance.api.*;
 import org.jvnet.substance.api.SubstanceConstants.SubstanceWidgetType;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
-import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
 import org.jvnet.substance.skin.SkinInfo;
 import org.jvnet.substance.utils.icon.SubstanceIconFactory;
 import org.jvnet.substance.utils.icon.TransitionAwareIcon;
@@ -136,7 +136,7 @@ public class SubstanceTitlePane extends JComponent {
 	 * The logfile name for the heap status panel. Can be <code>null</code> - in
 	 * this case the {@link HeapStatusThread} will not write heap information.
 	 */
-	protected static String heapStatusLogfileName;
+	private static String heapStatusLogfileName;
 
 	/**
 	 * The heap status panel of <code>this</code> title pane.
@@ -434,7 +434,7 @@ public class SubstanceTitlePane extends JComponent {
 					HeapStatusPanel panel = refPanel.get();
 					if (panel == null) {
 						// prune
-						panels.remove(it);
+						it.remove();
 						continue;
 					}
 
@@ -847,7 +847,6 @@ public class SubstanceTitlePane extends JComponent {
 		this.closeButton = this.createTitleButton();
 		this.closeButton.setAction(this.closeAction);
 		this.closeButton.setText(null);
-		this.closeButton.putClientProperty("paintActive", Boolean.TRUE);
 		this.closeButton.setBorder(null);
 		// this.closeButton.setToolTipText(SubstanceLookAndFeel
 		// .getLabelBundle().getString(
@@ -879,7 +878,6 @@ public class SubstanceTitlePane extends JComponent {
 			this.minimizeButton = this.createTitleButton();
 			this.minimizeButton.setAction(this.iconifyAction);
 			this.minimizeButton.setText(null);
-			this.minimizeButton.putClientProperty("paintActive", Boolean.TRUE);
 			this.minimizeButton.setBorder(null);
 
 			Icon minIcon = new TransitionAwareIcon(this.minimizeButton,
@@ -907,7 +905,6 @@ public class SubstanceTitlePane extends JComponent {
 
 			this.toggleButton = this.createTitleButton();
 			this.toggleButton.setAction(this.restoreAction);
-			this.toggleButton.putClientProperty("paintActive", Boolean.TRUE);
 			this.toggleButton.setBorder(null);
 			this.toggleButton.setText(null);
 
@@ -955,13 +952,6 @@ public class SubstanceTitlePane extends JComponent {
 	 *            if <code>true</code>, the window is in active state.
 	 */
 	private void setActive(boolean isActive) {
-		Boolean activeB = isActive ? Boolean.TRUE : Boolean.FALSE;
-
-		if (this.getWindowDecorationStyle() == JRootPane.FRAME) {
-			this.closeButton.putClientProperty("paintActive", activeB);
-			this.minimizeButton.putClientProperty("paintActive", activeB);
-			this.toggleButton.putClientProperty("paintActive", activeB);
-		}
 		this.getRootPane().repaint();
 	}
 
@@ -1206,8 +1196,10 @@ public class SubstanceTitlePane extends JComponent {
 				"Substance", null).getWindowTitleFont();
 		graphics.setFont(font);
 
-		SubstanceDecorationUtilities.paintDecorationBackground(graphics,
-				SubstanceTitlePane.this, false);
+		BackgroundPaintingUtils
+				.update(graphics, SubstanceTitlePane.this, false);
+		// DecorationPainterUtils.paintDecorationBackground(graphics,
+		// SubstanceTitlePane.this, false);
 
 		// draw the title (if needed)
 		if (theTitle != null) {
