@@ -120,8 +120,8 @@ public class SubstanceWidgetSupport extends LafWidgetSupport {
 	 */
 	@Override
 	public Icon getNumberIcon(int number) {
-		SubstanceColorScheme colorScheme = SubstanceLookAndFeel.getCurrentSkin(null)
-				.getMainActiveColorScheme(DecorationAreaType.HEADER);
+		SubstanceColorScheme colorScheme = SubstanceLookAndFeel.getCurrentSkin(
+				null).getMainActiveColorScheme(DecorationAreaType.HEADER);
 		return SubstanceImageCreator.getHexaMarker(number, colorScheme);
 	}
 
@@ -213,8 +213,8 @@ public class SubstanceWidgetSupport extends LafWidgetSupport {
 			colorScheme = SubstanceColorSchemeUtilities.GREEN;
 
 		if (colorScheme != null) {
-			SubstanceImageCreator.paintRectangularBackground(null, g, x, y, width,
-					height, colorScheme, 0.5f, false);
+			SubstanceImageCreator.paintRectangularBackground(null, g, x, y,
+					width, height, colorScheme, 0.5f, false);
 		}
 
 		g2.dispose();
@@ -266,7 +266,7 @@ public class SubstanceWidgetSupport extends LafWidgetSupport {
 	@Override
 	public int getLookupIconSize() {
 		int result = 2 + SubstanceSizeUtils.getControlFontSize();
-		if (result % 2 == 1)
+		if (result % 2 != 0)
 			result++;
 		return result;
 	}
