@@ -36,8 +36,7 @@ import java.awt.geom.Rectangle2D;
 import javax.swing.border.Border;
 
 import org.jvnet.lafwidget.utils.RenderingUtils;
-import org.jvnet.substance.api.ComponentState;
-import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.*;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -55,7 +54,8 @@ public class SubstanceEtchedBorder implements Border {
 	 */
 	public Color getHighlightColor(Component c) {
 		SubstanceColorScheme colorScheme = SubstanceColorSchemeUtilities
-				.getColorScheme(c, ComponentState.DEFAULT);
+				.getColorScheme(c, ColorSchemeAssociationKind.SEPARATOR,
+						ComponentState.DEFAULT);
 		boolean isDark = colorScheme.isDark();
 		Color foreDark = isDark ? colorScheme.getExtraLightColor()
 				: SubstanceColorUtilities.getInterpolatedColor(colorScheme
@@ -73,7 +73,8 @@ public class SubstanceEtchedBorder implements Border {
 	 */
 	public Color getShadowColor(Component c) {
 		SubstanceColorScheme colorScheme = SubstanceColorSchemeUtilities
-				.getColorScheme(c, ComponentState.DEFAULT);
+				.getColorScheme(c, ColorSchemeAssociationKind.SEPARATOR,
+						ComponentState.DEFAULT);
 		Color back = colorScheme.isDark() ? colorScheme.getDarkColor()
 				: colorScheme.getUltraLightColor();
 		return SubstanceColorUtilities.getAlphaColor(back, 196);
