@@ -1,5 +1,5 @@
 /*
- * $Id: ColorSchemeFilter.java,v 1.3 2009/01/01 01:13:54 kirillcool Exp $
+ * $Id: ColorSchemeFilter.java,v 1.5 2009/09/11 05:25:41 kirillcool Exp $
  *
  * Dual-licensed under LGPL (Sun and Romain Guy) and BSD (Romain Guy).
  *
@@ -51,7 +51,7 @@ public class ColorSchemeFilter extends AbstractFilter {
 
 	public static final int MAPSTEPS = 512;
 
-	protected static LazyResettableHashMap<ColorSchemeFilter> filters = new LazyResettableHashMap<ColorSchemeFilter>(
+	protected final static LazyResettableHashMap<ColorSchemeFilter> filters = new LazyResettableHashMap<ColorSchemeFilter>(
 			"ColorSchemeFilter");
 
 	protected float originalBrightnessFactor;
@@ -108,11 +108,13 @@ public class ColorSchemeFilter extends AbstractFilter {
 		int lowestSchemeBrightness = schemeBrightness.get(0);
 		int highestSchemeBrightness = schemeBrightness.get(schemeBrightness
 				.size() - 1);
+		boolean hasSameBrightness = (highestSchemeBrightness == lowestSchemeBrightness);
 
 		Map<Integer, Color> stretchedColorMapping = new TreeMap<Integer, Color>();
 		for (Map.Entry<Integer, Color> entry : schemeColorMapping.entrySet()) {
 			int brightness = entry.getKey();
-			int stretched = 255 - 255 * (highestSchemeBrightness - brightness)
+			int stretched = hasSameBrightness ? brightness : 255 - 255
+					* (highestSchemeBrightness - brightness)
 					/ (highestSchemeBrightness - lowestSchemeBrightness);
 			stretchedColorMapping.put(stretched, entry.getValue());
 		}
@@ -127,27 +129,32 @@ public class ColorSchemeFilter extends AbstractFilter {
 				this.interpolated[i] = stretchedColorMapping.get(brightness)
 						.getRGB();
 			} else {
-				int currIndex = 0;
-				while (true) {
-					int currStopValue = schemeBrightness.get(currIndex);
-					int nextStopValue = schemeBrightness.get(currIndex + 1);
-					if ((brightness > currStopValue)
-							&& (brightness < nextStopValue)) {
-						// interpolate
-						Color currStopColor = stretchedColorMapping
-								.get(currStopValue);
-						Color nextStopColor = stretchedColorMapping
-								.get(nextStopValue);
-						this.interpolated[i] = SubstanceColorUtilities
-								.getInterpolatedRGB(
-										currStopColor,
-										nextStopColor,
-										1.0
-												- (double) (brightness - currStopValue)
-												/ (double) (nextStopValue - currStopValue));
-						break;
+				if (hasSameBrightness) {
+					this.interpolated[i] = stretchedColorMapping.get(
+							lowestSchemeBrightness).getRGB();
+				} else {
+					int currIndex = 0;
+					while (true) {
+						int currStopValue = schemeBrightness.get(currIndex);
+						int nextStopValue = schemeBrightness.get(currIndex + 1);
+						if ((brightness > currStopValue)
+								&& (brightness < nextStopValue)) {
+							// interpolate
+							Color currStopColor = stretchedColorMapping
+									.get(currStopValue);
+							Color nextStopColor = stretchedColorMapping
+									.get(nextStopValue);
+							this.interpolated[i] = SubstanceColorUtilities
+									.getInterpolatedRGB(
+											currStopColor,
+											nextStopColor,
+											1.0
+													- (double) (brightness - currStopValue)
+													/ (double) (nextStopValue - currStopValue));
+							break;
+						}
+						currIndex++;
 					}
-					currIndex++;
 				}
 			}
 		}
