@@ -67,6 +67,11 @@ public class TransitionAwareIcon implements Icon {
 		public Icon getColorSchemeIcon(SubstanceColorScheme scheme);
 	}
 
+	public static interface ColorSchemeAssociationKindDelegate {
+		public ColorSchemeAssociationKind getColorSchemeAssociationKind(
+				ComponentState state);
+	}
+
 	/**
 	 * The associated component.
 	 */
@@ -82,6 +87,8 @@ public class TransitionAwareIcon implements Icon {
 	 */
 	protected Delegate delegate;
 
+	protected ColorSchemeAssociationKindDelegate colorSchemeAssociationKindDelegate;
+
 	protected String uniqueIconTypeId;
 
 	/**
@@ -122,9 +129,29 @@ public class TransitionAwareIcon implements Icon {
 	 */
 	public TransitionAwareIcon(JComponent comp, ButtonModel model,
 			Delegate delegate, String uniqueIconTypeId) {
+		this(comp, model, delegate, null, uniqueIconTypeId);
+	}
+
+	/**
+	 * Creates a new transition-aware icon.
+	 * 
+	 * @param comp
+	 *            Associated component.
+	 * @param model
+	 *            Associated model.
+	 * @param delegate
+	 *            Delegate to compute the actual icons.
+	 */
+	public TransitionAwareIcon(
+			JComponent comp,
+			ButtonModel model,
+			Delegate delegate,
+			ColorSchemeAssociationKindDelegate colorSchemeAssociationKindDelegate,
+			String uniqueIconTypeId) {
 		this.comp = comp;
 		this.model = model;
 		this.delegate = delegate;
+		this.colorSchemeAssociationKindDelegate = colorSchemeAssociationKindDelegate;
 		this.uniqueIconTypeId = uniqueIconTypeId;
 		this.iconWidth = this.delegate.getColorSchemeIcon(
 				SubstanceColorSchemeUtilities
@@ -151,8 +178,11 @@ public class TransitionAwareIcon implements Icon {
 			prevState = currState;
 		float cyclePos = currState.getCyclePosition();
 
+		ColorSchemeAssociationKind currColorSchemeAssociationKind = (this.colorSchemeAssociationKindDelegate == null) ? ColorSchemeAssociationKind.MARK
+				: this.colorSchemeAssociationKindDelegate
+						.getColorSchemeAssociationKind(currState);
 		SubstanceColorScheme currScheme = SubstanceColorSchemeUtilities
-				.getColorScheme(this.comp, ColorSchemeAssociationKind.MARK,
+				.getColorScheme(this.comp, currColorSchemeAssociationKind,
 						currState);
 
 		SubstanceColorScheme prevScheme = currScheme;
@@ -161,8 +191,11 @@ public class TransitionAwareIcon implements Icon {
 				FadeKind.ROLLOVER, FadeKind.SELECTION, FadeKind.PRESS,
 				FadeKind.ARM);
 		if (fadeState != null) {
+			ColorSchemeAssociationKind prevColorSchemeAssociationKind = (this.colorSchemeAssociationKindDelegate == null) ? ColorSchemeAssociationKind.MARK
+					: this.colorSchemeAssociationKindDelegate
+							.getColorSchemeAssociationKind(prevState);
 			prevScheme = SubstanceColorSchemeUtilities.getColorScheme(
-					this.comp, ColorSchemeAssociationKind.MARK, prevState);
+					this.comp, prevColorSchemeAssociationKind, prevState);
 			cyclePos = fadeState.getFadePosition();
 			if (!fadeState.isFadingIn())
 				cyclePos = 1.0f - cyclePos;
