@@ -54,12 +54,6 @@ import org.jvnet.substance.utils.*;
  * @author Kirill Grouchnikov
  */
 public class MenuUtilities {
-	/**
-	 * Delegate for painting the background.
-	 */
-	private static SubstanceMenuBackgroundDelegate backgroundDelegate = new SubstanceMenuBackgroundDelegate(
-			0.4f);
-
 	/**
 	 * Key to store the layout metrics. The value should be an instance of
 	 * {@link MenuLayoutMetrics}.
@@ -528,8 +522,6 @@ public class MenuUtilities {
 		MenuLayoutMetrics popupMetrics = MenuUtilities.getPopupLayoutMetrics(
 				menuItem, true);
 		Insets i = menuItem.getInsets();
-		// FontMetrics fm = menuItem.getFontMetrics(menuItem.getFont());
-		// int fontHeight = fm.getHeight();
 		if (popupMetrics != null) {
 			MenuGutterFillKind gutterFillKind = SubstanceCoreUtilities
 					.getMenuGutterFillKind();
@@ -586,17 +578,8 @@ public class MenuUtilities {
 
 				Rectangle labelRect = new Rectangle(0, 0, menuItem.getWidth(),
 						menuItem.getHeight());
-				// if (mli.iconRect != null)
-				// labelRect = labelRect.union(mli.iconRect);
 				if (mli.textRect != null)
 					labelRect = mli.textRect;
-				// // Align the accelerator text and the check and arrow icons
-				// // vertically with the center of the label rect.
-				// if (mli.acceleratorRect != null) {
-				// mli.acceleratorRect.y = labelRect.y;
-				// //+ (labelRect.height / 2)
-				// //- (mli.acceleratorRect.height / 2);
-				// }
 				if (mli.iconRect != null) {
 					mli.iconRect.y = labelRect.y + (labelRect.height / 2)
 							- (mli.iconRect.height / 2);
@@ -664,17 +647,8 @@ public class MenuUtilities {
 
 				Rectangle labelRect = new Rectangle(0, 0, menuItem.getWidth(),
 						menuItem.getHeight());
-				// if (mli.iconRect != null)
-				// labelRect = labelRect.union(mli.iconRect);
 				if (mli.textRect != null)
 					labelRect = mli.textRect;
-				// // Align the accelerator text and the check and arrow icons
-				// // vertically with the center of the label rect.
-				// if (mli.acceleratorRect != null) {
-				// mli.acceleratorRect.y = labelRect.y;
-				// //+ (labelRect.height / 2)
-				// //- (mli.acceleratorRect.height / 2);
-				// }
 				if (mli.iconRect != null) {
 					mli.iconRect.y = labelRect.y + (labelRect.height / 2)
 							- (mli.iconRect.height / 2);
@@ -696,10 +670,6 @@ public class MenuUtilities {
 					.getClientProperty(GUTTER_X));
 		}
 
-		// MenuUtilities.lineupTextRectangle(menuItem, mli.textRect, menuUi
-		// .getAcceleratorFont(), menuUi.getCheckIcon(), menuUi
-		// .getArrowIcon(), menuUi.getDefaultTextIconGap());
-
 		paintBackground(g2d, menuItem);
 		paintHighlights(g2d, menuItem);
 
@@ -832,11 +802,8 @@ public class MenuUtilities {
 	private static void paintBackground(Graphics g, JMenuItem menuItem) {
 		int textOffset = MenuUtilities.getTextOffset(menuItem, menuItem
 				.getParent());
-		// System.out.println(menuItem.getText() + ":" + textOffset);
-		Color bgColor = SubstanceColorUtilities
-				.getBackgroundFillColor(menuItem);
-		backgroundDelegate.paintBackground(g, menuItem, bgColor, 0.5f,
-				textOffset);
+		SubstanceMenuBackgroundDelegate
+				.paintBackground(g, menuItem, textOffset);
 	}
 
 	/**
@@ -902,13 +869,7 @@ public class MenuUtilities {
 		Component comp = menuItem.getParent();
 		if (comp instanceof JPopupMenu) {
 			JPopupMenu popupMenu = (JPopupMenu) comp;
-			Object prop = popupMenu.getClientProperty(LAYOUT_METRICS);
-			if (prop instanceof MenuLayoutMetrics) {
-				return (MenuLayoutMetrics) prop;
-			}
-			MenuLayoutMetrics metrics = getMetrics(popupMenu, forPainting);
-			popupMenu.putClientProperty(LAYOUT_METRICS, metrics);
-			return metrics;
+			return getPopupLayoutMetrics(popupMenu, forPainting);
 		}
 		// fix for issue 347 - menu item in menu bar is not
 		// covered by the code above
@@ -937,6 +898,17 @@ public class MenuUtilities {
 		return null;
 	}
 
+	public static MenuLayoutMetrics getPopupLayoutMetrics(JPopupMenu popupMenu,
+			boolean forPainting) {
+		Object prop = popupMenu.getClientProperty(LAYOUT_METRICS);
+		if (prop instanceof MenuLayoutMetrics) {
+			return (MenuLayoutMetrics) prop;
+		}
+		MenuLayoutMetrics metrics = getMetrics(popupMenu, forPainting);
+		popupMenu.putClientProperty(LAYOUT_METRICS, metrics);
+		return metrics;
+	}
+
 	/**
 	 * Cleans the layout metrics of the popup menu of the specified menu item.
 	 * 
