@@ -30,6 +30,7 @@
 package org.jvnet.substance.utils.menu;
 
 import java.awt.*;
+import java.awt.MultipleGradientPaint.CycleMethod;
 
 import javax.swing.*;
 
@@ -39,8 +40,8 @@ import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.api.ComponentState;
 import org.jvnet.substance.api.SubstanceColorScheme;
 import org.jvnet.substance.api.SubstanceConstants.MenuGutterFillKind;
-import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
-import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.painter.utils.BackgroundPaintingUtils;
+import org.jvnet.substance.painter.utils.HighlightPainterUtils;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -49,22 +50,6 @@ import org.jvnet.substance.utils.*;
  * @author Kirill Grouchnikov
  */
 public class SubstanceMenuBackgroundDelegate {
-	/**
-	 * Delegate for painting fill background.
-	 */
-	private SubstanceFillBackgroundDelegate fillBackgroundDelegate;
-
-	/**
-	 * Creates a new background delegate for menu items.
-	 * 
-	 * @param fillAlpha
-	 *            Alphs attribute for the fill.
-	 */
-	public SubstanceMenuBackgroundDelegate(float fillAlpha) {
-		this.fillBackgroundDelegate = new SubstanceFillBackgroundDelegate(
-				fillAlpha);
-	}
-
 	/**
 	 * Updates the specified menu item with the background that matches the
 	 * provided parameters.
@@ -80,41 +65,19 @@ public class SubstanceMenuBackgroundDelegate {
 	 * @param textOffset
 	 *            The offset of the menu item text.
 	 */
-	public void paintBackground(Graphics g, JMenuItem menuItem, Color bgColor,
-			float borderAlpha, int textOffset) {
+	public static void paintBackground(Graphics g, Component menuItem,
+			int textOffset) {
 		if (!menuItem.isShowing())
 			return;
 		int menuWidth = menuItem.getWidth();
 		int menuHeight = menuItem.getHeight();
 
 		Graphics2D graphics = (Graphics2D) g.create();
+		graphics.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
+				RenderingHints.VALUE_ANTIALIAS_OFF);
 
-		// if (TransitionLayout.isOpaque(menuItem)) {
-		// // menu item is opaque and selected (or armed) -
-		// // use background color of the item (with watermark)
-		// graphics.setColor(menuItem.getBackground());
-		Component comp = menuItem.getParent();
-		// graphics.fillRect(0, 0, menuWidth, menuHeight);
-		// // System.out.println(menuItem.getText());
-		this.fillBackgroundDelegate.setWatermarkAlpha(0.4f);
-		while (comp != null) {
-			// System.out.println("\t" + comp.getClass().getName());
-			if (comp instanceof JMenuItem) {
-				break;
-			}
-			if (comp instanceof JMenuBar) {
-				// top-level
-				this.fillBackgroundDelegate.setWatermarkAlpha(1.0f);
-				break;
-			}
-			comp = comp.getParent();
-		}
+		BackgroundPaintingUtils.update(graphics, menuItem, false);
 
-		// if (TransitionLayout.isOpaque(menuItem)
-		// || !(menuItem.getParent() instanceof JMenuBar)) {
-		// if (TransitionLayout.isOpaque(menuItem)) {
-		this.fillBackgroundDelegate.update(graphics, menuItem, false);
-		// }
 		if (menuItem.getParent() instanceof JPopupMenu) {
 			if (menuItem.getComponentOrientation().isLeftToRight()) {
 				MenuGutterFillKind fillKind = SubstanceCoreUtilities
@@ -128,8 +91,10 @@ public class SubstanceMenuBackgroundDelegate {
 					Color rightColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? scheme
 							.getUltraLightColor()
 							: scheme.getLightColor();
-					GradientPaint gp = new GradientPaint(0, 0, leftColor,
-							textOffset, 0, rightColor);
+					LinearGradientPaint gp = new LinearGradientPaint(0, 0,
+							textOffset, 0, new float[] { 0.0f, 1.0f },
+							new Color[] { leftColor, rightColor },
+							CycleMethod.REPEAT);
 					graphics.setComposite(TransitionLayout.getAlphaComposite(
 							menuItem, 0.7f, g));
 
@@ -157,8 +122,12 @@ public class SubstanceMenuBackgroundDelegate {
 					Color rightColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? scheme
 							.getLightColor()
 							: scheme.getUltraLightColor();
-					GradientPaint gp = new GradientPaint(textOffset, 0,
-							leftColor, menuWidth, 0, rightColor);
+
+					LinearGradientPaint gp = new LinearGradientPaint(
+							textOffset, 0, menuWidth, 0, new float[] { 0.0f,
+									1.0f },
+							new Color[] { leftColor, rightColor },
+							CycleMethod.REPEAT);
 					graphics.setComposite(TransitionLayout.getAlphaComposite(
 							menuItem, 0.7f, g));
 					graphics.setPaint(gp);
@@ -261,7 +230,7 @@ public class SubstanceMenuBackgroundDelegate {
 		if (hasHighlight && (totalAlpha > 0.0f)) {
 			graphics.setComposite(TransitionLayout.getAlphaComposite(menuItem,
 					totalAlpha, g));
-			SubstanceHighlightUtils.paintHighlight(graphics, null, menuItem,
+			HighlightPainterUtils.paintHighlight(graphics, null, menuItem,
 					new Rectangle(0, 0, menuItem.getWidth(), menuItem
 							.getHeight()), borderAlpha, null, currState,
 					prevState, fadeCoef);
