@@ -41,18 +41,17 @@ import javax.swing.event.ChangeListener;
 import javax.swing.plaf.FontUIResource;
 
 import org.jdesktop.swingx.*;
-import org.jvnet.lafwidget.LAFAdapter;
 import org.jvnet.lafwidget.LafWidget;
 import org.jvnet.lafwidget.tabbed.DefaultTabPreviewPainter;
 import org.jvnet.lafwidget.utils.LafConstants.TabOverviewKind;
 import org.jvnet.substance.SubstanceLookAndFeel;
 import org.jvnet.substance.api.SubstanceConstants.Side;
 import org.jvnet.substance.api.SubstanceConstants.TabCloseKind;
+import org.jvnet.substance.api.skin.SubstanceGeminiLookAndFeel;
 import org.jvnet.substance.api.tabbed.*;
 import org.jvnet.substance.fonts.FontSet;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
 import org.jvnet.substance.skin.SkinChangeListener;
-import org.jvnet.substance.skin.SubstanceTwilightLookAndFeel;
 import org.jvnet.substance.utils.SubstanceImageCreator;
 
 import test.check.*;
@@ -214,8 +213,8 @@ public class Check extends JFrame {
 				JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
 		SubstanceLookAndFeel.setDecorationType(scrollPane,
 				DecorationAreaType.GENERAL);
-		scrollPane.setOpaque(false);
-		scrollPane.getViewport().setOpaque(false);
+		// scrollPane.setOpaque(false);
+		// scrollPane.getViewport().setOpaque(false);
 
 		JPanel mainPanel = new JPanel();
 		mainPanel.add(scrollPane);
@@ -260,13 +259,22 @@ public class Check extends JFrame {
 		setMinimumSize(getPreferredSize());
 
 		ButtonsPanel buttonsPanel = new ButtonsPanel();
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Buttons", getIcon("JButtonColor16"), buttonsPanel);
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 		getRootPane().setDefaultButton(buttonsPanel.defaultButton);
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Combo box", getIcon("JComboBoxColor16"), new CombosPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Scroll pane", getIcon("JScrollPaneColor16"),
 				new ScrollPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
 		TabCloseCallback closeCallback = new TabCloseCallback() {
 			public TabCloseKind onAreaClick(JTabbedPane tabbedPane,
@@ -310,42 +318,79 @@ public class Check extends JFrame {
 		};
 
 		try {
+			// System.out.println(System.currentTimeMillis());
 			TabPanel tp = new TabPanel();
 			tp.jtp.putClientProperty(
 					SubstanceLookAndFeel.TABBED_PANE_CLOSE_CALLBACK,
 					closeCallback);
 			jtp.addTab("Tabbed pane", getIcon("JTabbedPaneColor16"), tp);
+			// System.out.println(System.currentTimeMillis() +
+			// jtp.getTitleAt(jtp.getTabCount()-1));
 		} catch (NoClassDefFoundError ncdfe) {
 		}
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Split", new SplitPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Desktop", getIcon("JDesktopPaneColor16"),
 				new DesktopPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Text fields", getIcon("JTextPaneColor16"),
 				new TextFieldsPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Table", getIcon("JTableColor16"), new TablePanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
 		try {
+			// System.out.println(System.currentTimeMillis());
 			jtp.addTab("List", getIcon("JListColor16"), new ListPanel());
+			// System.out.println(System.currentTimeMillis() +
+			// jtp.getTitleAt(jtp.getTabCount()-1));
 		} catch (NoClassDefFoundError ncdfe) {
 		}
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Slider", getIcon("JSliderColor16"), new SliderPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Progress bar", getIcon("JProgressBarColor16"),
 				new ProgressBarPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Spinner", getIcon("JSpinnerColor16"), new SpinnerPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Tree", getIcon("JTreeColor16"), new TreePanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("File tree", getIcon("JTreeColor16"), new FileTreePanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Cards", new CardPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		JPanel verticalButtonPanel = new JPanel();
 		verticalButtonPanel.setLayout(new GridLayout(1, 3));
 		verticalButtonPanel.add(new JButton("Vert button 1"));
@@ -361,19 +406,36 @@ public class Check extends JFrame {
 		}
 		verticalButtonPanel.add(smallVerticalButtonPanel);
 		jtp.addTab("Vertical buttons", verticalButtonPanel);
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Colored", new ColoredControlsPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Colorized", new ColorizedControlsPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Cells", new CellsPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
-		JPanel buttonStripPanel = new JPanel();
-		buttonStripPanel.setLayout(new FlowLayout());
+		// buttonStripPanel = new JPanel();
+		// buttonStripPanel.setLayout(new FlowLayout());
 
+		// System.out.println(System.currentTimeMillis());
 		jtp.addTab("Sizes", new SizesPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
-		jtp.addTab("Alignment", AlignmentPanel.getAlignmentPanel());
+		// System.out.println(System.currentTimeMillis());
+		jtp.addTab("Alignment", new AlignmentPanel());
+		// System.out.println(System.currentTimeMillis() +
+		// jtp.getTitleAt(jtp.getTabCount()-1));
 
 		// sample menu bar
 		JMenuBar jmb = new JMenuBar();
@@ -630,13 +692,13 @@ public class Check extends JFrame {
 					// JNLP sandbox
 				}
 
-				LAFAdapter.startWidget();
+				// LAFAdapter.startWidget();
 
 				try {
 					if (!hasLafSpecified) {
 						out(" CREATING LAF ");
 						long time0 = System.currentTimeMillis();
-						LookAndFeel laf = new SubstanceTwilightLookAndFeel();
+						LookAndFeel laf = new SubstanceGeminiLookAndFeel();
 						long time1 = System.currentTimeMillis();
 						out(" LAF CREATED " + (time1 - time0));
 						out(" SETTING LAF ");
@@ -842,6 +904,12 @@ public class Check extends JFrame {
 	public class TabSwitchListener implements ChangeListener {
 		public void stateChanged(ChangeEvent e) {
 			Component selected = jtp.getSelectedComponent();
+			if (selected instanceof Deferrable) {
+				Deferrable deferrable = (Deferrable) selected;
+				if (!deferrable.isInitialized())
+					deferrable.initialize();
+			}
+
 			if (selected instanceof Controllable) {
 				JPanel controlPanel = ((Controllable) selected)
 						.getControlPanel();
