@@ -30,19 +30,15 @@
 package test.check;
 
 import java.awt.*;
-import java.util.Map;
+import java.util.EnumSet;
 
 import javax.swing.*;
 
 import org.jvnet.lafwidget.LafWidget;
 import org.jvnet.lafwidget.utils.LafConstants.AnimationKind;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.border.BorderPainterInfo;
-import org.jvnet.substance.button.ButtonShaperInfo;
-import org.jvnet.substance.painter.GradientPainterInfo;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.utils.SubstanceConstants.FocusKind;
-import org.jvnet.substance.utils.SubstanceConstants.Side;
+import org.jvnet.substance.api.SubstanceConstants.FocusKind;
+import org.jvnet.substance.api.SubstanceConstants.Side;
 
 import test.Check;
 import test.check.command.*;
@@ -62,193 +58,6 @@ public class ButtonsPanel extends JPanel {
 	 */
 	public JButton defaultButton;
 
-	// /**
-	// * A configure command that disables the specified button.
-	// *
-	// * @author Kirill Grouchnikov
-	// */
-	// private class DisableCommand implements
-	// ConfigurationCommand<AbstractButton> {
-	// /*
-	// * (non-Javadoc)
-	// *
-	// * @see test.check.ConfigurationCommand#invoke(java.lang.Object)
-	// */
-	// public void configure(AbstractButton ab) {
-	// ab.setEnabled(false);
-	// }
-	// }
-
-	// /**
-	// * A configure command that selects the specified button.
-	// *
-	// * @author Kirill Grouchnikov
-	// */
-	// private class SelectCommand implements
-	// ConfigurationCommand<AbstractButton> {
-	// /*
-	// * (non-Javadoc)
-	// *
-	// * @see test.check.ConfigurationCommand#invoke(java.lang.Object)
-	// */
-	// public void configure(AbstractButton ab) {
-	// if (ab instanceof JButton)
-	// return;
-	// ab.setSelected(true);
-	// }
-	// }
-
-	/**
-	 * A configure command that sets a specified theme on the specified button.
-	 * 
-	 * @author Kirill Grouchnikov
-	 */
-	private class ThemeCommand implements ConfigurationCommand<AbstractButton> {
-		/**
-		 * Theme object.
-		 */
-		private Object themeObj;
-
-		/**
-		 * Creates the theme configuration command.
-		 * 
-		 * @param themeObj
-		 *            Theme object.
-		 */
-		public ThemeCommand(Object themeObj) {
-			this.themeObj = themeObj;
-		}
-
-		/*
-		 * (non-Javadoc)
-		 * 
-		 * @see test.check.ConfigurationCommand#invoke(java.lang.Object)
-		 */
-		public void configure(AbstractButton ab) {
-			ab.putClientProperty(SubstanceLookAndFeel.THEME_PROPERTY, themeObj);
-		}
-	}
-
-	/**
-	 * A configure command that applies the specified button shaper on the
-	 * specified button.
-	 * 
-	 * @author Kirill Grouchnikov
-	 */
-	private class ShaperCommand implements ConfigurationCommand<AbstractButton> {
-		/**
-		 * Button shaper object.
-		 */
-		private Object shaperObj;
-
-		/**
-		 * Creates the button shaper configuration command.
-		 * 
-		 * @param shaperObj
-		 *            Button shaper object.
-		 */
-		public ShaperCommand(Object shaperObj) {
-			this.shaperObj = shaperObj;
-		}
-
-		/*
-		 * (non-Javadoc)
-		 * 
-		 * @see test.check.ConfigurationCommand#invoke(java.lang.Object)
-		 */
-		public void configure(AbstractButton ab) {
-			ab.putClientProperty(SubstanceLookAndFeel.BUTTON_SHAPER_PROPERTY,
-					shaperObj);
-		}
-	}
-
-	/**
-	 * A configure command that sets the specified gradient painter on the
-	 * specified button.
-	 * 
-	 * @author Kirill Grouchnikov
-	 */
-	private class GradientPainterCommand implements
-			ConfigurationCommand<AbstractButton> {
-		/**
-		 * Gradient painter object.
-		 */
-		private Object painterObj;
-
-		/**
-		 * Creates the gradient painter configuration command.
-		 * 
-		 * @param painterObj
-		 *            Gradient painter object.
-		 */
-		public GradientPainterCommand(Object painterObj) {
-			this.painterObj = painterObj;
-		}
-
-		/*
-		 * (non-Javadoc)
-		 * 
-		 * @see test.check.ConfigurationCommand#invoke(java.lang.Object)
-		 */
-		public void configure(AbstractButton ab) {
-			ab.putClientProperty(
-					SubstanceLookAndFeel.GRADIENT_PAINTER_PROPERTY, painterObj);
-		}
-	}
-
-	/**
-	 * A configure command that sets the specified border painter on the
-	 * specified button.
-	 * 
-	 * @author Kirill Grouchnikov
-	 */
-	private class BorderPainterCommand implements
-			ConfigurationCommand<AbstractButton> {
-		/**
-		 * Gradient painter object.
-		 */
-		private Object painterObj;
-
-		/**
-		 * Creates the gradient painter configuration command.
-		 * 
-		 * @param painterObj
-		 *            Gradient painter object.
-		 */
-		public BorderPainterCommand(Object painterObj) {
-			this.painterObj = painterObj;
-		}
-
-		/*
-		 * (non-Javadoc)
-		 * 
-		 * @see test.check.ConfigurationCommand#invoke(java.lang.Object)
-		 */
-		public void configure(AbstractButton ab) {
-			ab.putClientProperty(SubstanceLookAndFeel.BORDER_PAINTER_PROPERTY,
-					painterObj);
-		}
-	}
-
-	/**
-	 * A configure command that marks the specified button to always be painted
-	 * in active state.
-	 * 
-	 * @author Kirill Grouchnikov
-	 */
-	private class PaintActiveCommand implements
-			ConfigurationCommand<AbstractButton> {
-		/*
-		 * (non-Javadoc)
-		 * 
-		 * @see test.check.ConfigurationCommand#invoke(java.lang.Object)
-		 */
-		public void configure(AbstractButton ab) {
-			ab.putClientProperty(SubstanceLookAndFeel.PAINT_ACTIVE_PROPERTY,
-					Boolean.TRUE);
-		}
-	}
-
 	/**
 	 * A configure command that removes the focus painting from the specified
 	 * button.
@@ -284,7 +93,7 @@ public class ButtonsPanel extends JPanel {
 		 * Creates the focus painting configuration command.
 		 * 
 		 * @param focusKind
-		 *            Focus painting kind.
+		 * 		Focus painting kind.
 		 */
 		public FocusKindCommand(FocusKind focusKind) {
 			this.focusKind = focusKind;
@@ -317,7 +126,7 @@ public class ButtonsPanel extends JPanel {
 		 * Creates a new animation configuration command.
 		 * 
 		 * @param animationKind
-		 *            Animation kind.
+		 * 		Animation kind.
 		 */
 		public AnimationKindCommand(AnimationKind animationKind) {
 			this.animationKind = animationKind;
@@ -385,7 +194,7 @@ public class ButtonsPanel extends JPanel {
 		 * Creates a straight side configuration command.
 		 * 
 		 * @param sideObj
-		 *            Straight side object.
+		 * 		Straight side object.
 		 */
 		public StraightSideCommand(Object sideObj) {
 			this.sideObj = sideObj;
@@ -418,7 +227,7 @@ public class ButtonsPanel extends JPanel {
 		 * Creates an open side configuration command.
 		 * 
 		 * @param sideObj
-		 *            Open side object.
+		 * 		Open side object.
 		 */
 		public OpenSideCommand(Object sideObj) {
 			this.sideObj = sideObj;
@@ -451,7 +260,7 @@ public class ButtonsPanel extends JPanel {
 		 * Creates a text configuration command.
 		 * 
 		 * @param text
-		 *            Text to set.
+		 * 		Text to set.
 		 */
 		public TextCommand(String text) {
 			this.text = text;
@@ -484,7 +293,7 @@ public class ButtonsPanel extends JPanel {
 		 * Creates a tooltip text configuration command.
 		 * 
 		 * @param tooltipText
-		 *            Tooltip text to set.
+		 * 		Tooltip text to set.
 		 */
 		public TooltipTextCommand(String tooltipText) {
 			this.tooltipText = tooltipText;
@@ -533,7 +342,7 @@ public class ButtonsPanel extends JPanel {
 		 * Creates a font configuration command.
 		 * 
 		 * @param font
-		 *            Font to set.
+		 * 		Font to set.
 		 */
 		public FontCommand(Font font) {
 			this.font = font;
@@ -564,7 +373,7 @@ public class ButtonsPanel extends JPanel {
 		 * Creates an icon configuration command.
 		 * 
 		 * @param icon
-		 *            Icon to set.
+		 * 		Icon to set.
 		 */
 		public IconCommand(Icon icon) {
 			this.icon = icon;
@@ -618,13 +427,13 @@ public class ButtonsPanel extends JPanel {
 	}
 
 	/**
-	 * Returns a row of buttons, consisting of {@link JButton},
-	 * {@link JToggleButton}, {@link JCheckBox} and {@link JRadioButton} in
-	 * default states.
+	 * Returns a row of buttons, consisting of {@link JButton}, {@link
+	 * JToggleButton}, {@link JCheckBox} and {@link JRadioButton} in default
+	 * states.
 	 * 
-	 * @return A row of buttons, consisting of {@link JButton},
-	 *         {@link JToggleButton}, {@link JCheckBox} and
-	 *         {@link JRadioButton} in default states.
+	 * @return A row of buttons, consisting of {@link JButton}, {@link
+	 * 	JToggleButton}, {@link JCheckBox} and {@link JRadioButton} in default
+	 * 	states.
 	 */
 	private AbstractButton[] getRow() {
 		AbstractButton[] result = new AbstractButton[4];
@@ -647,13 +456,13 @@ public class ButtonsPanel extends JPanel {
 	 * configuration command.
 	 * 
 	 * @param builder
-	 *            Form builder.
+	 * 		Form builder.
 	 * @param label
-	 *            Text to set.
+	 * 		Text to set.
 	 * @param icon
-	 *            Icon to set.
+	 * 		Icon to set.
 	 * @param cmd
-	 *            Configuration command to apply.
+	 * 		Configuration command to apply.
 	 */
 	private void addRow(DefaultFormBuilder builder, String label, Icon icon,
 			ConfigurationCommand<? super AbstractButton> cmd) {
@@ -716,6 +525,8 @@ public class ButtonsPanel extends JPanel {
 						new SelectCommand()));
 		this.addRow(builder, "HTML text", null, new TextCommand(
 				"<html>text <b>text</b> <font color='red'>text</font>"));
+		this.addRow(builder, "Long text", null, new TextCommand(
+				"Some long long text"));
 		this.addRow(builder, "With tooltip", null, new TooltipTextCommand(
 				"Sample tooltip"));
 		this
@@ -726,25 +537,6 @@ public class ButtonsPanel extends JPanel {
 		this.addRow(builder, "With icon", Check.getIcon("flag_sweden"),
 				new IconCommand(Check.getIcon("flag_sweden")));
 
-		builder.appendSeparator("Color settings");
-		this.addRow(builder, "Barby Pink", null, new ThemeCommand(
-				new SubstanceBarbyPinkTheme()));
-		this.addRow(builder, "Bottle Green", null, new ThemeCommand(
-				"Bottle Green"));
-		this.addRow(builder, "Steel Blue", null, new ThemeCommand(
-				new SubstanceSteelBlueTheme()));
-		this.addRow(builder, "Aqua & Sunset", null, new ThemeCommand(
-				new SubstanceMixTheme(new SubstanceAquaTheme(),
-						new SubstanceSunsetTheme())));
-		this.addRow(builder, "Green & Pink", null, new ThemeCommand(
-				new SubstanceMixTheme(new SubstanceLimeGreenTheme(),
-						new SubstanceBarbyPinkTheme())));
-		this.addRow(builder, "Always active", null, new PaintActiveCommand());
-		this.addRow(builder, "Always green", null,
-				new ChainCommand<AbstractButton>(new ThemeCommand(
-						new SubstanceBottleGreenTheme()),
-						new PaintActiveCommand()));
-
 		builder.appendSeparator("Focus indications");
 		this.addRow(builder, "No focus painted", null, new NoFocusCommand());
 		this
@@ -781,33 +573,28 @@ public class ButtonsPanel extends JPanel {
 
 		builder.appendSeparator("Side settings");
 		this.addRow(builder, "Straight top", null, new StraightSideCommand(
-				Side.TOP.name()));
+				Side.TOP));
 		this.addRow(builder, "Straight bottom", null, new StraightSideCommand(
 				Side.BOTTOM));
 		this.addRow(builder, "Straight left", null, new StraightSideCommand(
-				new String[] { Side.LEFT.name() }));
+				EnumSet.of(Side.LEFT)));
 		this.addRow(builder, "Straight right", null, new StraightSideCommand(
-				new Side[] { Side.RIGHT }));
+				EnumSet.of(Side.RIGHT)));
 
-		this
-				.addRow(builder, "Open top", null,
-						new ChainCommand<AbstractButton>(
-								new StraightSideCommand(Side.TOP.name()),
-								new OpenSideCommand(Side.TOP.name())));
+		this.addRow(builder, "Open top", null,
+				new ChainCommand<AbstractButton>(new StraightSideCommand(
+						Side.TOP), new OpenSideCommand(Side.TOP)));
 		this.addRow(builder, "Open bottom", null,
 				new ChainCommand<AbstractButton>(new StraightSideCommand(
 						Side.BOTTOM), new OpenSideCommand(Side.BOTTOM)));
-		this
-				.addRow(builder, "Open left", null,
-						new ChainCommand<AbstractButton>(
-								new StraightSideCommand(
-										new String[] { Side.LEFT.name() }),
-								new OpenSideCommand(new String[] { Side.LEFT
-										.name() })));
+		this.addRow(builder, "Open left", null,
+				new ChainCommand<AbstractButton>(new StraightSideCommand(
+						EnumSet.of(Side.LEFT)), new OpenSideCommand(EnumSet
+						.of(Side.LEFT))));
 		this.addRow(builder, "Open right", null,
 				new ChainCommand<AbstractButton>(new StraightSideCommand(
-						new Side[] { Side.RIGHT }), new OpenSideCommand(
-						new Side[] { Side.RIGHT })));
+						EnumSet.of(Side.RIGHT)), new OpenSideCommand(EnumSet
+						.of(Side.RIGHT))));
 
 		builder.appendSeparator("Unicode texts");
 		this.addRow(builder, "Hebrew", null, new ChainCommand<AbstractButton>(
@@ -828,48 +615,6 @@ public class ButtonsPanel extends JPanel {
 				new TextCommand("\u00E6\u00F0\u0127\u2248"), new IconCommand(
 						Check.getIcon("flag_italy"))));
 
-		if (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel) {
-			builder.appendSeparator("Shaper settings");
-			Map<String, ButtonShaperInfo> allButtonShapers = SubstanceLookAndFeel
-					.getAllButtonShapers();
-			for (ButtonShaperInfo bsi : allButtonShapers.values()) {
-				try {
-					this.addRow(builder, bsi.getDisplayName(), null,
-							new ShaperCommand(Class.forName(bsi.getClassName())
-									.newInstance()));
-				} catch (Exception exc) {
-				}
-			}
-		}
-
-		if (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel) {
-			builder.appendSeparator("Gradient painter settings");
-			Map<String, GradientPainterInfo> allGradientPainters = SubstanceLookAndFeel
-					.getAllGradientPainters();
-			for (GradientPainterInfo gpi : allGradientPainters.values()) {
-				try {
-					this.addRow(builder, gpi.getDisplayName(), null,
-							new GradientPainterCommand(Class.forName(
-									gpi.getClassName()).newInstance()));
-				} catch (Exception exc) {
-				}
-			}
-		}
-
-		if (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel) {
-			builder.appendSeparator("Border painter settings");
-			Map<String, BorderPainterInfo> allBorderPainters = SubstanceLookAndFeel
-					.getAllBorderPainters();
-			for (BorderPainterInfo bpi : allBorderPainters.values()) {
-				try {
-					this.addRow(builder, bpi.getDisplayName(), null,
-							new BorderPainterCommand(Class.forName(
-									bpi.getClassName()).newInstance()));
-				} catch (Exception exc) {
-				}
-			}
-		}
-
 		builder.appendSeparator("Misc settings");
 		this.addRow(builder, "No content area", null,
 				new NoContentAreaFilledCommand());
