@@ -51,20 +51,27 @@ import com.jgoodies.forms.layout.FormLayout;
  * 
  * @author Kirill Grouchnikov
  */
-public class ColorizedControlsPanel extends JPanel {
+public class ColorizedControlsPanel extends JPanel implements Deferrable {
 	/**
 	 * The default button.
 	 */
 	public JButton defaultButton;
+	
+	private boolean isInitialized;
+
+	@Override
+	public boolean isInitialized() {
+		return this.isInitialized;
+	}
 
 	/**
-	 * Returns a row of buttons, consisting of {@link JButton}, {@link
-	 * JToggleButton}, {@link JCheckBox} and {@link JRadioButton} in default
-	 * states.
+	 * Returns a row of buttons, consisting of {@link JButton},
+	 * {@link JToggleButton}, {@link JCheckBox} and {@link JRadioButton} in
+	 * default states.
 	 * 
-	 * @return A row of buttons, consisting of {@link JButton}, {@link
-	 * 	JToggleButton}, {@link JCheckBox} and {@link JRadioButton} in default
-	 * 	states.
+	 * @return A row of buttons, consisting of {@link JButton},
+	 *         {@link JToggleButton}, {@link JCheckBox} and {@link JRadioButton}
+	 *         in default states.
 	 */
 	private AbstractButton[] getRow() {
 		AbstractButton[] result = new AbstractButton[4];
@@ -80,13 +87,13 @@ public class ColorizedControlsPanel extends JPanel {
 	 * configuration command.
 	 * 
 	 * @param builder
-	 * 		Form builder.
+	 *            Form builder.
 	 * @param label
-	 * 		Text to set.
+	 *            Text to set.
 	 * @param icon
-	 * 		Icon to set.
+	 *            Icon to set.
 	 * @param configurationCmd
-	 * 		Configuration command to apply.
+	 *            Configuration command to apply.
 	 */
 	private void addButtonRow(DefaultFormBuilder builder, String label,
 			Icon icon, ConfigurationCommand<Component> configurationCmd) {
@@ -111,13 +118,13 @@ public class ColorizedControlsPanel extends JPanel {
 	 * command.
 	 * 
 	 * @param builder
-	 * 		Form builder.
+	 *            Form builder.
 	 * @param label
-	 * 		Text to set.
+	 *            Text to set.
 	 * @param creationCmd
-	 * 		Creation command.
+	 *            Creation command.
 	 * @param configurationCmd
-	 * 		Configuration command to apply.
+	 *            Configuration command to apply.
 	 */
 	private void addControlRow(DefaultFormBuilder builder, String label,
 			CreationCommand<Component> creationCmd,
@@ -164,7 +171,10 @@ public class ColorizedControlsPanel extends JPanel {
 	@SuppressWarnings("unchecked")
 	public ColorizedControlsPanel() {
 		this.setLayout(new BorderLayout());
+	}
 
+	@Override
+	public synchronized void initialize() {
 		FormLayout lmButtons = new FormLayout(
 				"right:pref, 10dlu, left:pref:grow(1), 4dlu,"
 						+ "left:pref:grow(1), 4dlu, left:pref:grow(1), "
@@ -1060,5 +1070,7 @@ public class ColorizedControlsPanel extends JPanel {
 		});
 		controls.add(colorizationSlider);
 		this.add(controls, BorderLayout.NORTH);
+
+		this.isInitialized = true;
 	}
 }
