@@ -50,7 +50,14 @@ import com.jgoodies.forms.layout.FormLayout;
  * 
  * @author Kirill Grouchnikov
  */
-public class CombosPanel extends ControllablePanel {
+public class CombosPanel extends ControllablePanel implements Deferrable {
+	private boolean isInitialized;
+
+	@Override
+	public boolean isInitialized() {
+		return this.isInitialized;
+	}
+
 	/**
 	 * A configure command that allows editing the specified combobox.
 	 * 
@@ -473,7 +480,10 @@ public class CombosPanel extends ControllablePanel {
 	 */
 	public CombosPanel() {
 		this.setLayout(new BorderLayout());
-
+	}
+	
+	@Override
+	public synchronized void initialize() {
 		JPanel gridPanel = new ScrollablePanel();
 		gridPanel.setLayout(new GridLayout(1, 2));
 		gridPanel.add(getLeftComboPanel());
@@ -572,5 +582,7 @@ public class CombosPanel extends ControllablePanel {
 		builder.append(checkEscape);
 
 		this.controlPanel = builder.getPanel();
+		
+		this.isInitialized = true;
 	}
 }
