@@ -459,7 +459,9 @@ public class ControlPanelFactory {
 		});
 		builder.append("Menu locale", menuLocale);
 
-		return builder.getPanel();
+		JPanel result = builder.getPanel();
+		result.setName("Main control panel");
+		return result;
 	}
 
 	/**
@@ -841,15 +843,23 @@ public class ControlPanelFactory {
 						dialog.setContentPane(myContentPane);
 
 						JTabbedPane tabs = new JTabbedPane();
-						tabs.addTab("Foo", new JButton("Test"));
-						tabs.addTab("Bar", new JLabel());
+						JPanel tab1 = new JPanel(new FlowLayout());
+						tab1.add(new JLabel("test"));
+						JTextField tab1TextField = new JTextField("some text");
+						tab1TextField.putClientProperty(
+								LafWidget.TEXT_FLIP_SELECT_ON_ESCAPE,
+								Boolean.TRUE);
+						tab1.add(tab1TextField);
+						tabs.addTab("Foo", tab1);
+						JPanel tab2 = new JPanel(new FlowLayout());
+						tab2.add(new JButton("Test"));
+						tabs.addTab("Bar", tab2);
 						dialog.add(tabs, BorderLayout.CENTER);
-						// add(new JButton("Test"), BorderLayout.CENTER);
 
 						dialog.add(new JLabel("Press Esc to close dialog"),
 								BorderLayout.NORTH);
 
-						// connect "Esc" key with "System.exit(0)"
+						// connect "Esc" key with disposing the dialog
 						String actionName = "VK_ESCAPE";
 						Action action = new AbstractAction(actionName) {
 							public void actionPerformed(ActionEvent e) {
