@@ -39,18 +39,16 @@ import javax.swing.*;
 import javax.swing.JInternalFrame.JDesktopIcon;
 import javax.swing.plaf.basic.BasicInternalFrameUI;
 
-import org.jvnet.substance.SubstanceImageCreator;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.watermark.WatermarkInfo;
+import org.jvnet.substance.skin.SkinChangeListener;
+import org.jvnet.substance.utils.SubstanceImageCreator;
 
 import com.jgoodies.forms.builder.DefaultFormBuilder;
 import com.jgoodies.forms.layout.FormLayout;
 
 /**
- * Test application panel for testing {@link JDesktopPane},
- * {@link JInternalFrame} and {@link JDesktopIcon} components.
+ * Test application panel for testing {@link JDesktopPane}, {@link
+ * JInternalFrame} and {@link JDesktopIcon} components.
  * 
  * @author Kirill Grouchnikov
  */
@@ -79,7 +77,8 @@ public class DesktopPanel extends ControllablePanel {
 		this.add(jdp, BorderLayout.CENTER);
 
 		FormLayout lm = new FormLayout("right:pref, 4dlu, fill:pref:grow", "");
-		DefaultFormBuilder builder = new DefaultFormBuilder(lm, new ScrollablePanel());
+		DefaultFormBuilder builder = new DefaultFormBuilder(lm,
+				new ScrollablePanel());
 		builder.appendSeparator("New sample frame");
 
 		JButton sample = new JButton("Add");
@@ -137,41 +136,23 @@ public class DesktopPanel extends ControllablePanel {
 					title += "0";
 				}
 				final JInternalFrame jif = new JInternalFrame(title);
-				// {
-				// @Override
-				// public void paint(Graphics g) {
-				// long start = System.nanoTime();
-				// super.paint(g);
-				// long end = System.nanoTime();
-				// System.err.println("paint done in " + (end - start));
-				// }
-				//
-				// @Override
-				// public void setLocation(int x, int y) {
-				// super.setLocation(x, y);
-				// }
-				//
-				// @Override
-				// public void setSize(int width, int height) {
-				// super.setSize(width, height);
-				// }
-				//
-				// @Override
-				// public void setBounds(int x, int y, int width, int height) {
-				// super.setBounds(x, y, width, height);
-				// }
-				//
-				// };
 				jif.setFrameIcon(new ImageIcon(SubstanceImageCreator
 						.getBigHexaMarker(count, SubstanceLookAndFeel
-								.getTheme())));
+								.getCurrentSkin(jif.getRootPane())
+								.getMainActiveColorScheme())));
 				SubstanceLookAndFeel
-						.registerThemeChangeListener(new ThemeChangeListener() {
-							public void themeChanged() {
-								jif.setFrameIcon(new ImageIcon(
-										SubstanceImageCreator.getBigHexaMarker(
-												count, SubstanceLookAndFeel
-														.getTheme())));
+						.registerSkinChangeListener(new SkinChangeListener() {
+							public void skinChanged() {
+								jif
+										.setFrameIcon(new ImageIcon(
+												SubstanceImageCreator
+														.getBigHexaMarker(
+																count,
+																SubstanceLookAndFeel
+																		.getCurrentSkin(
+																				jif
+																						.getRootPane())
+																		.getMainActiveColorScheme())));
 							}
 						});
 				jif.setLayout(new BorderLayout());
@@ -298,105 +279,7 @@ public class DesktopPanel extends ControllablePanel {
 				jdp.add(jif, 1);
 
 				JMenuBar jmb = new JMenuBar();
-
-				if (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel) {
-					Map<String, ThemeInfo> allThemes = SubstanceLookAndFeel
-							.getAllThemes();
-
-					JMenu jmTheme = new JMenu("Theme");
-					JMenu jmInvertedTheme = SubstanceLookAndFeel
-							.toEnableInvertedThemes() ? new JMenu(
-							"Inverted theme") : null;
-
-					ButtonGroup bgTheme = new ButtonGroup();
-					for (Map.Entry<String, ThemeInfo> themeEntry : allThemes
-							.entrySet()) {
-						String themeName = themeEntry.getKey();
-						final ThemeInfo themeInfo = themeEntry.getValue();
-						final String themeClassName = themeInfo.getClassName();
-
-						JRadioButtonMenuItem jmiTheme = new JRadioButtonMenuItem(
-								themeName);
-						try {
-							Class<?> themeClass = Class.forName(themeClassName);
-							SubstanceTheme theme = (SubstanceTheme) themeClass
-									.newInstance();
-							if (themeInfo.getThemeKind() == ThemeKind.INVERTED)
-								theme = new SubstanceInvertedTheme(theme);
-							jmiTheme.setIcon(SubstanceImageCreator
-									.getThemeIcon(theme));
-						} catch (Exception exc) {
-							continue;
-						}
-
-						jmiTheme.addActionListener(new ActionListener() {
-							public void actionPerformed(ActionEvent e) {
-								try {
-									if ((themeInfo.getThemeKind() == ThemeKind.INVERTED)
-											|| (themeInfo.getThemeKind() == ThemeKind.NEGATED)) {
-										SubstanceLookAndFeel
-												.setCurrentTheme(themeInfo);
-									} else {
-										SubstanceLookAndFeel
-												.setCurrentTheme(themeClassName);
-									}
-									// UIManager
-									// .setLookAndFeel(new
-									// SubstanceLookAndFeel());
-								} catch (Exception exc) {
-									exc.printStackTrace();
-								}
-								for (Frame frame : Frame.getFrames())
-									SwingUtilities.updateComponentTreeUI(frame);
-							}
-						});
-						if (themeName.equals(SubstanceLookAndFeel
-								.getCurrentThemeName())) {
-							jmiTheme.setSelected(true);
-						}
-						bgTheme.add(jmiTheme);
-
-						if (themeEntry.getValue().getThemeKind() == ThemeKind.INVERTED)
-							jmInvertedTheme.add(jmiTheme);
-						else
-							jmTheme.add(jmiTheme);
-					}
-
-					jmb.add(jmTheme);
-					if (jmInvertedTheme != null)
-						jmb.add(jmInvertedTheme);
-
-					JMenu jmWatermark = new JMenu("Watermark");
-
-					ButtonGroup bgWatermark = new ButtonGroup();
-					Map<String, WatermarkInfo> allWatermarks = SubstanceLookAndFeel
-							.getAllWatermarks();
-					for (Map.Entry<String, WatermarkInfo> watermarkEntry : allWatermarks
-							.entrySet()) {
-						String watermarkName = watermarkEntry.getKey();
-						final String watermarkClassName = watermarkEntry
-								.getValue().getClassName();
-
-						JRadioButtonMenuItem jmiWatermark = new JRadioButtonMenuItem(
-								watermarkName);
-						jmiWatermark.addActionListener(new ActionListener() {
-							public void actionPerformed(ActionEvent e) {
-								SubstanceLookAndFeel
-										.setCurrentWatermark(watermarkClassName);
-								for (Frame frame : Frame.getFrames())
-									SwingUtilities.updateComponentTreeUI(frame);
-							}
-						});
-						if (watermarkName.equals(SubstanceLookAndFeel
-								.getCurrentWatermarkName())) {
-							jmiWatermark.setSelected(true);
-						}
-						bgWatermark.add(jmiWatermark);
-						jmWatermark.add(jmiWatermark);
-					}
-
-					jmWatermark.addSeparator();
-				}
+				jmb.add(SampleMenuFactory.getSkinMenu());
 
 				JMenu jm1 = new JMenu("Menu1");
 				jm1.setMnemonic('1');
