@@ -55,7 +55,14 @@ import com.jgoodies.forms.layout.FormLayout;
  * 
  * @author Kirill Grouchnikov
  */
-public class FileTreePanel extends ControllablePanel {
+public class FileTreePanel extends ControllablePanel implements Deferrable {
+	private boolean isInitialized;
+
+	@Override
+	public boolean isInitialized() {
+		return this.isInitialized;
+	}
+
 	/**
 	 * File system view.
 	 */
@@ -366,7 +373,9 @@ public class FileTreePanel extends ControllablePanel {
 	 */
 	public FileTreePanel() {
 		this.setLayout(new BorderLayout());
-
+	}
+	
+	public synchronized void initialize() {
 		List<File> rootsList = new ArrayList<File>();
 		for (File child : File.listRoots()) {
 			rootsList.add(child);
@@ -429,5 +438,6 @@ public class FileTreePanel extends ControllablePanel {
 		builder.append("Decorations", cbTreeSmartScroll);
 
 		this.controlPanel = builder.getPanel();
+		this.isInitialized = true;
 	}
 }
\ No newline at end of file
