@@ -41,7 +41,8 @@ import javax.swing.event.*;
 import org.jvnet.lafwidget.LafWidget;
 import org.jvnet.lafwidget.utils.LafConstants.AnimationKind;
 import org.jvnet.substance.*;
-import org.jvnet.substance.combo.WidestComboPopupPrototype;
+import org.jvnet.substance.api.combo.WidestComboPopupPrototype;
+import org.jvnet.substance.api.renderers.SubstanceDefaultListCellRenderer;
 
 import com.jgoodies.forms.builder.DefaultFormBuilder;
 import com.jgoodies.forms.layout.FormLayout;
@@ -167,11 +168,6 @@ public class ListPanel extends ControllablePanel {
 	 */
 	private Color oldBackColor;
 
-	/**
-	 * Old list cell renderer.
-	 */
-	private ListCellRenderer oldListCellRenderer;
-
 	/**
 	 * Creates a new list panel.
 	 */
@@ -184,7 +180,8 @@ public class ListPanel extends ControllablePanel {
 		this.add(jsp, BorderLayout.CENTER);
 
 		FormLayout lm = new FormLayout("right:pref, 4dlu, fill:pref:grow", "");
-		DefaultFormBuilder builder = new DefaultFormBuilder(lm, new ScrollablePanel());
+		DefaultFormBuilder builder = new DefaultFormBuilder(lm,
+				new ScrollablePanel());
 		builder.appendSeparator("General");
 
 		final JCheckBox isEnabled = new JCheckBox("is enabled");
@@ -196,19 +193,6 @@ public class ListPanel extends ControllablePanel {
 		});
 		builder.append("Enabled", isEnabled);
 
-		final JCheckBox toUseSubstanceRenderer = new JCheckBox("use substance");
-		toUseSubstanceRenderer.setSelected(true);
-		toUseSubstanceRenderer.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				if (toUseSubstanceRenderer.isSelected())
-					list
-							.setCellRenderer(new SubstanceDefaultListCellRenderer());
-				else
-					list.setCellRenderer(new DefaultListCellRenderer());
-			}
-		});
-		builder.append("Renderer", toUseSubstanceRenderer);
-
 		final JSlider rowCountSlider = new JSlider(10, 1000, this.list
 				.getModel().getSize());
 		rowCountSlider.setPaintLabels(false);
@@ -225,17 +209,22 @@ public class ListPanel extends ControllablePanel {
 		final JCheckBox watermarkBleed = new JCheckBox("watermark bleed");
 		watermarkBleed.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				list.putClientProperty(SubstanceLookAndFeel.WATERMARK_TO_BLEED,
+				list.putClientProperty(SubstanceLookAndFeel.WATERMARK_VISIBLE,
 						Boolean.valueOf(watermarkBleed.isSelected()));
-				jsp.putClientProperty(SubstanceLookAndFeel.WATERMARK_TO_BLEED,
+				jsp.putClientProperty(SubstanceLookAndFeel.WATERMARK_VISIBLE,
 						Boolean.valueOf(watermarkBleed.isSelected()));
 				list.repaint();
 			}
 		});
 		builder.append("Watermark", watermarkBleed);
-		final JComboBox animCombo = new JComboBox(new Object[] {
+		final JComboBox animCombo = new FlexiComboBox<AnimationKind>(
 				AnimationKind.NONE, AnimationKind.SLOW, AnimationKind.REGULAR,
-				AnimationKind.FAST });
+				AnimationKind.FAST) {
+			@Override
+			public String getCaption(AnimationKind item) {
+				return item.getName();
+			}
+		};
 		animCombo.setSelectedItem(AnimationKind.REGULAR);
 		animCombo.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
@@ -243,16 +232,6 @@ public class ListPanel extends ControllablePanel {
 						.getSelectedItem());
 			}
 		});
-		animCombo.setRenderer(new SubstanceDefaultComboBoxRenderer(animCombo) {
-			@Override
-			public Component getListCellRendererComponent(JList list,
-					Object value, int index, boolean isSelected,
-					boolean cellHasFocus) {
-				AnimationKind ak = (AnimationKind) value;
-				return super.getListCellRendererComponent(list, ak.getName(),
-						index, isSelected, cellHasFocus);
-			}
-		});
 		builder.append("Animation", animCombo);
 
 		bUp = new JButton("Move selected up");
@@ -358,20 +337,50 @@ public class ListPanel extends ControllablePanel {
 
 		builder.append("Background", customBackgroundCb);
 
-		final JCheckBox customRenderer = new JCheckBox("Has custom renderer");
-		customRenderer.addActionListener(new ActionListener() {
+		builder.appendSeparator("Renderer");
+		ButtonGroup listRendererGroup = new ButtonGroup();
+		final JRadioButton substanceRenderer = new JRadioButton("Substance");
+		substanceRenderer.setSelected(true);
+		substanceRenderer.addActionListener(new ActionListener() {
+			@Override
 			public void actionPerformed(ActionEvent e) {
-				if (customRenderer.isSelected()) {
-					oldListCellRenderer = list.getCellRenderer();
-					list.setCellRenderer(new MyListCellRenderer());
-				} else {
-					list.setCellRenderer(oldListCellRenderer);
-				}
+				if (substanceRenderer.isSelected()) 
+					list.setCellRenderer(new SubstanceDefaultListCellRenderer());
 			}
 		});
-
-		builder.append("Renderer", customRenderer);
-
+		final JRadioButton coreDefaultRenderer = new JRadioButton("Default core");
+		coreDefaultRenderer.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				if (coreDefaultRenderer.isSelected()) 
+					list.setCellRenderer(new DefaultListCellRenderer());
+			}
+		});
+		final JRadioButton customRenderer = new JRadioButton("Custom");
+		customRenderer.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				if (customRenderer.isSelected()) 
+					list.setCellRenderer(new MyListCellRenderer());
+			}
+		});
+		final JRadioButton customSubstanceRenderer = new JRadioButton("Custom Substance");
+		customSubstanceRenderer.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				if (customSubstanceRenderer.isSelected()) 
+					list.setCellRenderer(new MySubstanceListCellRenderer());
+			}
+		});
+		listRendererGroup.add(substanceRenderer);
+		listRendererGroup.add(coreDefaultRenderer);
+		listRendererGroup.add(customRenderer);
+		listRendererGroup.add(customSubstanceRenderer);
+		builder.append("Select type", substanceRenderer);
+		builder.append("", coreDefaultRenderer);
+		builder.append("", customRenderer);
+		builder.append("", customSubstanceRenderer);
+		
 		controlPanel = builder.getPanel();
 	}
 
