@@ -62,6 +62,8 @@ public class MyListCellRenderer extends JLabel implements ListCellRenderer {
 
 		int comp = 156 + 10 * (index % 9);
 		this.setBackground(new Color(comp, comp, comp));
+		if (isSelected)
+			this.setBackground(list.getSelectionBackground());
 
 		return this;
 	}
