@@ -34,18 +34,20 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 
 import javax.swing.*;
-import javax.swing.border.TitledBorder;
 
 import org.jvnet.lafwidget.LafWidgetUtilities;
 import org.jvnet.lafwidget.animation.*;
 
+import com.jgoodies.forms.builder.DefaultFormBuilder;
+import com.jgoodies.forms.layout.FormLayout;
+
 /**
  * Test application panel for testing {@link JProgressBar} component.
  * 
  * @author Kirill Grouchnikov
  */
 public class ProgressBarPanel extends JPanel {
-	@RunOnEDT
+	@RunOnUIThread
 	private final class ProgressBarFadeTrackerAdapter extends
 			FadeTrackerAdapter {
 		@Override
@@ -83,82 +85,75 @@ public class ProgressBarPanel extends JPanel {
 
 		JPanel bars = new ScrollablePanel();
 		GridLayout gLayout = new GridLayout(1, 2);
-		gLayout.setHgap(5);
-		gLayout.setVgap(5);
 		bars.setLayout(gLayout);
 
-		JPanel horizPanel = new JPanel();
-		horizPanel.setLayout(new BoxLayout(horizPanel, BoxLayout.Y_AXIS));
-		bars.add(horizPanel);
-
-		JPanel vertPanel = new JPanel();
-		vertPanel.setLayout(new BoxLayout(vertPanel, BoxLayout.X_AXIS));
-		bars.add(vertPanel);
+		FormLayout horizontalLm = new FormLayout("left:pref:grow", "");
+		DefaultFormBuilder horizontalBuilder = new DefaultFormBuilder(
+				horizontalLm);
+		horizontalBuilder.setDefaultDialogBorder();
 
 		JProgressBar determinateEnHor = new JProgressBar(
 				JProgressBar.HORIZONTAL, 0, 100);
 		determinateEnHor.setIndeterminate(false);
-		JPanel dehPanel = new JPanel();
-		dehPanel.add(determinateEnHor);
-		dehPanel.setBorder(new TitledBorder("Determ enabled"));
+		horizontalBuilder.appendSeparator("Determinate enabled");
+		horizontalBuilder.append(determinateEnHor);
 
 		JProgressBar determinateEnHorStr = new JProgressBar(
 				JProgressBar.HORIZONTAL, 0, 100);
 		determinateEnHorStr.setIndeterminate(false);
 		determinateEnHorStr.setStringPainted(true);
-		JPanel dehsPanel = new JPanel();
-		dehsPanel.add(determinateEnHorStr);
-		dehsPanel.setBorder(new TitledBorder("Determ enabled string"));
+		horizontalBuilder.appendSeparator("Determinate enabled + string");
+		horizontalBuilder.append(determinateEnHorStr);
 
 		JProgressBar indeterminateEnHor = new JProgressBar(
 				JProgressBar.HORIZONTAL, 0, 100);
 		indeterminateEnHor.setIndeterminate(true);
 		indeterminateEnHor.setStringPainted(true);
 		indeterminateEnHor.setString("In progress");
-		JPanel iehPanel = new JPanel();
-		iehPanel.add(indeterminateEnHor);
-		iehPanel.setBorder(new TitledBorder("Indeterm enabled"));
-
-		horizPanel.add(dehPanel);
-		horizPanel.add(dehsPanel);
-		horizPanel.add(iehPanel);
+		horizontalBuilder.appendSeparator("Indeterminate enabled + string");
+		horizontalBuilder.append(indeterminateEnHor);
 
 		JProgressBar determinateDisHor = new JProgressBar(
 				JProgressBar.HORIZONTAL, 0, 100);
 		determinateDisHor.setIndeterminate(false);
 		determinateDisHor.setEnabled(false);
-		JPanel ddhPanel = new JPanel();
-		ddhPanel.add(determinateDisHor);
-		ddhPanel.setBorder(new TitledBorder("Determ disabled"));
+		horizontalBuilder.appendSeparator("Determinate disabled");
+		horizontalBuilder.append(determinateDisHor);
 
 		JProgressBar determinateDisHorStr = new JProgressBar(
 				JProgressBar.HORIZONTAL, 0, 100);
 		determinateDisHorStr.setIndeterminate(false);
 		determinateDisHorStr.setEnabled(false);
 		determinateDisHorStr.setStringPainted(true);
-		JPanel ddhsPanel = new JPanel();
-		ddhsPanel.add(determinateDisHorStr);
-		ddhsPanel.setBorder(new TitledBorder("Determ disabled string"));
+		horizontalBuilder.appendSeparator("Determinate disabled + string");
+		horizontalBuilder.append(determinateDisHorStr);
 
 		JProgressBar indeterminateDisHor = new JProgressBar(
 				JProgressBar.HORIZONTAL, 0, 100);
 		indeterminateDisHor.setIndeterminate(true);
 		indeterminateDisHor.setEnabled(false);
-		JPanel idhPanel = new JPanel();
-		idhPanel.add(indeterminateDisHor);
-		idhPanel.setBorder(new TitledBorder("Indeterm disabled"));
+		horizontalBuilder.appendSeparator("Indeterminate disabled");
+		horizontalBuilder.append(indeterminateDisHor);
 
-		horizPanel.add(ddhPanel);
-		horizPanel.add(ddhsPanel);
-		horizPanel.add(idhPanel);
+		bars.add(horizontalBuilder.getPanel());
+
+		FormLayout verticalLm = new FormLayout(
+				"center:pref:grow, 4dlu, center:pref:grow, 4dlu, "
+						+ "center:pref:grow, 4dlu, center:pref:grow, 4dlu, center:pref:grow",
+				"");
+		DefaultFormBuilder verticalBuilder = new DefaultFormBuilder(verticalLm);
+		verticalBuilder.setDefaultDialogBorder();
+		verticalBuilder.append("Enabled");
+		verticalBuilder.append("RTL");
+		verticalBuilder.append("Indeterm");
+		verticalBuilder.append("Disabled");
+		verticalBuilder.append("Dis indet");
 
 		JProgressBar determinateEnVer = new JProgressBar(JProgressBar.VERTICAL,
 				0, 100);
 		determinateEnVer.setIndeterminate(false);
 		determinateEnVer.setStringPainted(true);
-		JPanel devPanel = new JPanel();
-		devPanel.add(determinateEnVer);
-		devPanel.setBorder(new TitledBorder("Determ enabled"));
+		verticalBuilder.append(determinateEnVer);
 
 		JProgressBar determinateEnVerRTL = new JProgressBar(
 				JProgressBar.VERTICAL, 0, 100);
@@ -166,41 +161,28 @@ public class ProgressBarPanel extends JPanel {
 		determinateEnVerRTL.setStringPainted(true);
 		determinateEnVerRTL
 				.setComponentOrientation(ComponentOrientation.RIGHT_TO_LEFT);
-		JPanel devRtlPanel = new JPanel();
-		devRtlPanel.add(determinateEnVerRTL);
-		devRtlPanel.setBorder(new TitledBorder("Determ enabled RTL"));
+		verticalBuilder.append(determinateEnVerRTL);
 
 		JProgressBar indeterminateEnVer = new JProgressBar(
 				JProgressBar.VERTICAL, 0, 100);
 		indeterminateEnVer.setIndeterminate(true);
 		indeterminateEnVer.setStringPainted(true);
 		indeterminateEnVer.setString("In progress");
-		JPanel ievPanel = new JPanel();
-		ievPanel.add(indeterminateEnVer);
-		ievPanel.setBorder(new TitledBorder("Indeterm enabled"));
-
-		vertPanel.add(devPanel);
-		vertPanel.add(devRtlPanel);
-		vertPanel.add(ievPanel);
+		verticalBuilder.append(indeterminateEnVer);
 
 		JProgressBar determinateDisVer = new JProgressBar(
 				JProgressBar.VERTICAL, 0, 100);
 		determinateDisVer.setIndeterminate(false);
 		determinateDisVer.setEnabled(false);
-		JPanel ddvPanel = new JPanel();
-		ddvPanel.add(determinateDisVer);
-		ddvPanel.setBorder(new TitledBorder("Determ disabled"));
+		verticalBuilder.append(determinateDisVer);
 
 		JProgressBar indeterminateDisVer = new JProgressBar(
 				JProgressBar.VERTICAL, 0, 100);
 		indeterminateDisVer.setIndeterminate(true);
 		indeterminateDisVer.setEnabled(false);
-		JPanel idvPanel = new JPanel();
-		idvPanel.add(indeterminateDisVer);
-		idvPanel.setBorder(new TitledBorder("Indeterm disabled"));
+		verticalBuilder.append(indeterminateDisVer);
 
-		vertPanel.add(ddvPanel);
-		vertPanel.add(idvPanel);
+		bars.add(verticalBuilder.getPanel());
 
 		this.add(new JScrollPane(bars), BorderLayout.CENTER);
 
