@@ -31,7 +31,6 @@ package test.check;
 
 import java.awt.*;
 import java.awt.event.*;
-import java.security.AccessControlException;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -42,10 +41,10 @@ import javax.swing.tree.DefaultMutableTreeNode;
 import org.jvnet.lafwidget.LafWidget;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.lafwidget.layout.TransitionLayoutManager;
-import org.jvnet.lafwidget.tabbed.DefaultTabPreviewPainter;
 import org.jvnet.lafwidget.utils.LafConstants.AnimationKind;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.skin.*;
+import org.jvnet.substance.api.skin.MagellanSkin;
+import org.jvnet.substance.skin.SkinChangeListener;
 import org.jvnet.substance.utils.SubstanceImageCreator;
 
 import test.Check;
@@ -130,8 +129,8 @@ public class SampleFrame extends JFrame {
 
 		this.add(Check.getToolbar("", 16, false), BorderLayout.NORTH);
 		this.add(this.tabbed, BorderLayout.CENTER);
-		this.tabbed.putClientProperty(LafWidget.TABBED_PANE_PREVIEW_PAINTER,
-				new DefaultTabPreviewPainter());
+		// this.tabbed.putClientProperty(LafWidget.TABBED_PANE_PREVIEW_PAINTER,
+		// new DefaultTabPreviewPainter());
 
 		JPanel transPanel = new JPanel();
 		transPanel.setLayout(new BorderLayout());
@@ -283,7 +282,7 @@ public class SampleFrame extends JFrame {
 		JComboBox combo = new JComboBox(new Object[] { "item1" });
 		combo.setSelectedIndex(0);
 		JTextField text = new JTextField("Text field");
-		text.setEditable(false);
+		// text.setEditable(false);
 		text.putClientProperty(LafWidget.ANIMATION_KIND, AnimationKind.SLOW);
 
 		builder.add(combo, cc.xy(1, 7));
@@ -430,14 +429,6 @@ public class SampleFrame extends JFrame {
 	}
 
 	public static void main(String... args) throws Exception {
-		try {
-			if (System.getProperty("swing.defaultlaf") == null)
-				UIManager
-						.setLookAndFeel(new SubstanceTwilightLookAndFeel());
-		} catch (AccessControlException ace) {
-			UIManager
-					.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
-		}
 
 		// UIDefaults uid = UIManager.getLookAndFeelDefaults();
 		// Font segoe = new Font("Segoe UI", Font.PLAIN, 12);
@@ -453,6 +444,9 @@ public class SampleFrame extends JFrame {
 
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
+				if (System.getProperty("swing.defaultlaf") == null) {
+					SubstanceLookAndFeel.setSkin(new MagellanSkin());
+				}
 				JFrame.setDefaultLookAndFeelDecorated(true);
 				SampleFrame sf = new SampleFrame(true);
 				sf.setSize(315, 245);
