@@ -474,6 +474,11 @@ public class SampleMenuFactory {
 				"org.jvnet.substance.skin.SubstanceCremeCoffeeLookAndFeel"));
 		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Dust",
 				"org.jvnet.substance.skin.SubstanceDustLookAndFeel"));
+		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame,
+				"Dust Coffee",
+				"org.jvnet.substance.skin.SubstanceDustCoffeeLookAndFeel"));
+		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Gemini",
+				"org.jvnet.substance.api.skin.SubstanceGeminiLookAndFeel"));
 		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Moderate",
 				"org.jvnet.substance.skin.SubstanceModerateLookAndFeel"));
 		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Nebula",
@@ -489,20 +494,11 @@ public class SampleMenuFactory {
 		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Sahara",
 				"org.jvnet.substance.skin.SubstanceSaharaLookAndFeel"));
 		substanceMenus.addSeparator();
-		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame,
-				"Field of Wheat",
-				"org.jvnet.substance.skin.SubstanceFieldOfWheatLookAndFeel"));
-		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame,
-				"Finding Nemo",
-				"org.jvnet.substance.skin.SubstanceFindingNemoLookAndFeel"));
-		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame,
-				"Green Magic",
-				"org.jvnet.substance.skin.SubstanceGreenMagicLookAndFeel"));
-		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Mango",
-				"org.jvnet.substance.skin.SubstanceMangoLookAndFeel"));
 		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame,
 				"Office Blue 2007",
 				"org.jvnet.substance.skin.SubstanceOfficeBlue2007LookAndFeel"));
+		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Magellan",
+				"org.jvnet.substance.api.skin.SubstanceMagellanLookAndFeel"));
 		substanceMenus.addSeparator();
 		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame,
 				"Challenger Deep",
@@ -521,6 +517,12 @@ public class SampleMenuFactory {
 				.add(SubstanceLafChanger
 						.getMenuItem(frame, "Raven Graphite Glass",
 								"org.jvnet.substance.skin.SubstanceRavenGraphiteGlassLookAndFeel"));
+		substanceMenus
+				.add(SubstanceLafChanger
+						.getMenuItem(frame, "Graphite Aqua",
+								"org.jvnet.substance.api.skin.SubstanceGraphiteAquaLookAndFeel"));
+		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Twilight",
+				"org.jvnet.substance.skin.SubstanceTwilightLookAndFeel"));
 		lafMenu.add(substanceMenus);
 		lafMenu.addSeparator();
 		JMenu coreLafMenus = new JMenu("Core LAFs");
