@@ -39,8 +39,7 @@ import javax.swing.border.LineBorder;
 import org.jvnet.lafwidget.LafWidget;
 import org.jvnet.lafwidget.preview.DefaultPreviewPainter;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.theme.SubstanceBottleGreenTheme;
-import org.jvnet.substance.utils.SubstanceConstants.ScrollPaneButtonPolicyKind;
+import org.jvnet.substance.api.SubstanceConstants.ScrollPaneButtonPolicyKind;
 
 import test.Check;
 
@@ -123,62 +122,6 @@ public class ScrollPanel extends ControllablePanel {
 		});
 		builder.append("Auto scroll", hasAutoScroll);
 
-		builder.appendSeparator("Scrollbar settings");
-		final JCheckBox useCurrentTheme = new JCheckBox("Use global");
-		useCurrentTheme.setSelected(true);
-		useCurrentTheme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				sp.getHorizontalScrollBar().putClientProperty(
-						SubstanceLookAndFeel.THEME_PROPERTY,
-						(useCurrentTheme.isSelected() ? null
-								: new SubstanceBottleGreenTheme()));
-				sp.getVerticalScrollBar().putClientProperty(
-						SubstanceLookAndFeel.THEME_PROPERTY,
-						(useCurrentTheme.isSelected() ? null
-								: new SubstanceBottleGreenTheme()));
-				sp.repaint();
-			}
-		});
-		builder.append("Theme", useCurrentTheme);
-
-		final JCheckBox isOverlay = new JCheckBox("Has overlay");
-		isOverlay.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				sp.putClientProperty(SubstanceLookAndFeel.OVERLAY_PROPERTY,
-						isOverlay.isSelected() ? Boolean.TRUE : null);
-				sp.repaint();
-			}
-		});
-		builder.append("Overlay", isOverlay);
-
-		builder.append("Composite", new BackgroundCompositeCombo(sp));
-
-		final JCheckBox isNotActive = new JCheckBox("is not painted active");
-		isNotActive.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				sp.putClientProperty(
-						SubstanceLookAndFeel.PAINT_ACTIVE_PROPERTY, isNotActive
-								.isSelected() ? Boolean.FALSE : null);
-				sp.repaint();
-			}
-		});
-		builder.append("Active state", isNotActive);
-
-		// final JCheckBox hasCustomGripPainter = new JCheckBox("Has grip
-		// painter");
-		// hasCustomGripPainter.addActionListener(new ActionListener() {
-		// public void actionPerformed(ActionEvent e) {
-		// sp
-		// .putClientProperty(
-		// SubstanceLookAndFeel.GRIP_PAINTER,
-		// hasCustomGripPainter.isSelected() ? new
-		// CoreGripPainters.DragBumpsGripPainter()
-		// : null);
-		// sp.repaint();
-		// }
-		// });
-		// builder.append("Grips", hasCustomGripPainter);
-
 		builder.appendSeparator("Scroll buttons settings");
 		final JComboBox buttonPolicyCombo = new JComboBox(new Object[] {
 				ScrollPaneButtonPolicyKind.NONE,
