@@ -10,7 +10,8 @@ import javax.swing.event.ListSelectionListener;
 import javax.swing.table.DefaultTableModel;
 import javax.swing.tree.DefaultMutableTreeNode;
 
-import org.jvnet.substance.SubstanceDefaultListCellRenderer;
+import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.api.renderers.SubstanceDefaultListCellRenderer;
 
 import com.jgoodies.forms.builder.DefaultFormBuilder;
 import com.jgoodies.forms.layout.FormLayout;
@@ -207,7 +208,7 @@ public class SizesPanel extends JPanel {
 					public boolean isCellEditable(int row, int column) {
 						return false;
 					}
-					
+
 					@Override
 					public String getColumnName(int column) {
 						return "Column " + column;
@@ -228,16 +229,18 @@ public class SizesPanel extends JPanel {
 				return model.size();
 			}
 		});
-		list.setCellRenderer(new SubstanceDefaultListCellRenderer() {
-			@Override
-			public Component getListCellRendererComponent(JList list,
-					Object value, int index, boolean isSelected,
-					boolean cellHasFocus) {
-				return super.getListCellRendererComponent(list,
-						((Mapping) value).caption, index, isSelected,
-						cellHasFocus);
-			}
-		});
+		if (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel) {
+			list.setCellRenderer(new SubstanceDefaultListCellRenderer() {
+				@Override
+				public Component getListCellRendererComponent(JList list,
+						Object value, int index, boolean isSelected,
+						boolean cellHasFocus) {
+					return super.getListCellRendererComponent(list,
+							((Mapping) value).caption, index, isSelected,
+							cellHasFocus);
+				}
+			});
+		}
 		this.setLayout(new BorderLayout());
 		this.add(new JScrollPane(list), BorderLayout.WEST);
 
@@ -266,8 +269,8 @@ public class SizesPanel extends JPanel {
 										builder.append(fontSize + " pixels",
 												sel.creator.create(fontSize));
 									}
-									builder.append("72 pixels",
-											sel.creator.create(72));
+									builder.append("72 pixels", sel.creator
+											.create(72));
 									central = new JScrollPane(
 											builder.getPanel(),
 											JScrollPane.VERTICAL_SCROLLBAR_ALWAYS,
