@@ -60,7 +60,7 @@ public class SpinnerPanel extends JPanel {
 
 		CreationCommand<Component> basicCr = new CreationCommand<Component>() {
 			public Component create() {
-				JSpinner basicSpinner = new JSpinner();
+				JSpinner basicSpinner = new JSpinner(new SpinnerNumberModel());
 				return basicSpinner;
 			}
 		};
