@@ -97,6 +97,15 @@ public class SplitPanel extends ControllablePanel {
 			}
 		});
 
+		final JCheckBox isEnabled = new JCheckBox("is enabled");
+		isEnabled.setSelected(true);
+		isEnabled.addActionListener(new ActionListener() {
+			public void actionPerformed(ActionEvent e) {
+				splitPane.setEnabled(isEnabled.isSelected());
+			}
+		});
+
+		builder.append(isEnabled);
 		builder.append(isOneTouch);
 		builder.append(isFlat);
 		builder.append(isVertical);
