@@ -33,8 +33,9 @@ import java.awt.*;
 import java.awt.geom.AffineTransform;
 import java.awt.geom.GeneralPath;
 
-import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.api.SubstanceSkin;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
+import org.jvnet.substance.utils.SubstanceColorSchemeUtilities;
 import org.jvnet.substance.watermark.SubstanceWatermark;
 
 /**
@@ -67,9 +68,9 @@ public class SubstanceCoffeeBeansWatermark implements SubstanceWatermark {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#updateWatermarkImage()
+	 * @see org.jvnet.substance.watermark.SubstanceWatermark#updateWatermarkImage(org.jvnet.substance.skin.SubstanceSkin)
 	 */
-	public boolean updateWatermarkImage() {
+	public boolean updateWatermarkImage(SubstanceSkin skin) {
 		Dimension screenDim = Toolkit.getDefaultToolkit().getScreenSize();
 		int screenWidth = screenDim.width;
 		int screenHeight = screenDim.height;
@@ -79,8 +80,8 @@ public class SubstanceCoffeeBeansWatermark implements SubstanceWatermark {
 		Graphics2D graphics = (Graphics2D) SubstanceCoffeeBeansWatermark.watermarkImage
 				.getGraphics().create();
 
-		boolean status = this.drawWatermarkImage(graphics, 0, 0, screenWidth,
-				screenHeight);
+		boolean status = this.drawWatermarkImage(skin, graphics, 0, 0,
+				screenWidth, screenHeight);
 		graphics.dispose();
 		return status;
 	}
@@ -92,7 +93,8 @@ public class SubstanceCoffeeBeansWatermark implements SubstanceWatermark {
 	 *      int, int, int, int)
 	 */
 	public void previewWatermark(Graphics g, int x, int y, int width, int height) {
-		this.drawWatermarkImage((Graphics2D) g, x, y, width, height);
+		this.drawWatermarkImage(SubstanceColorSchemeUtilities.METALLIC_SKIN,
+				(Graphics2D) g, x, y, width, height);
 	}
 
 	/**
@@ -111,10 +113,9 @@ public class SubstanceCoffeeBeansWatermark implements SubstanceWatermark {
 	 * @return <code>true</code> if the drawing succeeded, <code>false</code>
 	 *         otherwise.
 	 */
-	private boolean drawWatermarkImage(Graphics2D graphics, int x, int y,
-			int width, int height) {
-		Color stampColor = SubstanceCoreUtilities
-				.isThemeDark(SubstanceLookAndFeel.getTheme()) ? new Color(255,
+	private boolean drawWatermarkImage(SubstanceSkin skin, Graphics2D graphics,
+			int x, int y, int width, int height) {
+		Color stampColor = skin.getWatermarkColorScheme().isDark() ? new Color(255,
 				255, 255, 25) : new Color(0, 0, 0, 15);
 
 		int minBubbleRadius = 10;
@@ -169,15 +170,6 @@ public class SubstanceCoffeeBeansWatermark implements SubstanceWatermark {
 		return "Coffee Beans";
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#isDependingOnTheme()
-	 */
-	public boolean isDependingOnTheme() {
-		return true;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
