@@ -31,7 +31,9 @@ package test.check;
 
 import java.awt.*;
 
-import org.jvnet.substance.utils.SubstanceThemeUtilities;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceSkin;
+import org.jvnet.substance.utils.SubstanceColorSchemeUtilities;
 import org.jvnet.substance.watermark.SubstanceWatermark;
 
 /**
@@ -70,7 +72,8 @@ public class SubstanceDiagonalGradientWatermark implements SubstanceWatermark {
 
 		Graphics2D graphics = (Graphics2D) g.create();
 		graphics.setPaint(new GradientPaint(x - dx, y - dy, Color.gray, x - dx
-				+ dw, y - dy + dh, SubstanceThemeUtilities.getTheme(c).getColorScheme().getMidColor()));
+				+ dw, y - dy + dh, SubstanceColorSchemeUtilities.getColorScheme(c,
+				ComponentState.DEFAULT).getMidColor()));
 		graphics.setComposite(AlphaComposite.getInstance(
 				AlphaComposite.SRC_OVER, 0.8f));
 		graphics.fillRect(x, y, width, height);
@@ -81,9 +84,9 @@ public class SubstanceDiagonalGradientWatermark implements SubstanceWatermark {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#updateWatermarkImage()
+	 * @see org.jvnet.substance.watermark.SubstanceWatermark#updateWatermarkImage(org.jvnet.substance.skin.SubstanceSkin)
 	 */
-	public boolean updateWatermarkImage() {
+	public boolean updateWatermarkImage(SubstanceSkin skin) {
 		return true;
 	}
 
@@ -106,15 +109,6 @@ public class SubstanceDiagonalGradientWatermark implements SubstanceWatermark {
 		return "Diagonal Gradient";
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#isDependingOnTheme()
-	 */
-	public boolean isDependingOnTheme() {
-		return false;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
