@@ -29,6 +29,7 @@
  */
 package test.check;
 
+import java.awt.Window;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 
@@ -63,47 +64,43 @@ public class SubstanceLafChanger implements ActionListener {
 	public void actionPerformed(ActionEvent e) {
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
-				boolean wasDecoratedByOS = !frame.isUndecorated();
+				final boolean wasDecoratedByOS = !frame.isUndecorated();
 
 				try {
 					UIManager.setLookAndFeel(lafClassName);
-					SwingUtilities.invokeLater(new Runnable() {
-						public void run() {
-							SwingUtilities.updateComponentTreeUI(frame);
+					for (Window window : Window.getWindows()) {
+						SwingUtilities.updateComponentTreeUI(window);
+					}
+
+					boolean canBeDecoratedByLAF = UIManager.getLookAndFeel()
+							.getSupportsWindowDecorations();
+					if (canBeDecoratedByLAF == wasDecoratedByOS) {
+						boolean wasVisible = frame.isVisible();
+
+						frame.setVisible(false);
+						frame.dispose();
+						if (!canBeDecoratedByLAF || wasOriginallyDecoratedByOS) {
+							// see the java docs under the method
+							// JFrame.setDefaultLookAndFeelDecorated(boolean
+							// value) for description of these 2 lines:
+							frame.setUndecorated(false);
+							frame.getRootPane().setWindowDecorationStyle(
+									JRootPane.NONE);
+
+						} else {
+							frame.setUndecorated(true);
+							frame.getRootPane().setWindowDecorationStyle(
+									JRootPane.FRAME);
 						}
-					});
+						frame.setVisible(wasVisible);
+						// wasDecoratedByOS = !frame.isUndecorated();
+					}
 				} catch (ClassNotFoundException cnfe) {
 					out("LAF main class '" + lafClassName + "' not found");
 				} catch (Exception exc) {
 					exc.printStackTrace();
 				}
 
-//				if (!wasOriginallyDecoratedByOS)
-//					return;
-				
-				boolean canBeDecoratedByLAF = UIManager.getLookAndFeel()
-						.getSupportsWindowDecorations();
-				if (canBeDecoratedByLAF == wasDecoratedByOS) {
-					boolean wasVisible = frame.isVisible();
-
-					frame.setVisible(false);
-					frame.dispose();
-					if (!canBeDecoratedByLAF || wasOriginallyDecoratedByOS) {
-						// see the java docs under the method
-						// JFrame.setDefaultLookAndFeelDecorated(boolean
-						// value) for description of these 2 lines:
-						frame.setUndecorated(false);
-						frame.getRootPane().setWindowDecorationStyle(
-								JRootPane.NONE);
-
-					} else {
-						frame.setUndecorated(true);
-						frame.getRootPane().setWindowDecorationStyle(
-								JRootPane.FRAME);
-					}
-					frame.setVisible(wasVisible);
-					wasDecoratedByOS = !frame.isUndecorated();
-				}
 			}
 		});
 	}
