@@ -34,9 +34,11 @@ import java.awt.BorderLayout;
 import javax.swing.*;
 
 import org.jvnet.lafwidget.LafWidget;
-import org.jvnet.substance.SubstanceImageCreator;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.theme.ThemeChangeListener;
+import org.jvnet.substance.skin.SkinChangeListener;
+import org.jvnet.substance.utils.SubstanceImageCreator;
+
+import test.Check;
 
 /**
  * Test application panel for testing {@link JTabbedPane} component.
@@ -56,40 +58,38 @@ public class TabPanel extends ControllablePanel {
 		this.setLayout(new BorderLayout());
 		jtp = new JTabbedPane();
 		NumberedPanel tnp1 = new NumberedPanel(1);
-		tnp1
-				.putClientProperty(
-						SubstanceLookAndFeel.TABBED_PANE_VERTICAL_ORIENTATION_ROTATE_ICONS,
-						Boolean.TRUE);
 		jtp.addTab("tab0", null, new JPanel());
-		jtp.addTab("tab1", SubstanceImageCreator.getThemeIcon(null), tnp1);
-		jtp.addTab("tab 2", SubstanceImageCreator.getThemeIcon(null),
-				new NumberedPanel(2));
+		jtp.addTab("tab1", Check.getIcon("flag_mexico"), tnp1);
+		jtp.addTab("tab 2", Check.getIcon("flag_sweden"), new NumberedPanel(2));
 		NumberedPanel tnp3 = new NumberedPanel(3);
-		tnp3
-				.putClientProperty(
-						SubstanceLookAndFeel.TABBED_PANE_VERTICAL_ORIENTATION_ROTATE_ICONS,
-						Boolean.TRUE);
-		jtp.addTab("tab  3", SubstanceImageCreator.getThemeIcon(null), tnp3);
+		jtp.addTab("tab  3", Check.getIcon("flag_russia"), tnp3);
 		final NumberedPanel np4 = new NumberedPanel(4);
-		jtp.addTab("tab   4", new ImageIcon(SubstanceImageCreator
-				.getBigHexaMarker(4, SubstanceLookAndFeel.getTheme())), np4);
+		boolean isSubstance = (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel);
+		jtp.addTab("tab   4", isSubstance ? new ImageIcon(SubstanceImageCreator
+				.getBigHexaMarker(4, SubstanceLookAndFeel.getCurrentSkin(jtp)
+						.getMainActiveColorScheme())) : null, np4);
 		final NumberedPanel np5 = new NumberedPanel(5);
-		jtp.addTab("tab    5", new ImageIcon(SubstanceImageCreator
-				.getBigHexaMarker(5, SubstanceLookAndFeel.getTheme())), np5);
+		jtp.addTab("tab    5", isSubstance ? new ImageIcon(
+				SubstanceImageCreator.getBigHexaMarker(5, SubstanceLookAndFeel
+						.getCurrentSkin(jtp).getMainActiveColorScheme()))
+				: null, np5);
 		SubstanceLookAndFeel
-				.registerThemeChangeListener(new ThemeChangeListener() {
-					public void themeChanged() {
+				.registerSkinChangeListener(new SkinChangeListener() {
+					@Override
+					public void skinChanged() {
 						int index4 = jtp.indexOfComponent(np4);
 						if (index4 >= 0) {
 							jtp.setIconAt(index4, SubstanceImageCreator
 									.getHexaMarker(4, SubstanceLookAndFeel
-											.getTheme()));
+											.getCurrentSkin(jtp)
+											.getMainActiveColorScheme()));
 						}
 						int index5 = jtp.indexOfComponent(np5);
 						if (index5 >= 0) {
 							jtp.setIconAt(index5, SubstanceImageCreator
 									.getHexaMarker(5, SubstanceLookAndFeel
-											.getTheme()));
+											.getCurrentSkin(jtp)
+											.getMainActiveColorScheme()));
 						}
 					}
 				});
