@@ -43,7 +43,7 @@ import javax.swing.table.JTableHeader;
 
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.utils.LafConstants.AnimationKind;
-import org.jvnet.substance.*;
+import org.jvnet.substance.SubstanceLookAndFeel;
 import org.jvnet.substance.api.SubstanceColorScheme;
 import org.jvnet.substance.api.renderers.SubstanceDefaultTableCellRenderer;
 import org.jvnet.substance.colorscheme.*;
@@ -58,7 +58,14 @@ import com.jgoodies.forms.layout.FormLayout;
  * 
  * @author Kirill Grouchnikov
  */
-public class TablePanel extends ControllablePanel {
+public class TablePanel extends ControllablePanel implements Deferrable {
+	private boolean isInitialized;
+
+	@Override
+	public boolean isInitialized() {
+		return this.isInitialized;
+	}
+
 	/**
 	 * The table.
 	 */
@@ -263,15 +270,9 @@ public class TablePanel extends ControllablePanel {
 	 * Creates a test panel with table.
 	 */
 	public TablePanel() {
-		// TableColumnModel columnModel = new DefaultTableColumnModel() {
-		// @Override public int getColumnCount() {
-		// return 10;
-		// }
-		//
-		// @Override public TableColumn getColumn(int columnIndex) {
-		// return new TableColumn(
-		// }
-		// };
+	}
+
+	public synchronized void initialize() {
 		this.table = new JTable(new MyTableModel(20));
 		this.table.setDefaultRenderer(Color.class, new MyColorTableRenderer());
 		this.table.setDefaultRenderer(Float.class, new MyFloatTableRenderer());
@@ -396,6 +397,22 @@ public class TablePanel extends ControllablePanel {
 		});
 		builder.append("Sorted", isSorted);
 
+		final JCheckBox customBackgroundCb = new JCheckBox(
+				"Has pink background");
+		customBackgroundCb.addActionListener(new ActionListener() {
+			Color oldBackColor;
+
+			public void actionPerformed(ActionEvent e) {
+				if (customBackgroundCb.isSelected()) {
+					oldBackColor = table.getBackground();
+					table.setBackground(new Color(255, 128, 128));
+				} else {
+					table.setBackground(oldBackColor);
+				}
+			}
+		});
+		builder.append("Background", customBackgroundCb);
+
 		final JCheckBox watermarkBleed = new JCheckBox("Watermark bleed");
 		watermarkBleed.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
@@ -513,6 +530,7 @@ public class TablePanel extends ControllablePanel {
 		builder.append("Set font", tahoma13);
 
 		this.controlPanel = builder.getPanel();
+		this.isInitialized = true;
 	}
 
 }
\ No newline at end of file
