@@ -40,9 +40,8 @@ import javax.swing.event.ChangeListener;
 import javax.swing.tree.DefaultMutableTreeNode;
 
 import org.jvnet.lafwidget.LafWidget;
-import org.jvnet.lafwidget.animation.FadeConfigurationManager;
-import org.jvnet.substance.SubstanceDefaultTreeCellRenderer;
 import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.api.renderers.SubstanceDefaultTreeCellRenderer;
 
 import test.Check;
 
@@ -63,6 +62,7 @@ public class TreePanel extends ControllablePanel {
 	 */
 	private static class TestTreeCellRenderer extends
 			SubstanceDefaultTreeCellRenderer {
+		@Override
 		public Component getTreeCellRendererComponent(JTree tree, Object value,
 				boolean sel, boolean expanded, boolean leaf, int row,
 				boolean hasFocus) {
@@ -133,7 +133,8 @@ public class TreePanel extends ControllablePanel {
 		this.add(this.jsp, BorderLayout.CENTER);
 
 		FormLayout lm = new FormLayout("right:pref, 4dlu, fill:pref:grow", "");
-		DefaultFormBuilder builder = new DefaultFormBuilder(lm, new ScrollablePanel());
+		DefaultFormBuilder builder = new DefaultFormBuilder(lm,
+				new ScrollablePanel());
 		builder.appendSeparator("General");
 
 		final JCheckBox isEnabled = new JCheckBox("is enabled");
@@ -164,12 +165,12 @@ public class TreePanel extends ControllablePanel {
 		});
 		builder.append("Editable", isEditable);
 
-		final JCheckBox watermarkBleed = new JCheckBox("is bleeding");
+		final JCheckBox watermarkBleed = new JCheckBox("is visible");
 		watermarkBleed.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				tree.putClientProperty(SubstanceLookAndFeel.WATERMARK_TO_BLEED,
+				tree.putClientProperty(SubstanceLookAndFeel.WATERMARK_VISIBLE,
 						Boolean.valueOf(watermarkBleed.isSelected()));
-				jsp.putClientProperty(SubstanceLookAndFeel.WATERMARK_TO_BLEED,
+				jsp.putClientProperty(SubstanceLookAndFeel.WATERMARK_VISIBLE,
 						Boolean.valueOf(watermarkBleed.isSelected()));
 				tree.repaint();
 			}
@@ -195,28 +196,6 @@ public class TreePanel extends ControllablePanel {
 		});
 		builder.append("Container", isWrappedInScrollPane);
 
-		final JCheckBox cbTreeDecorations = new JCheckBox(
-				"animate tree decorations");
-		cbTreeDecorations.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				if (cbTreeDecorations.isSelected()) {
-					FadeConfigurationManager
-							.getInstance()
-							.allowFades(
-									SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND,
-									tree);
-				} else {
-					FadeConfigurationManager
-							.getInstance()
-							.disallowFades(
-									SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND,
-									tree);
-				}
-				tree.repaint();
-			}
-		});
-		builder.append("Decorations", cbTreeDecorations);
-
 		final JCheckBox rendererCB = new JCheckBox("has custom renderer");
 		rendererCB.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
