@@ -83,7 +83,7 @@ public class FontSizePanel {
 
 		final JSlider fontSizeSlider = new JSlider(0, 10, 0);
 		fontSizeSlider.setFocusable(false);
-		//fontSizeSlider.setOpaque(false);
+		// fontSizeSlider.setOpaque(false);
 		fontSizeSlider
 				.setToolTipText("Controls the global font set size. Resets Substance as the current LAF.");
 		fontSizeSlider.addChangeListener(new ChangeListener() {
@@ -106,17 +106,7 @@ public class FontSizePanel {
 								}
 							};
 
-							try {
-								SubstanceLookAndFeel
-										.setFontPolicy(newFontPolicy);
-								UIManager
-										.setLookAndFeel(new SubstanceLookAndFeel());
-								SwingUtilities
-										.updateComponentTreeUI(SwingUtilities
-												.getWindowAncestor(fontSizeLabel));
-							} catch (Exception exc) {
-								exc.printStackTrace();
-							}
+							SubstanceLookAndFeel.setFontPolicy(newFontPolicy);
 
 							fontSizeLabel.setText(SubstanceLookAndFeel
 									.getFontPolicy().getFontSet("Substance",
@@ -138,7 +128,7 @@ public class FontSizePanel {
 		builder.append(zoomInLabel);
 
 		JPanel result = builder.getPanel();
-		//result.setOpaque(false);
+		// result.setOpaque(false);
 		return result;
 	}
 }
