@@ -37,7 +37,8 @@ import java.awt.event.ActionListener;
 import javax.swing.*;
 
 import org.jvnet.lafwidget.LafWidget;
-import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
+import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.skin.BusinessBlackSteelSkin;
 
 /**
  * Test application that shows the use of the
@@ -82,21 +83,16 @@ public class TextEditContextMenu extends JFrame {
 	}
 
 	/**
-	 * The main method for <code>this</code> sample. The arguments are
-	 * ignored.
+	 * The main method for <code>this</code> sample. The arguments are ignored.
 	 * 
 	 * @param args
 	 *            Ignored.
-	 * @throws Exception
-	 *             If some exception occured. Note that there is no special
-	 *             treatment of exception conditions in <code>this</code>
-	 *             sample code.
 	 */
-	public static void main(String[] args) throws Exception {
-		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
+	public static void main(String[] args) {
 		JFrame.setDefaultLookAndFeelDecorated(true);
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
+				SubstanceLookAndFeel.setSkin(new BusinessBlackSteelSkin());
 				new TextEditContextMenu().setVisible(true);
 			}
 		});
