@@ -41,8 +41,7 @@ import javax.swing.plaf.FontUIResource;
 import org.jvnet.substance.SubstanceLookAndFeel;
 import org.jvnet.substance.fonts.FontPolicy;
 import org.jvnet.substance.fonts.FontSet;
-import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
-
+import org.jvnet.substance.skin.BusinessBlackSteelSkin;
 
 /**
  * Test application that shows the use of the
@@ -184,15 +183,15 @@ public class GetFontPolicy extends JFrame {
 				FontPolicy fontPolicy = SubstanceLookAndFeel.getFontPolicy();
 				FontSet fontSet = fontPolicy.getFontSet("Substance", null);
 				String[] infoArray = new String[] {
-					"Control: " + fontSet.getControlFont(),
-					"Menu: " + fontSet.getMenuFont(),
-					"Message: " + fontSet.getMessageFont(),
-					"Small: " + fontSet.getSmallFont(),
-					"Title: " + fontSet.getTitleFont(),
-					"Window title: " + fontSet.getWindowTitleFont()
-				};
+						"Control: " + fontSet.getControlFont(),
+						"Menu: " + fontSet.getMenuFont(),
+						"Message: " + fontSet.getMessageFont(),
+						"Small: " + fontSet.getSmallFont(),
+						"Title: " + fontSet.getTitleFont(),
+						"Window title: " + fontSet.getWindowTitleFont() };
 				JList infoList = new JList(infoArray);
-				JDialog infoDialog = new JDialog(GetFontPolicy.this, "Font set info", true);
+				JDialog infoDialog = new JDialog(GetFontPolicy.this,
+						"Font set info", true);
 				infoDialog.setLayout(new BorderLayout());
 				infoDialog.add(infoList, BorderLayout.CENTER);
 				infoDialog.pack();
@@ -210,22 +209,17 @@ public class GetFontPolicy extends JFrame {
 	}
 
 	/**
-	 * The main method for <code>this</code> sample. The arguments are
-	 * ignored.
+	 * The main method for <code>this</code> sample. The arguments are ignored.
 	 * 
 	 * @param args
 	 *            Ignored.
-	 * @throws Exception
-	 *             If some exception occured. Note that there is no special
-	 *             treatment of exception conditions in <code>this</code>
-	 *             sample code.
 	 */
-	public static void main(String[] args) throws Exception {
-		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
+	public static void main(String[] args) {
 		JFrame.setDefaultLookAndFeelDecorated(true);
 		JDialog.setDefaultLookAndFeelDecorated(true);
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
+				SubstanceLookAndFeel.setSkin(new BusinessBlackSteelSkin());
 				new GetFontPolicy().setVisible(true);
 			}
 		});
