@@ -39,8 +39,7 @@ import javax.swing.plaf.FontUIResource;
 import org.jvnet.substance.SubstanceLookAndFeel;
 import org.jvnet.substance.fonts.FontPolicy;
 import org.jvnet.substance.fonts.FontSet;
-import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
-
+import org.jvnet.substance.skin.BusinessBlackSteelSkin;
 
 /**
  * Test application that shows the use of the
@@ -141,7 +140,7 @@ public class SetFontPolicy extends JFrame {
 					final int newValue = fontSizeSlider.getValue();
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
-							// reset the base font policy to null - this 
+							// reset the base font policy to null - this
 							// restores the original font policy (default size).
 							SubstanceLookAndFeel.setFontPolicy(null);
 							// Get the default font set
@@ -187,22 +186,17 @@ public class SetFontPolicy extends JFrame {
 	}
 
 	/**
-	 * The main method for <code>this</code> sample. The arguments are
-	 * ignored.
+	 * The main method for <code>this</code> sample. The arguments are ignored.
 	 * 
 	 * @param args
 	 *            Ignored.
-	 * @throws Exception
-	 *             If some exception occured. Note that there is no special
-	 *             treatment of exception conditions in <code>this</code>
-	 *             sample code.
 	 */
-	public static void main(String[] args) throws Exception {
-		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
+	public static void main(String[] args) {
 		JFrame.setDefaultLookAndFeelDecorated(true);
 		JDialog.setDefaultLookAndFeelDecorated(true);
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
+				SubstanceLookAndFeel.setSkin(new BusinessBlackSteelSkin());
 				new SetFontPolicy().setVisible(true);
 			}
 		});
