@@ -36,11 +36,11 @@ import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
+import org.jvnet.substance.skin.BusinessBlackSteelSkin;
 
 /**
- * Test application that shows the use of the {@link
- * SubstanceLookAndFeel#COLORIZATION_FACTOR} client property.
+ * Test application that shows the use of the
+ * {@link SubstanceLookAndFeel#COLORIZATION_FACTOR} client property.
  * 
  * @author Kirill Grouchnikov
  * @see SubstanceLookAndFeel#COLORIZATION_FACTOR
@@ -96,16 +96,13 @@ public class ColorizationFactor extends JFrame {
 	 * The main method for <code>this</code> sample. The arguments are ignored.
 	 * 
 	 * @param args
-	 * 		Ignored.
-	 * @throws Exception
-	 * 		If some exception occured. Note that there is no special treatment
-	 * 		of exception conditions in <code>this</code> sample code.
+	 *            Ignored.
 	 */
-	public static void main(String[] args) throws Exception {
-		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
+	public static void main(String[] args) {
 		JFrame.setDefaultLookAndFeelDecorated(true);
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
+				SubstanceLookAndFeel.setSkin(new BusinessBlackSteelSkin());
 				new ColorizationFactor().setVisible(true);
 			}
 		});
