@@ -30,16 +30,18 @@
 package tools.docrobot;
 
 import java.awt.Graphics;
-import java.awt.event.ComponentAdapter;
-import java.awt.event.ComponentEvent;
 import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.IOException;
-import java.util.concurrent.CountDownLatch;
 
 import javax.imageio.ImageIO;
-import javax.swing.*;
+import javax.swing.ImageIcon;
+import javax.swing.JFrame;
 
+import org.fest.swing.core.BasicRobot;
+import org.fest.swing.core.Robot;
+import org.fest.swing.edt.GuiActionRunner;
+import org.fest.swing.edt.GuiTask;
 import org.jvnet.substance.SubstanceLookAndFeel;
 import org.jvnet.substance.api.SubstanceSkin;
 import org.jvnet.substance.utils.SubstanceImageCreator;
@@ -67,11 +69,6 @@ public abstract class BaseRobot {
 	 */
 	protected SampleFrame sf;
 
-	/**
-	 * Used to wait for the rendering.
-	 */
-	protected CountDownLatch gate;
-
 	/**
 	 * Creates the new screenshot robot.
 	 * 
@@ -90,58 +87,56 @@ public abstract class BaseRobot {
 	 */
 	public void run() {
 		long start = System.currentTimeMillis();
-		this.gate = new CountDownLatch(1);
-		SwingUtilities.invokeLater(new Runnable() {
-			public void run() {
+
+		Robot robot = BasicRobot.robotWithNewAwtHierarchy();
+
+		// set skin
+		GuiActionRunner.execute(new GuiTask() {
+			@Override
+			protected void executeInEDT() throws Throwable {
 				SubstanceLookAndFeel.setSkin(skin);
-				SwingUtilities.invokeLater(new Runnable() {
-					public void run() {
-						JFrame.setDefaultLookAndFeelDecorated(true);
-						sf = new SampleFrame(false);
-						sf
-								.setIconImage(SubstanceImageCreator
-										.getColorSchemeImage(
-												null,
-												new ImageIcon(
-														BaseRobot.class
-																.getClassLoader()
-																.getResource(
-																		"test/resource/image-x-generic.png")),
-												SubstanceLookAndFeel
-														.getCurrentSkin(
-																sf
-																		.getRootPane())
-														.getMainActiveColorScheme(),
-												0.0f));
-						sf.addComponentListener(new ComponentAdapter() {
-							@Override
-							public void componentShown(ComponentEvent e) {
-								SwingUtilities.invokeLater(new Runnable() {
-									public void run() {
-										makeScreenshot();
-										SwingUtilities
-												.invokeLater(new Runnable() {
-													public void run() {
-														sf.dispose();
-														gate.countDown();
-													}
-												});
-									}
-								});
-							}
-						});
-						sf.setSize(315, 245);
-						sf.setLocationRelativeTo(null);
-						sf.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
-						sf.setVisible(true);
-					}
-				});
+				JFrame.setDefaultLookAndFeelDecorated(true);
 			}
 		});
-		try {
-			gate.await();
-		} catch (InterruptedException ie) {
-		}
+		robot.waitForIdle();
+
+		// create the frame and set the icon image
+		GuiActionRunner.execute(new GuiTask() {
+			@Override
+			protected void executeInEDT() throws Throwable {
+				sf = new SampleFrame(false);
+				sf.setIconImage(SubstanceImageCreator.getColorSchemeImage(null,
+						new ImageIcon(SkinRobot.class.getClassLoader()
+								.getResource(
+										"test/resource/image-x-generic.png")),
+						SubstanceLookAndFeel.getCurrentSkin(sf.getRootPane())
+								.getMainActiveColorScheme(), 0.0f));
+				sf.setSize(315, 245);
+				sf.setLocationRelativeTo(null);
+				sf.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
+				sf.setVisible(true);
+			}
+		});
+		robot.waitForIdle();
+
+		// make the screenshot
+		GuiActionRunner.execute(new GuiTask() {
+			@Override
+			protected void executeInEDT() throws Throwable {
+				makeScreenshot();
+			}
+		});
+		robot.waitForIdle();
+
+		// dispose the frame
+		GuiActionRunner.execute(new GuiTask() {
+			@Override
+			protected void executeInEDT() throws Throwable {
+				sf.dispose();
+			}
+		});
+		robot.waitForIdle();
+
 		long end = System.currentTimeMillis();
 		System.out.println(this.getClass().getSimpleName() + " : "
 				+ (end - start) + "ms");
