@@ -31,19 +31,20 @@ package tools.docrobot;
 
 import java.awt.FlowLayout;
 import java.awt.Graphics;
-import java.awt.event.ComponentAdapter;
-import java.awt.event.ComponentEvent;
 import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.IOException;
-import java.util.concurrent.CountDownLatch;
 
 import javax.imageio.ImageIO;
-import javax.swing.*;
+import javax.swing.JButton;
+import javax.swing.JFrame;
 
+import org.fest.swing.core.BasicRobot;
+import org.fest.swing.core.Robot;
+import org.fest.swing.edt.GuiActionRunner;
+import org.fest.swing.edt.GuiTask;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
-import org.jvnet.substance.utils.SubstanceImageCreator;
+import org.jvnet.substance.skin.BusinessBlackSteelSkin;
 
 /**
  * The base class for taking a single screenshot for Substance documentation.
@@ -61,11 +62,6 @@ public abstract class ImageWatermarkRobot {
 	 */
 	protected JFrame sf;
 
-	/**
-	 * Used to wait for the rendering.
-	 */
-	protected CountDownLatch gate;
-
 	/**
 	 * Creates the new screenshot robot.
 	 * 
@@ -81,78 +77,65 @@ public abstract class ImageWatermarkRobot {
 	 */
 	public void run() {
 		long start = System.currentTimeMillis();
-		this.gate = new CountDownLatch(1);
-		SwingUtilities.invokeLater(new Runnable() {
-			public void run() {
-				try {
-					UIManager
-							.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
-				} catch (Exception exc) {
-					exc.printStackTrace();
-				}
-				SwingUtilities.invokeLater(new Runnable() {
-					public void run() {
-						JFrame.setDefaultLookAndFeelDecorated(true);
-						sf = new JFrame("Sample frame");
-						sf.addComponentListener(new ComponentAdapter() {
-							@Override
-							public void componentShown(ComponentEvent e) {
-								SwingUtilities.invokeLater(new Runnable() {
-									public void run() {
-										apply();
-										sf
-												.setIconImage(SubstanceImageCreator
-														.getColorSchemeImage(
-																null,
-																new ImageIcon(
-																		ImageWatermarkRobot.class
-																				.getClassLoader()
-																				.getResource(
-																						"test/resource/image-x-generic.png")),
-																SubstanceLookAndFeel
-																		.getCurrentSkin(
-																				sf
-																						.getRootPane())
-																		.getMainActiveColorScheme(),
-																0.0f));
-										makeScreenshot();
-										SwingUtilities
-												.invokeLater(new Runnable() {
-													public void run() {
-														sf.dispose();
-														gate.countDown();
-													}
-												});
-									}
-								});
-							}
-						});
-						sf.setSize(238, 261);
 
-						sf.setLayout(new FlowLayout(FlowLayout.CENTER));
-						JButton defButton = new JButton("default");
-						JButton disButton = new JButton("disabled");
-						JButton regButton = new JButton("regular");
-						disButton.setEnabled(false);
-						sf.add(defButton);
-						sf.add(disButton);
-						sf.add(regButton);
-						sf.getRootPane().setDefaultButton(defButton);
+		Robot robot = BasicRobot.robotWithNewAwtHierarchy();
 
-						BufferedImage iconImage = new BufferedImage(1, 1,
-								BufferedImage.TYPE_INT_ARGB);
-						sf.setIconImage(iconImage);
-						sf.setLocationRelativeTo(null);
-						sf.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
-						sf.setVisible(true);
-					}
-				});
+		// set skin
+		GuiActionRunner.execute(new GuiTask() {
+			@Override
+			protected void executeInEDT() throws Throwable {
+				SubstanceLookAndFeel.setSkin(new BusinessBlackSteelSkin());
+				JFrame.setDefaultLookAndFeelDecorated(true);
 			}
 		});
-		try {
-			gate.await();
-		} catch (InterruptedException ie) {
-		}
+		robot.waitForIdle();
+
+		// create the frame and set the icon image
+		GuiActionRunner.execute(new GuiTask() {
+			@Override
+			protected void executeInEDT() throws Throwable {
+				sf = new JFrame("Sample frame");
+				apply();
+				sf.setSize(238, 261);
+
+				sf.setLayout(new FlowLayout(FlowLayout.CENTER));
+				JButton defButton = new JButton("default");
+				JButton disButton = new JButton("disabled");
+				JButton regButton = new JButton("regular");
+				disButton.setEnabled(false);
+				sf.add(defButton);
+				sf.add(disButton);
+				sf.add(regButton);
+				sf.getRootPane().setDefaultButton(defButton);
+
+				BufferedImage iconImage = new BufferedImage(1, 1,
+						BufferedImage.TYPE_INT_ARGB);
+				sf.setIconImage(iconImage);
+				sf.setLocationRelativeTo(null);
+				sf.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
+				sf.setVisible(true);
+			}
+		});
+		robot.waitForIdle();
+
+		// make the screenshot
+		GuiActionRunner.execute(new GuiTask() {
+			@Override
+			protected void executeInEDT() throws Throwable {
+				makeScreenshot();
+			}
+		});
+		robot.waitForIdle();
+
+		// dispose the frame
+		GuiActionRunner.execute(new GuiTask() {
+			@Override
+			protected void executeInEDT() throws Throwable {
+				sf.dispose();
+			}
+		});
+		robot.waitForIdle();
+
 		long end = System.currentTimeMillis();
 		System.out.println(this.getClass().getSimpleName() + " : "
 				+ (end - start) + "ms");
