@@ -30,7 +30,9 @@
 package tools.docrobot;
 
 import org.jvnet.substance.api.*;
-import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.api.painter.overlay.BottomLineOverlayPainter;
+import org.jvnet.substance.colorscheme.BlendBiColorScheme;
+import org.jvnet.substance.colorscheme.DarkMetallicColorScheme;
 import org.jvnet.substance.painter.border.ClassicBorderPainter;
 import org.jvnet.substance.painter.decoration.*;
 import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
@@ -39,14 +41,24 @@ import org.jvnet.substance.shaper.ClassicButtonShaper;
 import org.jvnet.substance.watermark.SubstancePlanktonWatermark;
 import org.jvnet.substance.watermark.SubstanceWatermark;
 
+/**
+ * The default dark skin for the docrobot scripts.
+ * 
+ * @author Kirill Grouchnikov
+ */
 public class RobotDefaultDarkSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
-	public static String NAME = "Robot Default";
+	public static String NAME = "Robot Default Dark";
 
+	/**
+	 * Creates the skin based on the specified color scheme.
+	 * 
+	 * @param colorScheme
+	 *            The active color scheme.
+	 */
 	public RobotDefaultDarkSkin(SubstanceColorScheme colorScheme) {
-		boolean isActiveSchemeDark = colorScheme.isDark();
 		SubstanceColorScheme inactiveScheme = new BlendBiColorScheme(
 				colorScheme, new DarkMetallicColorScheme(), 0.6);
 		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
@@ -66,6 +78,13 @@ public class RobotDefaultDarkSkin extends SubstanceSkin {
 		this.selectedTabFadeStart = 1.0;
 		this.selectedTabFadeEnd = 1.0;
 
+		BottomLineOverlayPainter bottomLineOverlayPainter = new BottomLineOverlayPainter(
+				ColorSchemeSingleColorQuery.MID);
+		this.addOverlayPainter(bottomLineOverlayPainter,
+				DecorationAreaType.PRIMARY_TITLE_PANE,
+				DecorationAreaType.SECONDARY_TITLE_PANE,
+				DecorationAreaType.HEADER);
+
 		this.watermark = new SubstancePlanktonWatermark();
 		this.watermarkScheme = new BlendBiColorScheme(colorScheme,
 				new DarkMetallicColorScheme(), 0.5);
@@ -75,7 +94,6 @@ public class RobotDefaultDarkSkin extends SubstanceSkin {
 		this.borderPainter = new ClassicBorderPainter();
 
 		MarbleNoiseDecorationPainter decorationPainter = new MarbleNoiseDecorationPainter();
-		decorationPainter.setPaintingSeparators(true);
 		decorationPainter.setBaseDecorationPainter(new ArcDecorationPainter());
 		decorationPainter.setTextureAlpha(0.3f);
 		this.decorationPainter = decorationPainter;
@@ -84,15 +102,14 @@ public class RobotDefaultDarkSkin extends SubstanceSkin {
 		this.borderPainter = new ClassicBorderPainter();
 	}
 
-	public RobotDefaultDarkSkin() {
-		this(new AquaColorScheme());
-	}
-
-	public RobotDefaultDarkSkin(SubstanceWatermark watermark) {
-		this();
-		this.watermark = watermark;
-	}
-
+	/**
+	 * Creates the skin based on the specified color scheme and watermark.
+	 * 
+	 * @param colorScheme
+	 *            The active color scheme.
+	 * @param watermark
+	 *            Watermark.
+	 */
 	public RobotDefaultDarkSkin(SubstanceColorScheme colorScheme,
 			SubstanceWatermark watermark) {
 		this(colorScheme);
