@@ -30,7 +30,9 @@
 package tools.docrobot;
 
 import org.jvnet.substance.api.*;
-import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.api.painter.overlay.BottomLineOverlayPainter;
+import org.jvnet.substance.colorscheme.LightGrayColorScheme;
+import org.jvnet.substance.colorscheme.MetallicColorScheme;
 import org.jvnet.substance.painter.border.ClassicBorderPainter;
 import org.jvnet.substance.painter.decoration.*;
 import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
@@ -38,12 +40,23 @@ import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
 import org.jvnet.substance.shaper.ClassicButtonShaper;
 import org.jvnet.substance.watermark.SubstanceWatermark;
 
+/**
+ * The default light skin for the docrobot scripts.
+ * 
+ * @author Kirill Grouchnikov
+ */
 public class RobotDefaultSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
 	public static String NAME = "Robot Default";
 
+	/**
+	 * Creates the skin based on the specified color scheme.
+	 * 
+	 * @param colorScheme
+	 *            The active color scheme.
+	 */
 	public RobotDefaultSkin(SubstanceColorScheme colorScheme) {
 		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
 				colorScheme, new MetallicColorScheme(),
@@ -56,12 +69,18 @@ public class RobotDefaultSkin extends SubstanceSkin {
 				DecorationAreaType.SECONDARY_TITLE_PANE,
 				DecorationAreaType.HEADER);
 
+		BottomLineOverlayPainter bottomLineOverlayPainter = new BottomLineOverlayPainter(
+				ColorSchemeSingleColorQuery.MID);
+		this.addOverlayPainter(bottomLineOverlayPainter,
+				DecorationAreaType.PRIMARY_TITLE_PANE,
+				DecorationAreaType.SECONDARY_TITLE_PANE,
+				DecorationAreaType.HEADER);
+
 		this.buttonShaper = new ClassicButtonShaper();
 		this.gradientPainter = new ClassicGradientPainter();
 		this.borderPainter = new ClassicBorderPainter();
 
 		MarbleNoiseDecorationPainter decorationPainter = new MarbleNoiseDecorationPainter();
-		decorationPainter.setPaintingSeparators(true);
 		decorationPainter.setBaseDecorationPainter(new ArcDecorationPainter());
 		decorationPainter.setTextureAlpha(0.3f);
 		this.decorationPainter = decorationPainter;
@@ -70,15 +89,14 @@ public class RobotDefaultSkin extends SubstanceSkin {
 		this.borderPainter = new ClassicBorderPainter();
 	}
 
-	public RobotDefaultSkin() {
-		this(new AquaColorScheme());
-	}
-
-	public RobotDefaultSkin(SubstanceWatermark watermark) {
-		this();
-		this.watermark = watermark;
-	}
-
+	/**
+	 * Creates the skin based on the specified color scheme and watermark.
+	 * 
+	 * @param colorScheme
+	 *            The active color scheme.
+	 * @param watermark
+	 *            Watermark.
+	 */
 	public RobotDefaultSkin(SubstanceColorScheme colorScheme,
 			SubstanceWatermark watermark) {
 		this(colorScheme);
